@@ -26,11 +26,9 @@ from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.typing import StateType
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
-from homeassistant.util.unit_system import METRIC_SYSTEM
 
 from . import AccuWeatherDataUpdateCoordinator
 from .const import (
-    API_IMPERIAL,
     API_METRIC,
     ATTR_CATEGORY,
     ATTR_DIRECTION,
@@ -51,7 +49,7 @@ PARALLEL_UPDATES = 1
 class AccuWeatherSensorDescriptionMixin:
     """Mixin for AccuWeather sensor."""
 
-    value_fn: Callable[[dict[str, Any], str], StateType]
+    value_fn: Callable[[dict[str, Any]], StateType]
 
 
 @dataclass
@@ -61,18 +59,25 @@ class AccuWeatherSensorDescription(
     """Class describing AccuWeather sensor entities."""
 
     attr_fn: Callable[[dict[str, Any]], dict[str, StateType]] = lambda _: {}
-    metric_unit: str | None = None
-    us_customary_unit: str | None = None
 
 
 FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
+    AccuWeatherSensorDescription(
+        key="AirQuality",
+        icon="mdi:air-filter",
+        name="Air quality",
+        value_fn=lambda data: cast(str, data[ATTR_CATEGORY]),
+        device_class=SensorDeviceClass.ENUM,
+        options=["good", "hazardous", "high", "low", "moderate", "unhealthy"],
+        translation_key="air_quality",
+    ),
     AccuWeatherSensorDescription(
         key="CloudCoverDay",
         icon="mdi:weather-cloudy",
         name="Cloud cover day",
         entity_registry_enabled_default=False,
         native_unit_of_measurement=PERCENTAGE,
-        value_fn=lambda data, _: cast(int, data),
+        value_fn=lambda data: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="CloudCoverNight",
@@ -80,7 +85,7 @@ FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Cloud cover night",
         entity_registry_enabled_default=False,
         native_unit_of_measurement=PERCENTAGE,
-        value_fn=lambda data, _: cast(int, data),
+        value_fn=lambda data: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="Grass",
@@ -88,15 +93,16 @@ FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Grass pollen",
         entity_registry_enabled_default=False,
         native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
-        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        value_fn=lambda data: cast(int, data[ATTR_VALUE]),
         attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
+        translation_key="grass_pollen",
     ),
     AccuWeatherSensorDescription(
         key="HoursOfSun",
         icon="mdi:weather-partly-cloudy",
         name="Hours of sun",
         native_unit_of_measurement=UnitOfTime.HOURS,
-        value_fn=lambda data, _: cast(float, data),
+        value_fn=lambda data: cast(float, data),
     ),
     AccuWeatherSensorDescription(
         key="Mold",
@@ -104,16 +110,9 @@ FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Mold pollen",
         entity_registry_enabled_default=False,
         native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
-        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
-        attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
-    ),
-    AccuWeatherSensorDescription(
-        key="Ozone",
-        icon="mdi:vector-triangle",
-        name="Ozone",
-        entity_registry_enabled_default=False,
-        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        value_fn=lambda data: cast(int, data[ATTR_VALUE]),
         attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
+        translation_key="mold_pollen",
     ),
     AccuWeatherSensorDescription(
         key="Ragweed",
@@ -121,56 +120,53 @@ FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Ragweed pollen",
         native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
         entity_registry_enabled_default=False,
-        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        value_fn=lambda data: cast(int, data[ATTR_VALUE]),
         attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
+        translation_key="ragweed_pollen",
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureMax",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature max",
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureMin",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature min",
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureShadeMax",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature shade max",
         entity_registry_enabled_default=False,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureShadeMin",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature shade min",
         entity_registry_enabled_default=False,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, _: cast(float, data[ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="ThunderstormProbabilityDay",
         icon="mdi:weather-lightning",
         name="Thunderstorm probability day",
         native_unit_of_measurement=PERCENTAGE,
-        value_fn=lambda data, _: cast(int, data),
+        value_fn=lambda data: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="ThunderstormProbabilityNight",
         icon="mdi:weather-lightning",
         name="Thunderstorm probability night",
         native_unit_of_measurement=PERCENTAGE,
-        value_fn=lambda data, _: cast(int, data),
+        value_fn=lambda data: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="Tree",
@@ -178,25 +174,26 @@ FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Tree pollen",
         native_unit_of_measurement=CONCENTRATION_PARTS_PER_CUBIC_METER,
         entity_registry_enabled_default=False,
-        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        value_fn=lambda data: cast(int, data[ATTR_VALUE]),
         attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
+        translation_key="tree_pollen",
     ),
     AccuWeatherSensorDescription(
         key="UVIndex",
         icon="mdi:weather-sunny",
         name="UV index",
         native_unit_of_measurement=UV_INDEX,
-        value_fn=lambda data, _: cast(int, data[ATTR_VALUE]),
+        value_fn=lambda data: cast(int, data[ATTR_VALUE]),
         attr_fn=lambda data: {ATTR_LEVEL: data[ATTR_CATEGORY]},
+        translation_key="uv_index",
     ),
     AccuWeatherSensorDescription(
         key="WindGustDay",
         device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind gust day",
         entity_registry_enabled_default=False,
-        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
-        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
-        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        value_fn=lambda data: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
         attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
     AccuWeatherSensorDescription(
@@ -204,27 +201,24 @@ FORECAST_SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind gust night",
         entity_registry_enabled_default=False,
-        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
-        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
-        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        value_fn=lambda data: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
         attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
     AccuWeatherSensorDescription(
         key="WindDay",
         device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind day",
-        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
-        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
-        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        value_fn=lambda data: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
         attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
     AccuWeatherSensorDescription(
         key="WindNight",
         device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind night",
-        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
-        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
-        value_fn=lambda data, _: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        value_fn=lambda data: cast(float, data[ATTR_SPEED][ATTR_VALUE]),
         attr_fn=lambda data: {"direction": data[ATTR_DIRECTION][ATTR_ENGLISH]},
     ),
 )
@@ -236,9 +230,8 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Apparent temperature",
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="Ceiling",
@@ -246,9 +239,8 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         icon="mdi:weather-fog",
         name="Cloud ceiling",
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfLength.METERS,
-        us_customary_unit=UnitOfLength.FEET,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfLength.METERS,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
         suggested_display_precision=0,
     ),
     AccuWeatherSensorDescription(
@@ -258,7 +250,7 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
         native_unit_of_measurement=PERCENTAGE,
-        value_fn=lambda data, _: cast(int, data),
+        value_fn=lambda data: cast(int, data),
     ),
     AccuWeatherSensorDescription(
         key="DewPoint",
@@ -266,18 +258,16 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Dew point",
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperature",
         device_class=SensorDeviceClass.TEMPERATURE,
         name="RealFeel temperature",
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="RealFeelTemperatureShade",
@@ -285,18 +275,16 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="RealFeel temperature shade",
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="Precipitation",
         device_class=SensorDeviceClass.PRECIPITATION_INTENSITY,
         name="Precipitation",
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
-        us_customary_unit=UnitOfVolumetricFlux.INCHES_PER_HOUR,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
         attr_fn=lambda data: {"type": data["PrecipitationType"]},
     ),
     AccuWeatherSensorDescription(
@@ -306,7 +294,7 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Pressure tendency",
         options=["falling", "rising", "steady"],
         translation_key="pressure_tendency",
-        value_fn=lambda data, _: cast(str, data["LocalizedText"]).lower(),
+        value_fn=lambda data: cast(str, data["LocalizedText"]).lower(),
     ),
     AccuWeatherSensorDescription(
         key="UVIndex",
@@ -314,7 +302,7 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="UV index",
         state_class=SensorStateClass.MEASUREMENT,
         native_unit_of_measurement=UV_INDEX,
-        value_fn=lambda data, _: cast(int, data),
+        value_fn=lambda data: cast(int, data),
         attr_fn=lambda data: {ATTR_LEVEL: data["UVIndexText"]},
     ),
     AccuWeatherSensorDescription(
@@ -323,9 +311,8 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Wet bulb temperature",
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="WindChillTemperature",
@@ -333,18 +320,16 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Wind chill temperature",
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfTemperature.CELSIUS,
-        us_customary_unit=UnitOfTemperature.FAHRENHEIT,
-        value_fn=lambda data, unit: cast(float, data[unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
+        value_fn=lambda data: cast(float, data[API_METRIC][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="Wind",
         device_class=SensorDeviceClass.WIND_SPEED,
         name="Wind",
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
-        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
-        value_fn=lambda data, unit: cast(float, data[ATTR_SPEED][unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        value_fn=lambda data: cast(float, data[ATTR_SPEED][API_METRIC][ATTR_VALUE]),
     ),
     AccuWeatherSensorDescription(
         key="WindGust",
@@ -352,9 +337,8 @@ SENSOR_TYPES: tuple[AccuWeatherSensorDescription, ...] = (
         name="Wind gust",
         entity_registry_enabled_default=False,
         state_class=SensorStateClass.MEASUREMENT,
-        metric_unit=UnitOfSpeed.KILOMETERS_PER_HOUR,
-        us_customary_unit=UnitOfSpeed.MILES_PER_HOUR,
-        value_fn=lambda data, unit: cast(float, data[ATTR_SPEED][unit][ATTR_VALUE]),
+        native_unit_of_measurement=UnitOfSpeed.KILOMETERS_PER_HOUR,
+        value_fn=lambda data: cast(float, data[ATTR_SPEED][API_METRIC][ATTR_VALUE]),
     ),
 )
 
@@ -374,7 +358,7 @@ async def async_setup_entry(
         # Some air quality/allergy sensors are only available for certain
         # locations.
         sensors.extend(
-            AccuWeatherForecastSensor(coordinator, description, forecast_day=day)
+            AccuWeatherSensor(coordinator, description, forecast_day=day)
             for day in range(MAX_FORECAST_DAYS + 1)
             for description in FORECAST_SENSOR_TYPES
             if description.key in coordinator.data[ATTR_FORECAST][0]
@@ -413,34 +397,27 @@ class AccuWeatherSensor(
             self._attr_unique_id = (
                 f"{coordinator.location_key}-{description.key}".lower()
             )
-        self._attr_native_unit_of_measurement = description.native_unit_of_measurement
-        if self.coordinator.hass.config.units is METRIC_SYSTEM:
-            self._unit_system = API_METRIC
-            if metric_unit := description.metric_unit:
-                self._attr_native_unit_of_measurement = metric_unit
-        else:
-            self._unit_system = API_IMPERIAL
-            if us_customary_unit := description.us_customary_unit:
-                self._attr_native_unit_of_measurement = us_customary_unit
         self._attr_device_info = coordinator.device_info
-        if forecast_day is not None:
-            self.forecast_day = forecast_day
+        self.forecast_day = forecast_day
 
     @property
     def native_value(self) -> StateType:
         """Return the state."""
-        return self.entity_description.value_fn(self._sensor_data, self._unit_system)
+        return self.entity_description.value_fn(self._sensor_data)
 
     @property
     def extra_state_attributes(self) -> dict[str, Any]:
         """Return the state attributes."""
+        if self.forecast_day is not None:
+            return self.entity_description.attr_fn(self._sensor_data)
+
         return self.entity_description.attr_fn(self.coordinator.data)
 
     @callback
     def _handle_coordinator_update(self) -> None:
         """Handle data update."""
         self._sensor_data = _get_sensor_data(
-            self.coordinator.data, self.entity_description.key
+            self.coordinator.data, self.entity_description.key, self.forecast_day
         )
         self.async_write_ha_state()
 
@@ -458,20 +435,3 @@ def _get_sensor_data(
         return sensors["PrecipitationSummary"]["PastHour"]
 
     return sensors[kind]
-
-
-class AccuWeatherForecastSensor(AccuWeatherSensor):
-    """Define an AccuWeather forecast entity."""
-
-    @property
-    def extra_state_attributes(self) -> dict[str, Any]:
-        """Return the state attributes."""
-        return self.entity_description.attr_fn(self._sensor_data)
-
-    @callback
-    def _handle_coordinator_update(self) -> None:
-        """Handle data update."""
-        self._sensor_data = _get_sensor_data(
-            self.coordinator.data, self.entity_description.key, self.forecast_day
-        )
-        self.async_write_ha_state()
