@@ -1,7 +1,7 @@
 """Switch platform for Advantage Air integration."""
 from typing import Any
 
-from homeassistant.components.switch import SwitchEntity
+from homeassistant.components.switch import SwitchDeviceClass, SwitchEntity
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -11,7 +11,8 @@ from .const import (
     ADVANTAGE_AIR_STATE_ON,
     DOMAIN as ADVANTAGE_AIR_DOMAIN,
 )
-from .entity import AdvantageAirAcEntity
+from .entity import AdvantageAirAcEntity, AdvantageAirThingEntity
+from .models import AdvantageAirData
 
 
 async def async_setup_entry(
@@ -21,12 +22,17 @@ async def async_setup_entry(
 ) -> None:
     """Set up AdvantageAir switch platform."""
 
-    instance = hass.data[ADVANTAGE_AIR_DOMAIN][config_entry.entry_id]
+    instance: AdvantageAirData = hass.data[ADVANTAGE_AIR_DOMAIN][config_entry.entry_id]
 
-    entities = []
-    for ac_key, ac_device in instance["coordinator"].data["aircons"].items():
-        if ac_device["info"]["freshAirStatus"] != "none":
-            entities.append(AdvantageAirFreshAir(instance, ac_key))
+    entities: list[SwitchEntity] = []
+    if aircons := instance.coordinator.data.get("aircons"):
+        for ac_key, ac_device in aircons.items():
+            if ac_device["info"]["freshAirStatus"] != "none":
+                entities.append(AdvantageAirFreshAir(instance, ac_key))
+    if things := instance.coordinator.data.get("myThings"):
+        for thing in things["things"].values():
+            if thing["channelDipState"] == 8:  # 8 = Other relay
+                entities.append(AdvantageAirRelay(instance, thing))
     async_add_entities(entities)
 
 
@@ -35,25 +41,28 @@ class AdvantageAirFreshAir(AdvantageAirAcEntity, SwitchEntity):
 
     _attr_icon = "mdi:air-filter"
     _attr_name = "Fresh air"
+    _attr_device_class = SwitchDeviceClass.SWITCH
 
-    def __init__(self, instance, ac_key):
+    def __init__(self, instance: AdvantageAirData, ac_key: str) -> None:
         """Initialize an Advantage Air fresh air control."""
         super().__init__(instance, ac_key)
         self._attr_unique_id += "-freshair"
 
     @property
-    def is_on(self):
+    def is_on(self) -> bool:
         """Return the fresh air status."""
         return self._ac["freshAirStatus"] == ADVANTAGE_AIR_STATE_ON
 
     async def async_turn_on(self, **kwargs: Any) -> None:
         """Turn fresh air on."""
-        await self.async_change(
-            {self.ac_key: {"info": {"freshAirStatus": ADVANTAGE_AIR_STATE_ON}}}
-        )
+        await self.async_update_ac({"freshAirStatus": ADVANTAGE_AIR_STATE_ON})
 
     async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn fresh air off."""
-        await self.async_change(
-            {self.ac_key: {"info": {"freshAirStatus": ADVANTAGE_AIR_STATE_OFF}}}
-        )
+        await self.async_update_ac({"freshAirStatus": ADVANTAGE_AIR_STATE_OFF})
+
+
+class AdvantageAirRelay(AdvantageAirThingEntity, SwitchEntity):
+    """Representation of Advantage Air Thing."""
+
+    _attr_device_class = SwitchDeviceClass.SWITCH
