@@ -14,9 +14,8 @@ from homeassistant.components.sensor import (
 from homeassistant.const import (
     CONF_MONITORED_CONDITIONS,
     PERCENTAGE,
-    POWER_WATT,
-    TEMP_CELSIUS,
-    TEMP_FAHRENHEIT,
+    UnitOfPower,
+    UnitOfTemperature,
 )
 from homeassistant.core import HomeAssistant, callback
 import homeassistant.helpers.config_validation as cv
@@ -24,7 +23,7 @@ from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
-from . import DOMAIN, UPDATE_TOPIC
+from . import DOMAIN, UPDATE_TOPIC, AquaLogicProcessor
 
 
 @dataclass
@@ -40,23 +39,23 @@ SENSOR_TYPES: tuple[AquaLogicSensorEntityDescription, ...] = (
     AquaLogicSensorEntityDescription(
         key="air_temp",
         name="Air Temperature",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
+        unit_metric=UnitOfTemperature.CELSIUS,
+        unit_imperial=UnitOfTemperature.FAHRENHEIT,
         device_class=SensorDeviceClass.TEMPERATURE,
     ),
     AquaLogicSensorEntityDescription(
         key="pool_temp",
         name="Pool Temperature",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
+        unit_metric=UnitOfTemperature.CELSIUS,
+        unit_imperial=UnitOfTemperature.FAHRENHEIT,
         icon="mdi:oil-temperature",
         device_class=SensorDeviceClass.TEMPERATURE,
     ),
     AquaLogicSensorEntityDescription(
         key="spa_temp",
         name="Spa Temperature",
-        unit_metric=TEMP_CELSIUS,
-        unit_imperial=TEMP_FAHRENHEIT,
+        unit_metric=UnitOfTemperature.CELSIUS,
+        unit_imperial=UnitOfTemperature.FAHRENHEIT,
         icon="mdi:oil-temperature",
         device_class=SensorDeviceClass.TEMPERATURE,
     ),
@@ -91,9 +90,9 @@ SENSOR_TYPES: tuple[AquaLogicSensorEntityDescription, ...] = (
     AquaLogicSensorEntityDescription(
         key="pump_power",
         name="Pump Power",
-        unit_metric=POWER_WATT,
-        unit_imperial=POWER_WATT,
-        icon="mdi:gauge",
+        unit_metric=UnitOfPower.WATT,
+        unit_imperial=UnitOfPower.WATT,
+        device_class=SensorDeviceClass.POWER,
     ),
     AquaLogicSensorEntityDescription(
         key="status",
@@ -120,7 +119,7 @@ async def async_setup_platform(
     discovery_info: DiscoveryInfoType | None = None,
 ) -> None:
     """Set up the sensor platform."""
-    processor = hass.data[DOMAIN]
+    processor: AquaLogicProcessor = hass.data[DOMAIN]
     monitored_conditions = config[CONF_MONITORED_CONDITIONS]
 
     entities = [
@@ -138,7 +137,11 @@ class AquaLogicSensor(SensorEntity):
     entity_description: AquaLogicSensorEntityDescription
     _attr_should_poll = False
 
-    def __init__(self, processor, description: AquaLogicSensorEntityDescription):
+    def __init__(
+        self,
+        processor: AquaLogicProcessor,
+        description: AquaLogicSensorEntityDescription,
+    ) -> None:
         """Initialize sensor."""
         self.entity_description = description
         self._processor = processor
@@ -153,7 +156,7 @@ class AquaLogicSensor(SensorEntity):
         )
 
     @callback
-    def async_update_callback(self):
+    def async_update_callback(self) -> None:
         """Update callback."""
         if (panel := self._processor.panel) is not None:
             if panel.is_metric:
