@@ -13,9 +13,8 @@ from homeassistant.components.number import (
     NumberEntityDescription,
     NumberMode,
 )
-from homeassistant.const import UnitOfTime
+from homeassistant.const import EntityCategory, UnitOfTime
 from homeassistant.core import HomeAssistant, callback
-from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import DOMAIN, HALF_DAY_SECS, ONE_DAY_SECS, ONE_MIN_SECS, SPEED_RANGE
@@ -40,6 +39,7 @@ AUTO_COMFORT_NUMBER_DESCRIPTIONS = (
     BAFNumberDescription(
         key="comfort_min_speed",
         name="Auto Comfort Minimum Speed",
+        native_step=1,
         native_min_value=0,
         native_max_value=SPEED_RANGE[1] - 1,
         entity_category=EntityCategory.CONFIG,
@@ -49,6 +49,7 @@ AUTO_COMFORT_NUMBER_DESCRIPTIONS = (
     BAFNumberDescription(
         key="comfort_max_speed",
         name="Auto Comfort Maximum Speed",
+        native_step=1,
         native_min_value=1,
         native_max_value=SPEED_RANGE[1],
         entity_category=EntityCategory.CONFIG,
@@ -58,6 +59,7 @@ AUTO_COMFORT_NUMBER_DESCRIPTIONS = (
     BAFNumberDescription(
         key="comfort_heat_assist_speed",
         name="Auto Comfort Heat Assist Speed",
+        native_step=1,
         native_min_value=SPEED_RANGE[0],
         native_max_value=SPEED_RANGE[1],
         entity_category=EntityCategory.CONFIG,
@@ -70,6 +72,7 @@ FAN_NUMBER_DESCRIPTIONS = (
     BAFNumberDescription(
         key="return_to_auto_timeout",
         name="Return to Auto Timeout",
+        native_step=1,
         native_min_value=ONE_MIN_SECS,
         native_max_value=HALF_DAY_SECS,
         entity_category=EntityCategory.CONFIG,
@@ -80,6 +83,7 @@ FAN_NUMBER_DESCRIPTIONS = (
     BAFNumberDescription(
         key="motion_sense_timeout",
         name="Motion Sense Timeout",
+        native_step=1,
         native_min_value=ONE_MIN_SECS,
         native_max_value=ONE_DAY_SECS,
         entity_category=EntityCategory.CONFIG,
@@ -93,6 +97,7 @@ LIGHT_NUMBER_DESCRIPTIONS = (
     BAFNumberDescription(
         key="light_return_to_auto_timeout",
         name="Light Return to Auto Timeout",
+        native_step=1,
         native_min_value=ONE_MIN_SECS,
         native_max_value=HALF_DAY_SECS,
         entity_category=EntityCategory.CONFIG,
@@ -103,6 +108,7 @@ LIGHT_NUMBER_DESCRIPTIONS = (
     BAFNumberDescription(
         key="light_auto_motion_timeout",
         name="Light Motion Sense Timeout",
+        native_step=1,
         native_min_value=ONE_MIN_SECS,
         native_max_value=ONE_DAY_SECS,
         entity_category=EntityCategory.CONFIG,
