@@ -25,61 +25,61 @@ from .entity import BroadlinkEntity
 SENSOR_TYPES: tuple[SensorEntityDescription, ...] = (
     SensorEntityDescription(
         key="temperature",
-        name="Temperature",
+        translation_key="temperature",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="air_quality",
-        name="Air quality",
+        translation_key="air_quality",
     ),
     SensorEntityDescription(
         key="humidity",
-        name="Humidity",
+        translation_key="humidity",
         native_unit_of_measurement=PERCENTAGE,
         device_class=SensorDeviceClass.HUMIDITY,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="light",
-        name="Light",
+        translation_key="light",
     ),
     SensorEntityDescription(
         key="noise",
-        name="Noise",
+        translation_key="noise",
     ),
     SensorEntityDescription(
         key="power",
-        name="Current power",
+        translation_key="power",
         native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="volt",
-        name="Voltage",
+        translation_key="voltage",
         native_unit_of_measurement=UnitOfElectricPotential.VOLT,
         device_class=SensorDeviceClass.VOLTAGE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="current",
-        name="Current",
+        translation_key="current",
         native_unit_of_measurement=UnitOfElectricCurrent.AMPERE,
         device_class=SensorDeviceClass.CURRENT,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="overload",
-        name="Overload",
+        translation_key="overload",
         native_unit_of_measurement=UnitOfElectricCurrent.AMPERE,
         device_class=SensorDeviceClass.CURRENT,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="totalconsum",
-        name="Total consumption",
+        translation_key="total_consumption",
         native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         state_class=SensorStateClass.TOTAL_INCREASING,
@@ -114,7 +114,7 @@ class BroadlinkSensor(BroadlinkEntity, SensorEntity):
 
     _attr_has_entity_name = True
 
-    def __init__(self, device, description: SensorEntityDescription):
+    def __init__(self, device, description: SensorEntityDescription) -> None:
         """Initialize the sensor."""
         super().__init__(device)
         self.entity_description = description
