@@ -16,7 +16,7 @@ from homeassistant.const import (
     CONF_TYPE,
 )
 from homeassistant.core import CALLBACK_TYPE, HomeAssistant
-from homeassistant.helpers import config_validation as cv, entity_registry
+from homeassistant.helpers import config_validation as cv, entity_registry as er
 from homeassistant.helpers.trigger import TriggerActionType, TriggerInfo
 from homeassistant.helpers.typing import ConfigType
 
@@ -36,7 +36,7 @@ async def async_get_triggers(
     hass: HomeAssistant, device_id: str
 ) -> list[dict[str, str]]:
     """List device triggers for button devices."""
-    registry = entity_registry.async_get(hass)
+    registry = er.async_get(hass)
     return [
         {
             CONF_PLATFORM: "device",
@@ -45,7 +45,7 @@ async def async_get_triggers(
             CONF_ENTITY_ID: entry.entity_id,
             CONF_TYPE: "pressed",
         }
-        for entry in entity_registry.async_entries_for_device(registry, device_id)
+        for entry in er.async_entries_for_device(registry, device_id)
         if entry.domain == DOMAIN
     ]
 
