@@ -19,7 +19,7 @@ from homeassistant.components.websocket_api import ERR_NOT_FOUND, ERR_NOT_SUPPOR
 from homeassistant.components.websocket_api.connection import ActiveConnection
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import STATE_OFF, STATE_ON
-from homeassistant.core import HomeAssistant
+from homeassistant.core import HomeAssistant, ServiceCall
 from homeassistant.exceptions import HomeAssistantError
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.config_validation import (  # noqa: F401
@@ -37,15 +37,27 @@ from .const import (
     CONF_EVENT,
     EVENT_DESCRIPTION,
     EVENT_END,
+    EVENT_END_DATE,
+    EVENT_END_DATETIME,
+    EVENT_IN,
+    EVENT_IN_DAYS,
+    EVENT_IN_WEEKS,
+    EVENT_LOCATION,
     EVENT_RECURRENCE_ID,
     EVENT_RECURRENCE_RANGE,
     EVENT_RRULE,
     EVENT_START,
+    EVENT_START_DATE,
+    EVENT_START_DATETIME,
     EVENT_SUMMARY,
+    EVENT_TIME_FIELDS,
+    EVENT_TYPES,
     EVENT_UID,
     CalendarEntityFeature,
 )
 
+# mypy: disallow-any-generics
+
 _LOGGER = logging.getLogger(__name__)
 
 DOMAIN = "calendar"
@@ -55,8 +67,188 @@ SCAN_INTERVAL = datetime.timedelta(seconds=60)
 # Don't support rrules more often than daily
 VALID_FREQS = {"DAILY", "WEEKLY", "MONTHLY", "YEARLY"}
 
+# Ensure events created in Home Assistant have a positive duration
+MIN_NEW_EVENT_DURATION = datetime.timedelta(seconds=1)
 
-# mypy: disallow-any-generics
+# Events must have a non-negative duration e.g. Google Calendar can create zero
+# duration events in the UI.
+MIN_EVENT_DURATION = datetime.timedelta(seconds=0)
+
+
+def _has_timezone(*keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
+    """Assert that all datetime values have a timezone."""
+
+    def validate(obj: dict[str, Any]) -> dict[str, Any]:
+        """Validate that all datetime values have a timezone."""
+        for k in keys:
+            if (
+                (value := obj.get(k))
+                and isinstance(value, datetime.datetime)
+                and value.tzinfo is None
+            ):
+                raise vol.Invalid("Expected all values to have a timezone")
+        return obj
+
+    return validate
+
+
+def _has_consistent_timezone(*keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
+    """Verify that all datetime values have a consistent timezone."""
+
+    def validate(obj: dict[str, Any]) -> dict[str, Any]:
+        """Test that all keys that are datetime values have the same timezone."""
+        tzinfos = []
+        for key in keys:
+            if not (value := obj.get(key)) or not isinstance(value, datetime.datetime):
+                return obj
+            tzinfos.append(value.tzinfo)
+        uniq_values = groupby(tzinfos)
+        if len(list(uniq_values)) > 1:
+            raise vol.Invalid("Expected all values to have the same timezone")
+        return obj
+
+    return validate
+
+
+def _as_local_timezone(*keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
+    """Convert all datetime values to the local timezone."""
+
+    def validate(obj: dict[str, Any]) -> dict[str, Any]:
+        """Convert all keys that are datetime values to local timezone."""
+        for k in keys:
+            if (value := obj.get(k)) and isinstance(value, datetime.datetime):
+                obj[k] = dt.as_local(value)
+        return obj
+
+    return validate
+
+
+def _has_min_duration(
+    start_key: str, end_key: str, min_duration: datetime.timedelta
+) -> Callable[[dict[str, Any]], dict[str, Any]]:
+    """Verify that the time span between start and end has a minimum duration."""
+
+    def validate(obj: dict[str, Any]) -> dict[str, Any]:
+        if (start := obj.get(start_key)) and (end := obj.get(end_key)):
+            duration = end - start
+            if duration < min_duration:
+                raise vol.Invalid(
+                    f"Expected minimum event duration of {min_duration} ({start}, {end})"
+                )
+        return obj
+
+    return validate
+
+
+def _has_same_type(*keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
+    """Verify that all values are of the same type."""
+
+    def validate(obj: dict[str, Any]) -> dict[str, Any]:
+        """Test that all keys in the dict have values of the same type."""
+        uniq_values = groupby(type(obj[k]) for k in keys)
+        if len(list(uniq_values)) > 1:
+            raise vol.Invalid(f"Expected all values to be the same type: {keys}")
+        return obj
+
+    return validate
+
+
+def _validate_rrule(value: Any) -> str:
+    """Validate a recurrence rule string."""
+    if value is None:
+        raise vol.Invalid("rrule value is None")
+
+    if not isinstance(value, str):
+        raise vol.Invalid("rrule value expected a string")
+
+    try:
+        rrulestr(value)
+    except ValueError as err:
+        raise vol.Invalid(f"Invalid rrule '{value}': {err}") from err
+
+    # Example format: FREQ=DAILY;UNTIL=...
+    rule_parts = dict(s.split("=", 1) for s in value.split(";"))
+    if not (freq := rule_parts.get("FREQ")):
+        raise vol.Invalid("rrule did not contain FREQ")
+
+    if freq not in VALID_FREQS:
+        raise vol.Invalid(f"Invalid frequency for rule: {value}")
+
+    return str(value)
+
+
+CREATE_EVENT_SERVICE = "create_event"
+CREATE_EVENT_SCHEMA = vol.All(
+    cv.has_at_least_one_key(EVENT_START_DATE, EVENT_START_DATETIME, EVENT_IN),
+    cv.has_at_most_one_key(EVENT_START_DATE, EVENT_START_DATETIME, EVENT_IN),
+    cv.make_entity_service_schema(
+        {
+            vol.Required(EVENT_SUMMARY): cv.string,
+            vol.Optional(EVENT_DESCRIPTION, default=""): cv.string,
+            vol.Optional(EVENT_LOCATION): cv.string,
+            vol.Inclusive(
+                EVENT_START_DATE, "dates", "Start and end dates must both be specified"
+            ): cv.date,
+            vol.Inclusive(
+                EVENT_END_DATE, "dates", "Start and end dates must both be specified"
+            ): cv.date,
+            vol.Inclusive(
+                EVENT_START_DATETIME,
+                "datetimes",
+                "Start and end datetimes must both be specified",
+            ): cv.datetime,
+            vol.Inclusive(
+                EVENT_END_DATETIME,
+                "datetimes",
+                "Start and end datetimes must both be specified",
+            ): cv.datetime,
+            vol.Optional(EVENT_IN): vol.Schema(
+                {
+                    vol.Exclusive(EVENT_IN_DAYS, EVENT_TYPES): cv.positive_int,
+                    vol.Exclusive(EVENT_IN_WEEKS, EVENT_TYPES): cv.positive_int,
+                }
+            ),
+        },
+    ),
+    _has_consistent_timezone(EVENT_START_DATETIME, EVENT_END_DATETIME),
+    _as_local_timezone(EVENT_START_DATETIME, EVENT_END_DATETIME),
+    _has_min_duration(EVENT_START_DATE, EVENT_END_DATE, MIN_NEW_EVENT_DURATION),
+    _has_min_duration(EVENT_START_DATETIME, EVENT_END_DATETIME, MIN_NEW_EVENT_DURATION),
+)
+
+WEBSOCKET_EVENT_SCHEMA = vol.Schema(
+    vol.All(
+        {
+            vol.Required(EVENT_START): vol.Any(cv.date, cv.datetime),
+            vol.Required(EVENT_END): vol.Any(cv.date, cv.datetime),
+            vol.Required(EVENT_SUMMARY): cv.string,
+            vol.Optional(EVENT_DESCRIPTION): cv.string,
+            vol.Optional(EVENT_LOCATION): cv.string,
+            vol.Optional(EVENT_RRULE): _validate_rrule,
+        },
+        _has_same_type(EVENT_START, EVENT_END),
+        _has_consistent_timezone(EVENT_START, EVENT_END),
+        _as_local_timezone(EVENT_START, EVENT_END),
+        _has_min_duration(EVENT_START, EVENT_END, MIN_NEW_EVENT_DURATION),
+    )
+)
+
+# Validation for the CalendarEvent dataclass
+CALENDAR_EVENT_SCHEMA = vol.Schema(
+    vol.All(
+        {
+            vol.Required("start"): vol.Any(cv.date, cv.datetime),
+            vol.Required("end"): vol.Any(cv.date, cv.datetime),
+            vol.Required(EVENT_SUMMARY): cv.string,
+            vol.Optional(EVENT_RRULE): _validate_rrule,
+        },
+        _has_same_type("start", "end"),
+        _has_timezone("start", "end"),
+        _as_local_timezone("start", "end"),
+        _has_min_duration("start", "end", MIN_EVENT_DURATION),
+    ),
+    extra=vol.ALLOW_EXTRA,
+)
 
 
 async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
@@ -76,6 +268,13 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     websocket_api.async_register_command(hass, handle_calendar_event_delete)
     websocket_api.async_register_command(hass, handle_calendar_event_update)
 
+    component.async_register_entity_service(
+        CREATE_EVENT_SERVICE,
+        CREATE_EVENT_SCHEMA,
+        async_create_event,
+        required_features=[CalendarEntityFeature.CREATE_EVENT],
+    )
+
     await component.async_setup(config)
     return True
 
@@ -141,6 +340,29 @@ class CalendarEvent:
             "all_day": self.all_day,
         }
 
+    def __post_init__(self) -> None:
+        """Perform validation on the CalendarEvent."""
+
+        def skip_none(obj: Iterable[tuple[str, Any]]) -> dict[str, str]:
+            return {k: v for k, v in obj if v is not None}
+
+        try:
+            CALENDAR_EVENT_SCHEMA(dataclasses.asdict(self, dict_factory=skip_none))
+        except vol.Invalid as err:
+            raise HomeAssistantError(
+                f"Failed to validate CalendarEvent: {err}"
+            ) from err
+
+        # It is common to set a start an end date to be the same thing for
+        # an all day event, but that is not a valid duration. Fix to have a
+        # duration of one day.
+        if (
+            not isinstance(self.start, datetime.datetime)
+            and not isinstance(self.end, datetime.datetime)
+            and self.start == self.end
+        ):
+            self.end = self.start + datetime.timedelta(days=1)
+
 
 def _event_dict_factory(obj: Iterable[tuple[str, Any]]) -> dict[str, str]:
     """Convert CalendarEvent dataclass items to dictionary of attributes."""
@@ -214,30 +436,6 @@ def is_offset_reached(
     return start + offset_time <= dt.now(start.tzinfo)
 
 
-def _validate_rrule(value: Any) -> str:
-    """Validate a recurrence rule string."""
-    if value is None:
-        raise vol.Invalid("rrule value is None")
-
-    if not isinstance(value, str):
-        raise vol.Invalid("rrule value expected a string")
-
-    try:
-        rrulestr(value)
-    except ValueError as err:
-        raise vol.Invalid(f"Invalid rrule: {str(err)}") from err
-
-    # Example format: FREQ=DAILY;UNTIL=...
-    rule_parts = dict(s.split("=", 1) for s in value.split(";"))
-    if not (freq := rule_parts.get("FREQ")):
-        raise vol.Invalid("rrule did not contain FREQ")
-
-    if freq not in VALID_FREQS:
-        raise vol.Invalid(f"Invalid frequency for rule: {value}")
-
-    return str(value)
-
-
 class CalendarEntity(Entity):
     """Base class for calendar event entities."""
 
@@ -337,12 +535,15 @@ class CalendarEventView(http.HomeAssistantView):
             return web.Response(status=HTTPStatus.BAD_REQUEST)
         if start_date is None or end_date is None:
             return web.Response(status=HTTPStatus.BAD_REQUEST)
+        if start_date > end_date:
+            return web.Response(status=HTTPStatus.BAD_REQUEST)
 
         try:
             calendar_event_list = await entity.async_get_events(
-                request.app["hass"], start_date, end_date
+                request.app["hass"], dt.as_local(start_date), dt.as_local(end_date)
             )
         except HomeAssistantError as err:
+            _LOGGER.debug("Error reading events: %s", err)
             return self.json_message(
                 f"Error reading events: {err}", HTTPStatus.INTERNAL_SERVER_ERROR
             )
@@ -377,67 +578,11 @@ class CalendarListView(http.HomeAssistantView):
         return self.json(sorted(calendar_list, key=lambda x: cast(str, x["name"])))
 
 
-def _has_same_type(*keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
-    """Verify that all values are of the same type."""
-
-    def validate(obj: dict[str, Any]) -> dict[str, Any]:
-        """Test that all keys in the dict have values of the same type."""
-        uniq_values = groupby(type(obj[k]) for k in keys)
-        if len(list(uniq_values)) > 1:
-            raise vol.Invalid(f"Expected all values to be the same type: {keys}")
-        return obj
-
-    return validate
-
-
-def _has_consistent_timezone(*keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
-    """Verify that all datetime values have a consistent timezone."""
-
-    def validate(obj: dict[str, Any]) -> dict[str, Any]:
-        """Test that all keys that are datetime values have the same timezone."""
-        values = [obj[k] for k in keys]
-        if all(isinstance(value, datetime.datetime) for value in values):
-            uniq_values = groupby(value.tzinfo for value in values)
-            if len(list(uniq_values)) > 1:
-                raise vol.Invalid(
-                    f"Expected all values to have the same timezone: {values}"
-                )
-        return obj
-
-    return validate
-
-
-def _is_sorted(*keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
-    """Verify that the specified values are sequential."""
-
-    def validate(obj: dict[str, Any]) -> dict[str, Any]:
-        """Test that all keys in the dict are in order."""
-        values = [obj[k] for k in keys]
-        if values != sorted(values):
-            raise vol.Invalid(f"Values were not in order: {values}")
-        return obj
-
-    return validate
-
-
 @websocket_api.websocket_command(
     {
         vol.Required("type"): "calendar/event/create",
         vol.Required("entity_id"): cv.entity_id,
-        CONF_EVENT: vol.Schema(
-            vol.All(
-                {
-                    vol.Required(EVENT_START): vol.Any(cv.date, cv.datetime),
-                    vol.Required(EVENT_END): vol.Any(cv.date, cv.datetime),
-                    vol.Required(EVENT_SUMMARY): cv.string,
-                    vol.Optional(EVENT_DESCRIPTION): cv.string,
-                    vol.Optional(EVENT_RRULE): _validate_rrule,
-                },
-                _has_same_type(EVENT_START, EVENT_END),
-                _has_consistent_timezone(EVENT_START, EVENT_END),
-                _is_sorted(EVENT_START, EVENT_END),
-            )
-        ),
+        CONF_EVENT: WEBSOCKET_EVENT_SCHEMA,
     }
 )
 @websocket_api.async_response
@@ -520,20 +665,7 @@ async def handle_calendar_event_delete(
         vol.Required(EVENT_UID): cv.string,
         vol.Optional(EVENT_RECURRENCE_ID): cv.string,
         vol.Optional(EVENT_RECURRENCE_RANGE): cv.string,
-        vol.Required(CONF_EVENT): vol.Schema(
-            vol.All(
-                {
-                    vol.Required(EVENT_START): vol.Any(cv.date, cv.datetime),
-                    vol.Required(EVENT_END): vol.Any(cv.date, cv.datetime),
-                    vol.Required(EVENT_SUMMARY): cv.string,
-                    vol.Optional(EVENT_DESCRIPTION): cv.string,
-                    vol.Optional(EVENT_RRULE): _validate_rrule,
-                },
-                _has_same_type(EVENT_START, EVENT_END),
-                _has_consistent_timezone(EVENT_START, EVENT_END),
-                _is_sorted(EVENT_START, EVENT_END),
-            )
-        ),
+        vol.Required(CONF_EVENT): WEBSOCKET_EVENT_SCHEMA,
     }
 )
 @websocket_api.async_response
@@ -569,3 +701,43 @@ async def handle_calendar_event_update(
         connection.send_error(msg["id"], "failed", str(ex))
     else:
         connection.send_result(msg["id"])
+
+
+def _validate_timespan(
+    values: dict[str, Any]
+) -> tuple[datetime.datetime | datetime.date, datetime.datetime | datetime.date]:
+    """Parse a create event service call and convert the args ofr a create event entity call.
+
+    This converts the input service arguments into a `start` and `end` date or date time. This
+    exists because service calls use `start_date` and `start_date_time` whereas the
+    normal entity methods can take either a `datetim` or `date` as a single `start` argument.
+    It also handles the other service call variations like "in days" as well.
+    """
+
+    if event_in := values.get(EVENT_IN):
+        days = event_in.get(EVENT_IN_DAYS, 7 * event_in.get(EVENT_IN_WEEKS, 0))
+        today = datetime.date.today()
+        return (
+            today + datetime.timedelta(days=days),
+            today + datetime.timedelta(days=days + 1),
+        )
+
+    if EVENT_START_DATE in values and EVENT_END_DATE in values:
+        return (values[EVENT_START_DATE], values[EVENT_END_DATE])
+
+    if EVENT_START_DATETIME in values and EVENT_END_DATETIME in values:
+        return (values[EVENT_START_DATETIME], values[EVENT_END_DATETIME])
+
+    raise ValueError("Missing required fields to set start or end date/datetime")
+
+
+async def async_create_event(entity: CalendarEntity, call: ServiceCall) -> None:
+    """Add a new event to calendar."""
+    # Convert parameters to format used by async_create_event
+    (start, end) = _validate_timespan(call.data)
+    params = {
+        **{k: v for k, v in call.data.items() if k not in EVENT_TIME_FIELDS},
+        EVENT_START: start,
+        EVENT_END: end,
+    }
+    await entity.async_create_event(**params)
