@@ -5,7 +5,7 @@ from collections.abc import AsyncIterable
 import logging
 
 from hass_nabucasa import Cloud
-from hass_nabucasa.voice import VoiceError
+from hass_nabucasa.voice import STT_LANGUAGES, VoiceError
 
 from homeassistant.components.stt import (
     AudioBitRates,
@@ -23,35 +23,15 @@ from .const import DOMAIN
 
 _LOGGER = logging.getLogger(__name__)
 
-SUPPORT_LANGUAGES = [
-    "da-DK",
-    "de-DE",
-    "en-AU",
-    "en-CA",
-    "en-GB",
-    "en-US",
-    "es-ES",
-    "fi-FI",
-    "fr-CA",
-    "fr-FR",
-    "it-IT",
-    "ja-JP",
-    "nl-NL",
-    "pl-PL",
-    "pt-PT",
-    "ru-RU",
-    "sv-SE",
-    "th-TH",
-    "zh-CN",
-    "zh-HK",
-]
-
 
 async def async_get_engine(hass, config, discovery_info=None):
     """Set up Cloud speech component."""
     cloud: Cloud = hass.data[DOMAIN]
 
-    return CloudProvider(cloud)
+    cloud_provider = CloudProvider(cloud)
+    if discovery_info is not None:
+        discovery_info["platform_loaded"].set()
+    return cloud_provider
 
 
 class CloudProvider(Provider):
@@ -64,7 +44,7 @@ class CloudProvider(Provider):
     @property
     def supported_languages(self) -> list[str]:
         """Return a list of supported languages."""
-        return SUPPORT_LANGUAGES
+        return STT_LANGUAGES
 
     @property
     def supported_formats(self) -> list[AudioFormats]:
@@ -95,7 +75,7 @@ class CloudProvider(Provider):
         self, metadata: SpeechMetadata, stream: AsyncIterable[bytes]
     ) -> SpeechResult:
         """Process an audio stream to STT service."""
-        content = (
+        content_type = (
             f"audio/{metadata.format!s}; codecs=audio/{metadata.codec!s};"
             " samplerate=16000"
         )
@@ -103,10 +83,12 @@ class CloudProvider(Provider):
         # Process STT
         try:
             result = await self.cloud.voice.process_stt(
-                stream, content, metadata.language
+                stream=stream,
+                content_type=content_type,
+                language=metadata.language,
             )
         except VoiceError as err:
-            _LOGGER.debug("Voice error: %s", err)
+            _LOGGER.error("Voice error: %s", err)
             return SpeechResult(None, SpeechResultState.ERROR)
 
         # Return Speech as Text
