@@ -535,8 +535,8 @@ def entry_json(entry: config_entries.ConfigEntry) -> dict:
         "source": entry.source,
         "state": entry.state.value,
         "supports_options": supports_options,
-        "supports_remove_device": entry.supports_remove_device,
-        "supports_unload": entry.supports_unload,
+        "supports_remove_device": entry.supports_remove_device or False,
+        "supports_unload": entry.supports_unload or False,
         "pref_disable_new_entities": entry.pref_disable_new_entities,
         "pref_disable_polling": entry.pref_disable_polling,
         "disabled_by": entry.disabled_by,
