@@ -24,7 +24,7 @@ from homeassistant.helpers.update_coordinator import DataUpdateCoordinator, Upda
 
 from . import Control4Entity, get_items_of_category
 from .const import CONF_DIRECTOR, CONTROL4_ENTITY_TYPE, DOMAIN
-from .director_utils import director_update_data
+from .director_utils import update_variables_for_config_entry
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -47,14 +47,18 @@ async def async_setup_entry(
     async def async_update_data_non_dimmer():
         """Fetch data from Control4 director for non-dimmer lights."""
         try:
-            return await director_update_data(hass, entry, CONTROL4_NON_DIMMER_VAR)
+            return await update_variables_for_config_entry(
+                hass, entry, {CONTROL4_NON_DIMMER_VAR}
+            )
         except C4Exception as err:
             raise UpdateFailed(f"Error communicating with API: {err}") from err
 
     async def async_update_data_dimmer():
         """Fetch data from Control4 director for dimmer lights."""
         try:
-            return await director_update_data(hass, entry, CONTROL4_DIMMER_VAR)
+            return await update_variables_for_config_entry(
+                hass, entry, {CONTROL4_DIMMER_VAR}
+            )
         except C4Exception as err:
             raise UpdateFailed(f"Error communicating with API: {err}") from err
 
@@ -175,7 +179,7 @@ class Control4Light(Control4Entity, LightEntity):
             self._attr_color_mode = ColorMode.ONOFF
             self._attr_supported_color_modes = {ColorMode.ONOFF}
 
-    def create_api_object(self):
+    def _create_api_object(self):
         """Create a pyControl4 device object.
 
         This exists so the director token used is always the latest one, without needing to re-init the entire entity.
@@ -185,13 +189,15 @@ class Control4Light(Control4Entity, LightEntity):
     @property
     def is_on(self):
         """Return whether this light is on or off."""
-        return self.coordinator.data[self._idx]["value"] > 0
+        if self._is_dimmer:
+            return self.coordinator.data[self._idx][CONTROL4_DIMMER_VAR] > 0
+        return self.coordinator.data[self._idx][CONTROL4_NON_DIMMER_VAR] > 0
 
     @property
     def brightness(self):
         """Return the brightness of this light between 0..255."""
         if self._is_dimmer:
-            return round(self.coordinator.data[self._idx]["value"] * 2.55)
+            return round(self.coordinator.data[self._idx][CONTROL4_DIMMER_VAR] * 2.55)
         return None
 
     @property
@@ -203,7 +209,7 @@ class Control4Light(Control4Entity, LightEntity):
 
     async def async_turn_on(self, **kwargs: Any) -> None:
         """Turn the entity on."""
-        c4_light = self.create_api_object()
+        c4_light = self._create_api_object()
         if self._is_dimmer:
             if ATTR_TRANSITION in kwargs:
                 transition_length = kwargs[ATTR_TRANSITION] * 1000
@@ -226,7 +232,7 @@ class Control4Light(Control4Entity, LightEntity):
 
     async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn the entity off."""
-        c4_light = self.create_api_object()
+        c4_light = self._create_api_object()
         if self._is_dimmer:
             if ATTR_TRANSITION in kwargs:
                 transition_length = kwargs[ATTR_TRANSITION] * 1000
