@@ -3,13 +3,13 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-from typing import Any, TypedDict
+from typing import Any, Literal, TypedDict
 
 from homeassistant.core import Context
 from homeassistant.helpers import intent
 
 
-@dataclass
+@dataclass(slots=True)
 class ConversationInput:
     """User input to be processed."""
 
@@ -19,7 +19,7 @@ class ConversationInput:
     language: str
 
 
-@dataclass
+@dataclass(slots=True)
 class ConversationResult:
     """Result of async_process."""
 
@@ -49,6 +49,11 @@ class AbstractConversationAgent(ABC):
         """Return the attribution."""
         return None
 
+    @property
+    @abstractmethod
+    def supported_languages(self) -> list[str] | Literal["*"]:
+        """Return a list of supported languages."""
+
     @abstractmethod
     async def async_process(self, user_input: ConversationInput) -> ConversationResult:
         """Process a sentence."""
