@@ -25,6 +25,7 @@ from aioesphomeapi import (
     NumberInfo,
     SelectInfo,
     SensorInfo,
+    SensorState,
     SwitchInfo,
     TextSensorInfo,
     UserService,
@@ -99,6 +100,10 @@ class RuntimeEntryData:
     _ble_connection_free_futures: list[asyncio.Future[int]] = field(
         default_factory=list
     )
+    assist_pipeline_update_callbacks: list[Callable[[], None]] = field(
+        default_factory=list
+    )
+    assist_pipeline_state: bool = False
 
     @property
     def name(self) -> str:
@@ -153,6 +158,24 @@ class RuntimeEntryData:
         self._ble_connection_free_futures.append(fut)
         return await fut
 
+    @callback
+    def async_set_assist_pipeline_state(self, state: bool) -> None:
+        """Set the assist pipeline state."""
+        self.assist_pipeline_state = state
+        for update_callback in self.assist_pipeline_update_callbacks:
+            update_callback()
+
+    def async_subscribe_assist_pipeline_update(
+        self, update_callback: Callable[[], None]
+    ) -> Callable[[], None]:
+        """Subscribe to assist pipeline updates."""
+
+        def _unsubscribe() -> None:
+            self.assist_pipeline_update_callbacks.remove(update_callback)
+
+        self.assist_pipeline_update_callbacks.append(update_callback)
+        return _unsubscribe
+
     @callback
     def async_remove_entity(
         self, hass: HomeAssistant, component_key: str, key: int
@@ -180,6 +203,10 @@ class RuntimeEntryData:
         if async_get_dashboard(hass):
             needed_platforms.add(Platform.UPDATE)
 
+        if self.device_info is not None and self.device_info.voice_assistant_version:
+            needed_platforms.add(Platform.BINARY_SENSOR)
+            needed_platforms.add(Platform.SELECT)
+
         for info in infos:
             for info_type, platform in INFO_TYPE_TO_PLATFORM.items():
                 if isinstance(info, info_type):
@@ -214,9 +241,18 @@ class RuntimeEntryData:
         current_state_by_type = self.state[state_type]
         current_state = current_state_by_type.get(key, _SENTINEL)
         subscription_key = (state_type, key)
-        if current_state == state and subscription_key not in stale_state:
+        if (
+            current_state == state
+            and subscription_key not in stale_state
+            and not (
+                type(state) is SensorState  # pylint: disable=unidiomatic-typecheck
+                and (platform_info := self.info.get(Platform.SENSOR))
+                and (entity_info := platform_info.get(state.key))
+                and (cast(SensorInfo, entity_info)).force_update
+            )
+        ):
             _LOGGER.debug(
-                "%s: ignoring duplicate update with and key %s: %s",
+                "%s: ignoring duplicate update with key %s: %s",
                 self.name,
                 key,
                 state,
