@@ -10,6 +10,9 @@ ATTR_HOME = "HOME_MODE"
 ATTR_AWAY = "AWAY_MODE"
 ATTR_TYPE_CLOUD = "EZVIZ_CLOUD_ACCOUNT"
 ATTR_TYPE_CAMERA = "CAMERA_ACCOUNT"
+CONF_SESSION_ID = "session_id"
+CONF_RFSESSION_ID = "rf_session_id"
+CONF_EZVIZ_ACCOUNT = "ezviz_account"
 
 # Services data
 DIR_UP = "up"
@@ -33,10 +36,8 @@ SERVICE_DETECTION_SENSITIVITY = "set_alarm_detection_sensibility"
 EU_URL = "apiieu.ezvizlife.com"
 RUSSIA_URL = "apirus.ezvizru.com"
 DEFAULT_CAMERA_USERNAME = "admin"
-DEFAULT_RTSP_PORT = 554
 DEFAULT_TIMEOUT = 25
 DEFAULT_FFMPEG_ARGUMENTS = ""
 
 # Data
 DATA_COORDINATOR = "coordinator"
-DATA_UNDO_UPDATE_LISTENER = "undo_update_listener"
