@@ -3,12 +3,14 @@
 from datetime import timedelta
 import logging
 
+from aiohttp import ClientTimeout
+
 DOMAIN = "life360"
 LOGGER = logging.getLogger(__package__)
 
 ATTRIBUTION = "Data provided by life360.com"
-COMM_MAX_RETRIES = 2
-COMM_TIMEOUT = 3.05
+COMM_MAX_RETRIES = 3
+COMM_TIMEOUT = ClientTimeout(sock_connect=15, total=60)
 SPEED_FACTOR_MPH = 2.25
 SPEED_DIGITS = 1
 UPDATE_INTERVAL = timedelta(seconds=10)
