@@ -1,7 +1,6 @@
 """Support for manual alarms."""
 from __future__ import annotations
 
-import copy
 import datetime
 import logging
 import re
@@ -30,9 +29,10 @@ from homeassistant.const import (
     STATE_ALARM_TRIGGERED,
 )
 from homeassistant.core import HomeAssistant, callback
+from homeassistant.exceptions import HomeAssistantError
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.event import track_point_in_time
+from homeassistant.helpers.event import async_track_point_in_time
 from homeassistant.helpers.restore_state import RestoreEntity
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 import homeassistant.util.dt as dt_util
@@ -74,15 +74,16 @@ ATTR_NEXT_STATE = "next_state"
 
 def _state_validator(config):
     """Validate the state."""
-    config = copy.deepcopy(config)
     for state in SUPPORTED_PRETRIGGER_STATES:
         if CONF_DELAY_TIME not in config[state]:
-            config[state][CONF_DELAY_TIME] = config[CONF_DELAY_TIME]
+            config[state] = config[state] | {CONF_DELAY_TIME: config[CONF_DELAY_TIME]}
         if CONF_TRIGGER_TIME not in config[state]:
-            config[state][CONF_TRIGGER_TIME] = config[CONF_TRIGGER_TIME]
+            config[state] = config[state] | {
+                CONF_TRIGGER_TIME: config[CONF_TRIGGER_TIME]
+            }
     for state in SUPPORTED_ARMING_STATES:
         if CONF_ARMING_TIME not in config[state]:
-            config[state][CONF_ARMING_TIME] = config[CONF_ARMING_TIME]
+            config[state] = config[state] | {CONF_ARMING_TIME: config[CONF_ARMING_TIME]}
 
     return config
 
@@ -174,8 +175,7 @@ def setup_platform(
 
 
 class ManualAlarm(alarm.AlarmControlPanelEntity, RestoreEntity):
-    """
-    Representation of an alarm status.
+    """Representation of an alarm status.
 
     When armed, will be arming for 'arming_time', after that armed.
     When triggered, will be pending for the triggering state's 'delay_time'.
@@ -284,72 +284,49 @@ class ManualAlarm(alarm.AlarmControlPanelEntity, RestoreEntity):
             return alarm.CodeFormat.NUMBER
         return alarm.CodeFormat.TEXT
 
-    def alarm_disarm(self, code: str | None = None) -> None:
+    async def async_alarm_disarm(self, code: str | None = None) -> None:
         """Send disarm command."""
-        if not self._validate_code(code, STATE_ALARM_DISARMED):
-            return
-
+        self._async_validate_code(code, STATE_ALARM_DISARMED)
         self._state = STATE_ALARM_DISARMED
         self._state_ts = dt_util.utcnow()
-        self.schedule_update_ha_state()
+        self.async_write_ha_state()
 
-    def alarm_arm_home(self, code: str | None = None) -> None:
+    async def async_alarm_arm_home(self, code: str | None = None) -> None:
         """Send arm home command."""
-        if self.code_arm_required and not self._validate_code(
-            code, STATE_ALARM_ARMED_HOME
-        ):
-            return
+        self._async_validate_code(code, STATE_ALARM_ARMED_HOME)
+        self._async_update_state(STATE_ALARM_ARMED_HOME)
 
-        self._update_state(STATE_ALARM_ARMED_HOME)
-
-    def alarm_arm_away(self, code: str | None = None) -> None:
+    async def async_alarm_arm_away(self, code: str | None = None) -> None:
         """Send arm away command."""
-        if self.code_arm_required and not self._validate_code(
-            code, STATE_ALARM_ARMED_AWAY
-        ):
-            return
+        self._async_validate_code(code, STATE_ALARM_ARMED_AWAY)
+        self._async_update_state(STATE_ALARM_ARMED_AWAY)
 
-        self._update_state(STATE_ALARM_ARMED_AWAY)
-
-    def alarm_arm_night(self, code: str | None = None) -> None:
+    async def async_alarm_arm_night(self, code: str | None = None) -> None:
         """Send arm night command."""
-        if self.code_arm_required and not self._validate_code(
-            code, STATE_ALARM_ARMED_NIGHT
-        ):
-            return
+        self._async_validate_code(code, STATE_ALARM_ARMED_NIGHT)
+        self._async_update_state(STATE_ALARM_ARMED_NIGHT)
 
-        self._update_state(STATE_ALARM_ARMED_NIGHT)
-
-    def alarm_arm_vacation(self, code: str | None = None) -> None:
+    async def async_alarm_arm_vacation(self, code: str | None = None) -> None:
         """Send arm vacation command."""
-        if self.code_arm_required and not self._validate_code(
-            code, STATE_ALARM_ARMED_VACATION
-        ):
-            return
+        self._async_validate_code(code, STATE_ALARM_ARMED_VACATION)
+        self._async_update_state(STATE_ALARM_ARMED_VACATION)
 
-        self._update_state(STATE_ALARM_ARMED_VACATION)
-
-    def alarm_arm_custom_bypass(self, code: str | None = None) -> None:
+    async def async_alarm_arm_custom_bypass(self, code: str | None = None) -> None:
         """Send arm custom bypass command."""
-        if self.code_arm_required and not self._validate_code(
-            code, STATE_ALARM_ARMED_CUSTOM_BYPASS
-        ):
-            return
+        self._async_validate_code(code, STATE_ALARM_ARMED_CUSTOM_BYPASS)
+        self._async_update_state(STATE_ALARM_ARMED_CUSTOM_BYPASS)
 
-        self._update_state(STATE_ALARM_ARMED_CUSTOM_BYPASS)
-
-    def alarm_trigger(self, code: str | None = None) -> None:
-        """
-        Send alarm trigger command.
+    async def async_alarm_trigger(self, code: str | None = None) -> None:
+        """Send alarm trigger command.
 
         No code needed, a trigger time of zero for the current state
         disables the alarm.
         """
         if not self._trigger_time_by_state[self._active_state]:
             return
-        self._update_state(STATE_ALARM_TRIGGERED)
+        self._async_update_state(STATE_ALARM_TRIGGERED)
 
-    def _update_state(self, state: str) -> None:
+    def _async_update_state(self, state: str) -> None:
         """Update the state."""
         if self._state == state:
             return
@@ -357,16 +334,19 @@ class ManualAlarm(alarm.AlarmControlPanelEntity, RestoreEntity):
         self._previous_state = self._state
         self._state = state
         self._state_ts = dt_util.utcnow()
-        self.schedule_update_ha_state()
+        self.async_write_ha_state()
+        self._async_set_state_update_events()
 
+    def _async_set_state_update_events(self) -> None:
+        state = self._state
         if state == STATE_ALARM_TRIGGERED:
             pending_time = self._pending_time(state)
-            track_point_in_time(
+            async_track_point_in_time(
                 self._hass, self.async_scheduled_update, self._state_ts + pending_time
             )
 
             trigger_time = self._trigger_time_by_state[self._previous_state]
-            track_point_in_time(
+            async_track_point_in_time(
                 self._hass,
                 self.async_scheduled_update,
                 self._state_ts + pending_time + trigger_time,
@@ -374,26 +354,30 @@ class ManualAlarm(alarm.AlarmControlPanelEntity, RestoreEntity):
         elif state in SUPPORTED_ARMING_STATES:
             arming_time = self._arming_time(state)
             if arming_time:
-                track_point_in_time(
+                async_track_point_in_time(
                     self._hass,
                     self.async_scheduled_update,
                     self._state_ts + arming_time,
                 )
 
-    def _validate_code(self, code, state):
+    def _async_validate_code(self, code, state):
         """Validate given code."""
-        if self._code is None:
-            return True
+        if (
+            state != STATE_ALARM_DISARMED and not self.code_arm_required
+        ) or self._code is None:
+            return
+
         if isinstance(self._code, str):
             alarm_code = self._code
         else:
-            alarm_code = self._code.render(
+            alarm_code = self._code.async_render(
                 parse_result=False, from_state=self._state, to_state=state
             )
-        check = not alarm_code or code == alarm_code
-        if not check:
-            _LOGGER.warning("Invalid code given for %s", state)
-        return check
+
+        if not alarm_code or code == alarm_code:
+            return
+
+        raise HomeAssistantError("Invalid alarm code provided")
 
     @property
     def extra_state_attributes(self) -> dict[str, Any]:
@@ -403,6 +387,10 @@ class ManualAlarm(alarm.AlarmControlPanelEntity, RestoreEntity):
                 ATTR_PREVIOUS_STATE: self._previous_state,
                 ATTR_NEXT_STATE: self._state,
             }
+        if self.state == STATE_ALARM_TRIGGERED:
+            return {
+                ATTR_PREVIOUS_STATE: self._previous_state,
+            }
         return {}
 
     @callback
@@ -414,14 +402,14 @@ class ManualAlarm(alarm.AlarmControlPanelEntity, RestoreEntity):
         """Run when entity about to be added to hass."""
         await super().async_added_to_hass()
         if state := await self.async_get_last_state():
-            if (
-                state.state in (STATE_ALARM_PENDING, STATE_ALARM_ARMING)
-                and hasattr(state, "attributes")
-                and state.attributes[ATTR_PREVIOUS_STATE]
-            ):
-                # If in arming or pending state, we return to the ATTR_PREVIOUS_STATE
-                self._state = state.attributes[ATTR_PREVIOUS_STATE]
-                self._state_ts = dt_util.utcnow()
+            self._state_ts = state.last_updated
+            if hasattr(state, "attributes") and ATTR_NEXT_STATE in state.attributes:
+                # If in arming or pending state we record the transition,
+                # not the current state
+                self._state = state.attributes[ATTR_NEXT_STATE]
             else:
                 self._state = state.state
-                self._state_ts = state.last_updated
+
+            if hasattr(state, "attributes") and ATTR_PREVIOUS_STATE in state.attributes:
+                self._previous_state = state.attributes[ATTR_PREVIOUS_STATE]
+                self._async_set_state_update_events()
