@@ -50,6 +50,10 @@ ABBREVIATIONS = {
     "curr_temp_tpl": "current_temperature_template",
     "dev": "device",
     "dev_cla": "device_class",
+    "dir_cmd_t": "direction_command_topic",
+    "dir_cmd_tpl": "direction_command_template",
+    "dir_stat_t": "direction_state_topic",
+    "dir_val_tpl": "direction_value_template",
     "dock_t": "docked_topic",
     "dock_tpl": "docked_template",
     "e": "encoding",
