@@ -33,7 +33,6 @@ DAILY_NAME = "Daily Energy Usage"
 ACTIVE_TYPE = "active"
 DAILY_TYPE = "daily"
 
-ICON = "mdi:flash"
 
 MIN_TIME_BETWEEN_DAILY_UPDATES = timedelta(seconds=150)
 MIN_TIME_BETWEEN_ACTIVE_UPDATES = timedelta(seconds=10)
@@ -140,6 +139,8 @@ class NeurioData:
 class NeurioEnergy(SensorEntity):
     """Implementation of a Neurio energy sensor."""
 
+    _attr_icon = "mdi:flash"
+
     def __init__(self, data, name, sensor_type, update_call):
         """Initialize the sensor."""
         self._name = name
@@ -172,11 +173,6 @@ class NeurioEnergy(SensorEntity):
         """Return the unit of measurement of this entity, if any."""
         return self._unit_of_measurement
 
-    @property
-    def icon(self):
-        """Icon to use in the frontend, if any."""
-        return ICON
-
     def update(self) -> None:
         """Get the latest data, update state."""
         self.update_sensor()
