@@ -13,5 +13,4 @@ SENSOR_SAFE = "safe"
 SENSOR_SLIDING = "sliding"
 SENSOR_SMOKE_CO = "alarm"
 SENSOR_TEMPERATURE = "temperature"
-SENSOR_WINDOW_HINGED_HORIZONTAL = "window_hinged_horizontal"
-SENSOR_WINDOW_HINGED_VERTICAL = "window_hinged_vertical"
+SENSOR_WINDOW_HINGED = "window_hinged"
