@@ -14,8 +14,7 @@ from homeassistant.const import (
     CONF_LONGITUDE,
     CONF_NAME,
     CONF_RADIUS,
-    LENGTH_KILOMETERS,
-    LENGTH_METERS,
+    UnitOfLength,
 )
 from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
@@ -39,7 +38,8 @@ DEFAULT_ALTITUDE = 0
 
 EVENT_OPENSKY_ENTRY = f"{DOMAIN}_entry"
 EVENT_OPENSKY_EXIT = f"{DOMAIN}_exit"
-SCAN_INTERVAL = timedelta(seconds=12)  # opensky public limit is 10 seconds
+# OpenSky free user has 400 credits, with 4 credits per API call. 100/24 = ~4 requests per hour
+SCAN_INTERVAL = timedelta(minutes=15)
 
 OPENSKY_API_URL = "https://opensky-network.org/api/states/all"
 OPENSKY_API_FIELDS = [
@@ -107,7 +107,7 @@ class OpenSkySensor(SensorEntity):
         self._latitude = latitude
         self._longitude = longitude
         self._radius = DistanceConverter.convert(
-            radius, LENGTH_KILOMETERS, LENGTH_METERS
+            radius, UnitOfLength.KILOMETERS, UnitOfLength.METERS
         )
         self._altitude = altitude
         self._state = 0
