@@ -1,6 +1,7 @@
 """Config flow for Philips TV integration."""
 from __future__ import annotations
 
+from collections.abc import Mapping
 import platform
 from typing import Any
 
@@ -20,6 +21,18 @@ from homeassistant.data_entry_flow import FlowResult
 from . import LOGGER
 from .const import CONF_ALLOW_NOTIFY, CONF_SYSTEM, CONST_APP_ID, CONST_APP_NAME, DOMAIN
 
+USER_SCHEMA = vol.Schema(
+    {
+        vol.Required(
+            CONF_HOST,
+        ): str,
+        vol.Required(
+            CONF_API_VERSION,
+            default=1,
+        ): vol.In([1, 5, 6]),
+    }
+)
+
 
 async def _validate_input(
     hass: core.HomeAssistant, host: str, api_version: int
@@ -47,9 +60,19 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         self._current: dict[str, Any] = {}
         self._hub: PhilipsTV | None = None
         self._pair_state: Any = None
+        self._entry: config_entries.ConfigEntry | None = None
 
     async def _async_create_current(self) -> FlowResult:
         system = self._current[CONF_SYSTEM]
+        if self._entry:
+            self.hass.config_entries.async_update_entry(
+                self._entry, data=self._entry.data | self._current
+            )
+            self.hass.async_create_task(
+                self.hass.config_entries.async_reload(self._entry.entry_id)
+            )
+            return self.async_abort(reason="reauth_successful")
+
         return self.async_create_entry(
             title=f"{system['name']} ({system['serialnumber']})",
             data=self._current,
@@ -108,6 +131,13 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         self._current[CONF_PASSWORD] = password
         return await self._async_create_current()
 
+    async def async_step_reauth(self, entry_data: Mapping[str, Any]) -> FlowResult:
+        """Handle configuration by re-auth."""
+        self._entry = self.hass.config_entries.async_get_entry(self.context["entry_id"])
+        self._current[CONF_HOST] = entry_data[CONF_HOST]
+        self._current[CONF_API_VERSION] = entry_data[CONF_API_VERSION]
+        return await self.async_step_user()
+
     async def async_step_user(
         self, user_input: dict[str, Any] | None = None
     ) -> FlowResult:
@@ -128,7 +158,8 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             else:
                 if serialnumber := hub.system.get("serialnumber"):
                     await self.async_set_unique_id(serialnumber)
-                    self._abort_if_unique_id_configured()
+                    if self._entry is None:
+                        self._abort_if_unique_id_configured()
 
                 self._current[CONF_SYSTEM] = hub.system
                 self._current[CONF_API_VERSION] = hub.api_version
@@ -138,14 +169,7 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
                     return await self.async_step_pair()
                 return await self._async_create_current()
 
-        schema = vol.Schema(
-            {
-                vol.Required(CONF_HOST, default=self._current.get(CONF_HOST)): str,
-                vol.Required(
-                    CONF_API_VERSION, default=self._current.get(CONF_API_VERSION, 1)
-                ): vol.In([1, 5, 6]),
-            }
-        )
+        schema = self.add_suggested_values_to_schema(USER_SCHEMA, self._current)
         return self.async_show_form(step_id="user", data_schema=schema, errors=errors)
 
     @staticmethod
