@@ -72,7 +72,7 @@ class ProsegurAlarm(alarm.AlarmControlPanelEntity):
         """Update alarm status."""
 
         try:
-            self._installation = await Installation.retrieve(self._auth)
+            self._installation = await Installation.retrieve(self._auth, self.contract)
         except ConnectionError as err:
             _LOGGER.error(err)
             self._attr_available = False
