@@ -1,4 +1,4 @@
-"""This platform provides support for sensor data from RainMachine."""
+"""Support for sensor data from RainMachine."""
 from __future__ import annotations
 
 from dataclasses import dataclass
