@@ -3,14 +3,14 @@ from __future__ import annotations
 
 from collections.abc import Callable
 from datetime import datetime, timedelta
-from functools import lru_cache
 import logging
 import time
 from typing import Any, cast
 
 import ciso8601
-from fnvhash import fnv1a_32
+from fnv_hash_fast import fnv1a_32
 from sqlalchemy import (
+    CHAR,
     JSON,
     BigInteger,
     Boolean,
@@ -25,17 +25,18 @@ from sqlalchemy import (
     SmallInteger,
     String,
     Text,
+    case,
     type_coerce,
 )
 from sqlalchemy.dialects import mysql, oracle, postgresql, sqlite
 from sqlalchemy.engine.interfaces import Dialect
+from sqlalchemy.ext.compiler import compiles
 from sqlalchemy.orm import DeclarativeBase, Mapped, aliased, mapped_column, relationship
+from sqlalchemy.types import TypeDecorator
 from typing_extensions import Self
 
 from homeassistant.const import (
-    MAX_LENGTH_EVENT_CONTEXT_ID,
     MAX_LENGTH_EVENT_EVENT_TYPE,
-    MAX_LENGTH_EVENT_ORIGIN,
     MAX_LENGTH_STATE_ENTITY_ID,
     MAX_LENGTH_STATE_STATE,
 )
@@ -136,6 +137,27 @@ _DEFAULT_TABLE_ARGS = {
 }
 
 
+class UnusedDateTime(DateTime):
+    """An unused column type that behaves like a datetime."""
+
+
+class Unused(CHAR):
+    """An unused column type that behaves like a string."""
+
+
+@compiles(UnusedDateTime, "mysql", "mariadb", "sqlite")  # type: ignore[misc,no-untyped-call]
+@compiles(Unused, "mysql", "mariadb", "sqlite")  # type: ignore[misc,no-untyped-call]
+def compile_char_zero(type_: TypeDecorator, compiler: Any, **kw: Any) -> str:
+    """Compile UnusedDateTime and Unused as CHAR(0) on mysql, mariadb, and sqlite."""
+    return "CHAR(0)"  # Uses 1 byte on MySQL (no change on sqlite)
+
+
+@compiles(Unused, "postgresql")  # type: ignore[misc,no-untyped-call]
+def compile_char_one(type_: TypeDecorator, compiler: Any, **kw: Any) -> str:
+    """Compile Unused as CHAR(1) on postgresql."""
+    return "CHAR(1)"  # Uses 1 byte
+
+
 class FAST_PYSQLITE_DATETIME(sqlite.DATETIME):
     """Use ciso8601 to parse datetimes instead of sqlalchemy built-in regex."""
 
@@ -144,6 +166,19 @@ class FAST_PYSQLITE_DATETIME(sqlite.DATETIME):
         return lambda value: None if value is None else ciso8601.parse_datetime(value)
 
 
+class NativeLargeBinary(LargeBinary):
+    """A faster version of LargeBinary for engines that support python bytes natively."""
+
+    def result_processor(self, dialect, coltype):  # type: ignore[no-untyped-def]
+        """No conversion needed for engines that support native bytes."""
+        return None
+
+
+# For MariaDB and MySQL we can use an unsigned integer type since it will fit 2**32
+# for sqlite and postgresql we use a bigint
+UINT_32_TYPE = BigInteger().with_variant(
+    mysql.INTEGER(unsigned=True), "mysql", "mariadb"  # type: ignore[no-untyped-call]
+)
 JSON_VARIANT_CAST = Text().with_variant(
     postgresql.JSON(none_as_null=True), "postgresql"  # type: ignore[no-untyped-call]
 )
@@ -161,7 +196,13 @@ DOUBLE_TYPE = (
     .with_variant(oracle.DOUBLE_PRECISION(), "oracle")
     .with_variant(postgresql.DOUBLE_PRECISION(), "postgresql")
 )
+UNUSED_LEGACY_COLUMN = Unused(0)
+UNUSED_LEGACY_DATETIME_COLUMN = UnusedDateTime(timezone=True)
+UNUSED_LEGACY_INTEGER_COLUMN = SmallInteger()
 DOUBLE_PRECISION_TYPE_SQL = "DOUBLE PRECISION"
+CONTEXT_BINARY_TYPE = LargeBinary(CONTEXT_ID_BIN_MAX_LENGTH).with_variant(
+    NativeLargeBinary(CONTEXT_ID_BIN_MAX_LENGTH), "mysql", "mariadb", "sqlite"
+)
 
 TIMESTAMP_TYPE = DOUBLE_TYPE
 
@@ -202,41 +243,21 @@ class Events(Base):
     )
     __tablename__ = TABLE_EVENTS
     event_id: Mapped[int] = mapped_column(Integer, Identity(), primary_key=True)
-    event_type: Mapped[str | None] = mapped_column(
-        String(MAX_LENGTH_EVENT_EVENT_TYPE)
-    )  # no longer used
-    event_data: Mapped[str | None] = mapped_column(
-        Text().with_variant(mysql.LONGTEXT, "mysql", "mariadb")
-    )
-    origin: Mapped[str | None] = mapped_column(
-        String(MAX_LENGTH_EVENT_ORIGIN)
-    )  # no longer used for new rows
+    event_type: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
+    event_data: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
+    origin: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
     origin_idx: Mapped[int | None] = mapped_column(SmallInteger)
-    time_fired: Mapped[datetime | None] = mapped_column(
-        DATETIME_TYPE
-    )  # no longer used for new rows
+    time_fired: Mapped[datetime | None] = mapped_column(UNUSED_LEGACY_DATETIME_COLUMN)
     time_fired_ts: Mapped[float | None] = mapped_column(TIMESTAMP_TYPE, index=True)
-    context_id: Mapped[str | None] = mapped_column(  # no longer used
-        String(MAX_LENGTH_EVENT_CONTEXT_ID), index=True
-    )
-    context_user_id: Mapped[str | None] = mapped_column(  # no longer used
-        String(MAX_LENGTH_EVENT_CONTEXT_ID)
-    )
-    context_parent_id: Mapped[str | None] = mapped_column(  # no longer used
-        String(MAX_LENGTH_EVENT_CONTEXT_ID)
-    )
+    context_id: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
+    context_user_id: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
+    context_parent_id: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
     data_id: Mapped[int | None] = mapped_column(
         Integer, ForeignKey("event_data.data_id"), index=True
     )
-    context_id_bin: Mapped[bytes | None] = mapped_column(
-        LargeBinary(CONTEXT_ID_BIN_MAX_LENGTH),
-    )
-    context_user_id_bin: Mapped[bytes | None] = mapped_column(
-        LargeBinary(CONTEXT_ID_BIN_MAX_LENGTH),
-    )
-    context_parent_id_bin: Mapped[bytes | None] = mapped_column(
-        LargeBinary(CONTEXT_ID_BIN_MAX_LENGTH)
-    )
+    context_id_bin: Mapped[bytes | None] = mapped_column(CONTEXT_BINARY_TYPE)
+    context_user_id_bin: Mapped[bytes | None] = mapped_column(CONTEXT_BINARY_TYPE)
+    context_parent_id_bin: Mapped[bytes | None] = mapped_column(CONTEXT_BINARY_TYPE)
     event_type_id: Mapped[int | None] = mapped_column(
         Integer, ForeignKey("event_types.event_type_id")
     )
@@ -310,7 +331,7 @@ class EventData(Base):
     __table_args__ = (_DEFAULT_TABLE_ARGS,)
     __tablename__ = TABLE_EVENT_DATA
     data_id: Mapped[int] = mapped_column(Integer, Identity(), primary_key=True)
-    hash: Mapped[int | None] = mapped_column(BigInteger, index=True)
+    hash: Mapped[int | None] = mapped_column(UINT_32_TYPE, index=True)
     # Note that this is not named attributes to avoid confusion with the states table
     shared_data: Mapped[str | None] = mapped_column(
         Text().with_variant(mysql.LONGTEXT, "mysql", "mariadb")
@@ -344,10 +365,9 @@ class EventData(Base):
         return bytes_result
 
     @staticmethod
-    @lru_cache
     def hash_shared_data_bytes(shared_data_bytes: bytes) -> int:
         """Return the hash of json encoded shared data."""
-        return cast(int, fnv1a_32(shared_data_bytes))
+        return fnv1a_32(shared_data_bytes)
 
     def to_native(self) -> dict[str, Any]:
         """Convert to an event data dictionary."""
@@ -397,21 +417,13 @@ class States(Base):
     )
     __tablename__ = TABLE_STATES
     state_id: Mapped[int] = mapped_column(Integer, Identity(), primary_key=True)
-    entity_id: Mapped[str | None] = mapped_column(
-        String(MAX_LENGTH_STATE_ENTITY_ID)
-    )  # no longer used for new rows
+    entity_id: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
     state: Mapped[str | None] = mapped_column(String(MAX_LENGTH_STATE_STATE))
-    attributes: Mapped[str | None] = mapped_column(
-        Text().with_variant(mysql.LONGTEXT, "mysql", "mariadb")
-    )  # no longer used for new rows
-    event_id: Mapped[int | None] = mapped_column(Integer)  # no longer used for new rows
-    last_changed: Mapped[datetime | None] = mapped_column(
-        DATETIME_TYPE
-    )  # no longer used for new rows
+    attributes: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
+    event_id: Mapped[int | None] = mapped_column(UNUSED_LEGACY_INTEGER_COLUMN)
+    last_changed: Mapped[datetime | None] = mapped_column(UNUSED_LEGACY_DATETIME_COLUMN)
     last_changed_ts: Mapped[float | None] = mapped_column(TIMESTAMP_TYPE)
-    last_updated: Mapped[datetime | None] = mapped_column(
-        DATETIME_TYPE
-    )  # no longer used for new rows
+    last_updated: Mapped[datetime | None] = mapped_column(UNUSED_LEGACY_DATETIME_COLUMN)
     last_updated_ts: Mapped[float | None] = mapped_column(
         TIMESTAMP_TYPE, default=time.time, index=True
     )
@@ -421,29 +433,17 @@ class States(Base):
     attributes_id: Mapped[int | None] = mapped_column(
         Integer, ForeignKey("state_attributes.attributes_id"), index=True
     )
-    context_id: Mapped[str | None] = mapped_column(  # no longer used
-        String(MAX_LENGTH_EVENT_CONTEXT_ID), index=True
-    )
-    context_user_id: Mapped[str | None] = mapped_column(  # no longer used
-        String(MAX_LENGTH_EVENT_CONTEXT_ID)
-    )
-    context_parent_id: Mapped[str | None] = mapped_column(  # no longer used
-        String(MAX_LENGTH_EVENT_CONTEXT_ID)
-    )
+    context_id: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
+    context_user_id: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
+    context_parent_id: Mapped[str | None] = mapped_column(UNUSED_LEGACY_COLUMN)
     origin_idx: Mapped[int | None] = mapped_column(
         SmallInteger
     )  # 0 is local, 1 is remote
     old_state: Mapped[States | None] = relationship("States", remote_side=[state_id])
     state_attributes: Mapped[StateAttributes | None] = relationship("StateAttributes")
-    context_id_bin: Mapped[bytes | None] = mapped_column(
-        LargeBinary(CONTEXT_ID_BIN_MAX_LENGTH),
-    )
-    context_user_id_bin: Mapped[bytes | None] = mapped_column(
-        LargeBinary(CONTEXT_ID_BIN_MAX_LENGTH),
-    )
-    context_parent_id_bin: Mapped[bytes | None] = mapped_column(
-        LargeBinary(CONTEXT_ID_BIN_MAX_LENGTH)
-    )
+    context_id_bin: Mapped[bytes | None] = mapped_column(CONTEXT_BINARY_TYPE)
+    context_user_id_bin: Mapped[bytes | None] = mapped_column(CONTEXT_BINARY_TYPE)
+    context_parent_id_bin: Mapped[bytes | None] = mapped_column(CONTEXT_BINARY_TYPE)
     metadata_id: Mapped[int | None] = mapped_column(
         Integer, ForeignKey("states_meta.metadata_id")
     )
@@ -544,7 +544,7 @@ class StateAttributes(Base):
     __table_args__ = (_DEFAULT_TABLE_ARGS,)
     __tablename__ = TABLE_STATE_ATTRIBUTES
     attributes_id: Mapped[int] = mapped_column(Integer, Identity(), primary_key=True)
-    hash: Mapped[int | None] = mapped_column(BigInteger, index=True)
+    hash: Mapped[int | None] = mapped_column(UINT_32_TYPE, index=True)
     # Note that this is not named attributes to avoid confusion with the states table
     shared_attrs: Mapped[str | None] = mapped_column(
         Text().with_variant(mysql.LONGTEXT, "mysql", "mariadb")
@@ -593,10 +593,9 @@ class StateAttributes(Base):
         return bytes_result
 
     @staticmethod
-    @lru_cache(maxsize=2048)
     def hash_shared_attrs_bytes(shared_attrs_bytes: bytes) -> int:
         """Return the hash of json encoded shared attributes."""
-        return cast(int, fnv1a_32(shared_attrs_bytes))
+        return fnv1a_32(shared_attrs_bytes)
 
     def to_native(self) -> dict[str, Any]:
         """Convert to a state attributes dictionary."""
@@ -634,20 +633,18 @@ class StatisticsBase:
     """Statistics base class."""
 
     id: Mapped[int] = mapped_column(Integer, Identity(), primary_key=True)
-    created: Mapped[datetime | None] = mapped_column(DATETIME_TYPE)  # No longer used
+    created: Mapped[datetime | None] = mapped_column(UNUSED_LEGACY_DATETIME_COLUMN)
     created_ts: Mapped[float | None] = mapped_column(TIMESTAMP_TYPE, default=time.time)
     metadata_id: Mapped[int | None] = mapped_column(
         Integer,
         ForeignKey(f"{TABLE_STATISTICS_META}.id", ondelete="CASCADE"),
     )
-    start: Mapped[datetime | None] = mapped_column(
-        DATETIME_TYPE, index=True
-    )  # No longer used
+    start: Mapped[datetime | None] = mapped_column(UNUSED_LEGACY_DATETIME_COLUMN)
     start_ts: Mapped[float | None] = mapped_column(TIMESTAMP_TYPE, index=True)
     mean: Mapped[float | None] = mapped_column(DOUBLE_TYPE)
     min: Mapped[float | None] = mapped_column(DOUBLE_TYPE)
     max: Mapped[float | None] = mapped_column(DOUBLE_TYPE)
-    last_reset: Mapped[datetime | None] = mapped_column(DATETIME_TYPE)
+    last_reset: Mapped[datetime | None] = mapped_column(UNUSED_LEGACY_DATETIME_COLUMN)
     last_reset_ts: Mapped[float | None] = mapped_column(TIMESTAMP_TYPE)
     state: Mapped[float | None] = mapped_column(DOUBLE_TYPE)
     sum: Mapped[float | None] = mapped_column(DOUBLE_TYPE)
@@ -825,3 +822,11 @@ ENTITY_ID_IN_EVENT: ColumnElement = EVENT_DATA_JSON["entity_id"]
 OLD_ENTITY_ID_IN_EVENT: ColumnElement = OLD_FORMAT_EVENT_DATA_JSON["entity_id"]
 DEVICE_ID_IN_EVENT: ColumnElement = EVENT_DATA_JSON["device_id"]
 OLD_STATE = aliased(States, name="old_state")
+
+SHARED_ATTR_OR_LEGACY_ATTRIBUTES = case(
+    (StateAttributes.shared_attrs.is_(None), States.attributes),
+    else_=StateAttributes.shared_attrs,
+).label("attributes")
+SHARED_DATA_OR_LEGACY_EVENT_DATA = case(
+    (EventData.shared_data.is_(None), Events.event_data), else_=EventData.shared_data
+).label("event_data")
