@@ -1,21 +1,19 @@
 """Purge old data helper."""
 from __future__ import annotations
 
-from collections.abc import Callable, Iterable
+from collections.abc import Callable
 from datetime import datetime
-from functools import partial
-from itertools import islice, zip_longest
+from itertools import zip_longest
 import logging
-from typing import TYPE_CHECKING, Any
+import time
+from typing import TYPE_CHECKING
 
 from sqlalchemy.orm.session import Session
-from sqlalchemy.sql.expression import distinct
 
-from homeassistant.const import EVENT_STATE_CHANGED
 import homeassistant.util.dt as dt_util
 
-from .const import MAX_ROWS_TO_PURGE
-from .db_schema import Events, StateAttributes, States
+from .const import SQLITE_MAX_BIND_VARS
+from .db_schema import Events, States, StatesMeta
 from .models import DatabaseEngine
 from .queries import (
     attributes_ids_exist_in_states,
@@ -24,14 +22,19 @@ from .queries import (
     data_ids_exist_in_events_with_fast_in_distinct,
     delete_event_data_rows,
     delete_event_rows,
+    delete_event_types_rows,
     delete_recorder_runs_rows,
     delete_states_attributes_rows,
+    delete_states_meta_rows,
     delete_states_rows,
     delete_statistics_runs_rows,
     delete_statistics_short_term_rows,
     disconnect_states_rows,
+    find_entity_ids_to_purge,
+    find_event_types_to_purge,
     find_events_to_purge,
     find_latest_statistics_runs_run_id,
+    find_legacy_detached_states_and_attributes_to_purge,
     find_legacy_event_state_and_attributes_and_data_ids_to_purge,
     find_legacy_row,
     find_short_term_statistics_to_purge,
@@ -39,7 +42,7 @@ from .queries import (
     find_statistics_runs_to_purge,
 )
 from .repack import repack_database
-from .util import retryable_database_job, session_scope
+from .util import chunked, retryable_database_job, session_scope
 
 if TYPE_CHECKING:
     from . import Recorder
@@ -51,22 +54,6 @@ DEFAULT_STATES_BATCHES_PER_PURGE = 20  # We expect ~95% de-dupe rate
 DEFAULT_EVENTS_BATCHES_PER_PURGE = 15  # We expect ~92% de-dupe rate
 
 
-def take(take_num: int, iterable: Iterable) -> list[Any]:
-    """Return first n items of the iterable as a list.
-
-    From itertools recipes
-    """
-    return list(islice(iterable, take_num))
-
-
-def chunked(iterable: Iterable, chunked_num: int) -> Iterable[Any]:
-    """Break *iterable* into lists of length *n*.
-
-    From more-itertools
-    """
-    return iter(partial(take, chunked_num, iter(iterable)), [])
-
-
 @retryable_database_job("purge")
 def purge_old_data(
     instance: Recorder,
@@ -85,9 +72,9 @@ def purge_old_data(
         purge_before.isoformat(sep=" ", timespec="seconds"),
     )
     with session_scope(session=instance.get_session()) as session:
-        # Purge a max of MAX_ROWS_TO_PURGE, based on the oldest states or events record
+        # Purge a max of SQLITE_MAX_BIND_VARS, based on the oldest states or events record
         has_more_to_purge = False
-        if _purging_legacy_format(session):
+        if instance.use_legacy_events_index and _purging_legacy_format(session):
             _LOGGER.debug(
                 "Purge running in legacy format as there are states with event_id"
                 " remaining"
@@ -125,6 +112,14 @@ def purge_old_data(
             _LOGGER.debug("Cleanup filtered data hasn't fully completed yet")
             return False
 
+        # This purge cycle is finished, clean up old event types and
+        # recorder runs
+        if instance.event_type_manager.active:
+            _purge_old_event_types(instance, session)
+
+        if instance.states_meta_manager.active:
+            _purge_old_entity_ids(instance, session)
+
         _purge_old_recorder_runs(instance, session, purge_before)
     if repack:
         repack_database(instance)
@@ -148,13 +143,32 @@ def _purge_legacy_format(
     ) = _select_legacy_event_state_and_attributes_and_data_ids_to_purge(
         session, purge_before
     )
-    if state_ids:
-        _purge_state_ids(instance, session, state_ids)
+    _purge_state_ids(instance, session, state_ids)
     _purge_unused_attributes_ids(instance, session, attributes_ids)
-    if event_ids:
-        _purge_event_ids(session, event_ids)
+    _purge_event_ids(session, event_ids)
     _purge_unused_data_ids(instance, session, data_ids)
-    return bool(event_ids or state_ids or attributes_ids or data_ids)
+
+    # The database may still have some rows that have an event_id but are not
+    # linked to any event. These rows are not linked to any event because the
+    # event was deleted. We need to purge these rows as well or we will never
+    # switch to the new format which will prevent us from purging any events
+    # that happened after the detached states.
+    (
+        detached_state_ids,
+        detached_attributes_ids,
+    ) = _select_legacy_detached_state_and_attributes_and_data_ids_to_purge(
+        session, purge_before
+    )
+    _purge_state_ids(instance, session, detached_state_ids)
+    _purge_unused_attributes_ids(instance, session, detached_attributes_ids)
+    return bool(
+        event_ids
+        or state_ids
+        or attributes_ids
+        or data_ids
+        or detached_state_ids
+        or detached_attributes_ids
+    )
 
 
 def _purge_states_and_attributes_ids(
@@ -173,7 +187,7 @@ def _purge_states_and_attributes_ids(
     # There are more states relative to attributes_ids so
     # we purge enough state_ids to try to generate a full
     # size batch of attributes_ids that will be around the size
-    # MAX_ROWS_TO_PURGE
+    # SQLITE_MAX_BIND_VARS
     attributes_ids_batch: set[int] = set()
     for _ in range(states_batch_size):
         state_ids, attributes_ids = _select_state_attributes_ids_to_purge(
@@ -207,7 +221,7 @@ def _purge_events_and_data_ids(
     # There are more events relative to data_ids so
     # we purge enough event_ids to try to generate a full
     # size batch of data_ids that will be around the size
-    # MAX_ROWS_TO_PURGE
+    # SQLITE_MAX_BIND_VARS
     data_ids_batch: set[int] = set()
     for _ in range(events_batch_size):
         event_ids, data_ids = _select_event_data_ids_to_purge(session, purge_before)
@@ -309,7 +323,7 @@ def _select_unused_attributes_ids(
         #
         # We used to generate a query based on how many attribute_ids to find but
         # that meant sqlalchemy Transparent SQL Compilation Caching was working against
-        # us by cached up to MAX_ROWS_TO_PURGE different statements which could be
+        # us by cached up to SQLITE_MAX_BIND_VARS different statements which could be
         # up to 500MB for large database due to the complexity of the ORM objects.
         #
         # We now break the query into groups of 100 and use a lambda_stmt to ensure
@@ -420,6 +434,31 @@ def _select_short_term_statistics_to_purge(
     return [statistic.id for statistic in statistics]
 
 
+def _select_legacy_detached_state_and_attributes_and_data_ids_to_purge(
+    session: Session, purge_before: datetime
+) -> tuple[set[int], set[int]]:
+    """Return a list of state, and attribute ids to purge.
+
+    We do not link these anymore since state_change events
+    do not exist in the events table anymore, however we
+    still need to be able to purge them.
+    """
+    states = session.execute(
+        find_legacy_detached_states_and_attributes_to_purge(
+            dt_util.utc_to_timestamp(purge_before)
+        )
+    ).all()
+    _LOGGER.debug("Selected %s state ids to remove", len(states))
+    state_ids = set()
+    attributes_ids = set()
+    for state in states:
+        if state_id := state.state_id:
+            state_ids.add(state_id)
+        if attributes_id := state.attributes_id:
+            attributes_ids.add(attributes_id)
+    return state_ids, attributes_ids
+
+
 def _select_legacy_event_state_and_attributes_and_data_ids_to_purge(
     session: Session, purge_before: datetime
 ) -> tuple[set[int], set[int], set[int], set[int]]:
@@ -441,17 +480,19 @@ def _select_legacy_event_state_and_attributes_and_data_ids_to_purge(
     data_ids = set()
     for event in events:
         event_ids.add(event.event_id)
-        if event.state_id:
-            state_ids.add(event.state_id)
-        if event.attributes_id:
-            attributes_ids.add(event.attributes_id)
-        if event.data_id:
-            data_ids.add(event.data_id)
+        if state_id := event.state_id:
+            state_ids.add(state_id)
+        if attributes_id := event.attributes_id:
+            attributes_ids.add(attributes_id)
+        if data_id := event.data_id:
+            data_ids.add(data_id)
     return event_ids, state_ids, attributes_ids, data_ids
 
 
 def _purge_state_ids(instance: Recorder, session: Session, state_ids: set[int]) -> None:
     """Disconnect states and delete by state id."""
+    if not state_ids:
+        return
 
     # Update old_state_id to NULL before deleting to ensure
     # the delete does not fail due to a foreign key constraint
@@ -464,87 +505,33 @@ def _purge_state_ids(instance: Recorder, session: Session, state_ids: set[int])
     _LOGGER.debug("Deleted %s states", deleted_rows)
 
     # Evict eny entries in the old_states cache referring to a purged state
-    _evict_purged_states_from_old_states_cache(instance, state_ids)
-
-
-def _evict_purged_states_from_old_states_cache(
-    instance: Recorder, purged_state_ids: set[int]
-) -> None:
-    """Evict purged states from the old states cache."""
-    # Make a map from old_state_id to entity_id
-    old_states = instance._old_states  # pylint: disable=protected-access
-    old_state_reversed = {
-        old_state.state_id: entity_id
-        for entity_id, old_state in old_states.items()
-        if old_state.state_id
-    }
-
-    # Evict any purged state from the old states cache
-    for purged_state_id in purged_state_ids.intersection(old_state_reversed):
-        old_states.pop(old_state_reversed[purged_state_id], None)
-
-
-def _evict_purged_data_from_data_cache(
-    instance: Recorder, purged_data_ids: set[int]
-) -> None:
-    """Evict purged data ids from the data ids cache."""
-    # Make a map from data_id to the data json
-    event_data_ids = instance._event_data_ids  # pylint: disable=protected-access
-    event_data_ids_reversed = {
-        data_id: data for data, data_id in event_data_ids.items()
-    }
-
-    # Evict any purged data from the event_data_ids cache
-    for purged_attribute_id in purged_data_ids.intersection(event_data_ids_reversed):
-        event_data_ids.pop(event_data_ids_reversed[purged_attribute_id], None)
-
-
-def _evict_purged_attributes_from_attributes_cache(
-    instance: Recorder, purged_attributes_ids: set[int]
-) -> None:
-    """Evict purged attribute ids from the attribute ids cache."""
-    # Make a map from attributes_id to the attributes json
-    state_attributes_ids = (
-        instance._state_attributes_ids  # pylint: disable=protected-access
-    )
-    state_attributes_ids_reversed = {
-        attributes_id: attributes
-        for attributes, attributes_id in state_attributes_ids.items()
-    }
-
-    # Evict any purged attributes from the state_attributes_ids cache
-    for purged_attribute_id in purged_attributes_ids.intersection(
-        state_attributes_ids_reversed
-    ):
-        state_attributes_ids.pop(
-            state_attributes_ids_reversed[purged_attribute_id], None
-        )
+    instance.states_manager.evict_purged_state_ids(state_ids)
 
 
 def _purge_batch_attributes_ids(
     instance: Recorder, session: Session, attributes_ids: set[int]
 ) -> None:
-    """Delete old attributes ids in batches of MAX_ROWS_TO_PURGE."""
-    for attributes_ids_chunk in chunked(attributes_ids, MAX_ROWS_TO_PURGE):
+    """Delete old attributes ids in batches of SQLITE_MAX_BIND_VARS."""
+    for attributes_ids_chunk in chunked(attributes_ids, SQLITE_MAX_BIND_VARS):
         deleted_rows = session.execute(
             delete_states_attributes_rows(attributes_ids_chunk)
         )
         _LOGGER.debug("Deleted %s attribute states", deleted_rows)
 
     # Evict any entries in the state_attributes_ids cache referring to a purged state
-    _evict_purged_attributes_from_attributes_cache(instance, attributes_ids)
+    instance.state_attributes_manager.evict_purged(attributes_ids)
 
 
 def _purge_batch_data_ids(
     instance: Recorder, session: Session, data_ids: set[int]
 ) -> None:
-    """Delete old event data ids in batches of MAX_ROWS_TO_PURGE."""
-    for data_ids_chunk in chunked(data_ids, MAX_ROWS_TO_PURGE):
+    """Delete old event data ids in batches of SQLITE_MAX_BIND_VARS."""
+    for data_ids_chunk in chunked(data_ids, SQLITE_MAX_BIND_VARS):
         deleted_rows = session.execute(delete_event_data_rows(data_ids_chunk))
         _LOGGER.debug("Deleted %s data events", deleted_rows)
 
     # Evict any entries in the event_data_ids cache referring to a purged state
-    _evict_purged_data_from_data_cache(instance, data_ids)
+    instance.event_data_manager.evict_purged(data_ids)
 
 
 def _purge_statistics_runs(session: Session, statistics_runs: list[int]) -> None:
@@ -563,8 +550,10 @@ def _purge_short_term_statistics(
     _LOGGER.debug("Deleted %s short term statistics", deleted_rows)
 
 
-def _purge_event_ids(session: Session, event_ids: Iterable[int]) -> None:
+def _purge_event_ids(session: Session, event_ids: set[int]) -> None:
     """Delete by event id."""
+    if not event_ids:
+        return
     deleted_rows = session.execute(delete_event_rows(event_ids))
     _LOGGER.debug("Deleted %s events", deleted_rows)
 
@@ -575,120 +564,211 @@ def _purge_old_recorder_runs(
     """Purge all old recorder runs."""
     # Recorder runs is small, no need to batch run it
     deleted_rows = session.execute(
-        delete_recorder_runs_rows(purge_before, instance.run_history.current.run_id)
+        delete_recorder_runs_rows(
+            purge_before, instance.recorder_runs_manager.current.run_id
+        )
     )
     _LOGGER.debug("Deleted %s recorder_runs", deleted_rows)
 
 
+def _purge_old_event_types(instance: Recorder, session: Session) -> None:
+    """Purge all old event types."""
+    # Event types is small, no need to batch run it
+    purge_event_types = set()
+    event_type_ids = set()
+    for event_type_id, event_type in session.execute(find_event_types_to_purge()):
+        purge_event_types.add(event_type)
+        event_type_ids.add(event_type_id)
+
+    if not event_type_ids:
+        return
+
+    deleted_rows = session.execute(delete_event_types_rows(event_type_ids))
+    _LOGGER.debug("Deleted %s event types", deleted_rows)
+
+    # Evict any entries in the event_type cache referring to a purged state
+    instance.event_type_manager.evict_purged(purge_event_types)
+
+
+def _purge_old_entity_ids(instance: Recorder, session: Session) -> None:
+    """Purge all old entity_ids."""
+    # entity_ids are small, no need to batch run it
+    purge_entity_ids = set()
+    states_metadata_ids = set()
+    for metadata_id, entity_id in session.execute(find_entity_ids_to_purge()):
+        purge_entity_ids.add(entity_id)
+        states_metadata_ids.add(metadata_id)
+
+    if not states_metadata_ids:
+        return
+
+    deleted_rows = session.execute(delete_states_meta_rows(states_metadata_ids))
+    _LOGGER.debug("Deleted %s states meta", deleted_rows)
+
+    # Evict any entries in the event_type cache referring to a purged state
+    instance.states_meta_manager.evict_purged(purge_entity_ids)
+    instance.states_manager.evict_purged_entity_ids(purge_entity_ids)
+
+
 def _purge_filtered_data(instance: Recorder, session: Session) -> bool:
     """Remove filtered states and events that shouldn't be in the database."""
     _LOGGER.debug("Cleanup filtered data")
     database_engine = instance.database_engine
     assert database_engine is not None
+    now_timestamp = time.time()
 
     # Check if excluded entity_ids are in database
-    excluded_entity_ids: list[str] = [
-        entity_id
-        for (entity_id,) in session.query(distinct(States.entity_id)).all()
-        if not instance.entity_filter(entity_id)
+    entity_filter = instance.entity_filter
+    has_more_states_to_purge = False
+    excluded_metadata_ids: list[str] = [
+        metadata_id
+        for (metadata_id, entity_id) in session.query(
+            StatesMeta.metadata_id, StatesMeta.entity_id
+        ).all()
+        if not entity_filter(entity_id)
     ]
-    if len(excluded_entity_ids) > 0:
-        _purge_filtered_states(instance, session, excluded_entity_ids, database_engine)
-        return False
+    if excluded_metadata_ids:
+        has_more_states_to_purge = _purge_filtered_states(
+            instance, session, excluded_metadata_ids, database_engine, now_timestamp
+        )
 
     # Check if excluded event_types are in database
-    excluded_event_types: list[str] = [
-        event_type
-        for (event_type,) in session.query(distinct(Events.event_type)).all()
-        if event_type in instance.exclude_t
-    ]
-    if len(excluded_event_types) > 0:
-        _purge_filtered_events(instance, session, excluded_event_types)
-        return False
+    has_more_events_to_purge = False
+    if (
+        event_type_to_event_type_ids := instance.event_type_manager.get_many(
+            instance.exclude_event_types, session
+        )
+    ) and (
+        excluded_event_type_ids := [
+            event_type_id
+            for event_type_id in event_type_to_event_type_ids.values()
+            if event_type_id is not None
+        ]
+    ):
+        has_more_events_to_purge = _purge_filtered_events(
+            instance, session, excluded_event_type_ids, now_timestamp
+        )
 
-    return True
+    # Purge has completed if there are not more state or events to purge
+    return not (has_more_states_to_purge or has_more_events_to_purge)
 
 
 def _purge_filtered_states(
     instance: Recorder,
     session: Session,
-    excluded_entity_ids: list[str],
+    metadata_ids_to_purge: list[str],
     database_engine: DatabaseEngine,
-) -> None:
-    """Remove filtered states and linked events."""
-    state_ids: list[int]
-    attributes_ids: list[int]
-    event_ids: list[int]
-    state_ids, attributes_ids, event_ids = zip(
-        *(
-            session.query(States.state_id, States.attributes_id, States.event_id)
-            .filter(States.entity_id.in_(excluded_entity_ids))
-            .limit(MAX_ROWS_TO_PURGE)
-            .all()
-        )
+    purge_before_timestamp: float,
+) -> bool:
+    """Remove filtered states and linked events.
+
+    Return true if all states are purged
+    """
+    state_ids: tuple[int, ...]
+    attributes_ids: tuple[int, ...]
+    event_ids: tuple[int, ...]
+    to_purge = list(
+        session.query(States.state_id, States.attributes_id, States.event_id)
+        .filter(States.metadata_id.in_(metadata_ids_to_purge))
+        .filter(States.last_updated_ts < purge_before_timestamp)
+        .limit(SQLITE_MAX_BIND_VARS)
+        .all()
     )
-    event_ids = [id_ for id_ in event_ids if id_ is not None]
+    if not to_purge:
+        return True
+    state_ids, attributes_ids, event_ids = zip(*to_purge)
+    filtered_event_ids = {id_ for id_ in event_ids if id_ is not None}
     _LOGGER.debug(
         "Selected %s state_ids to remove that should be filtered", len(state_ids)
     )
     _purge_state_ids(instance, session, set(state_ids))
-    _purge_event_ids(session, event_ids)
+    # These are legacy events that are linked to a state that are no longer
+    # created but since we did not remove them when we stopped adding new ones
+    # we will need to purge them here.
+    _purge_event_ids(session, filtered_event_ids)
     unused_attribute_ids_set = _select_unused_attributes_ids(
         session, {id_ for id_ in attributes_ids if id_ is not None}, database_engine
     )
     _purge_batch_attributes_ids(instance, session, unused_attribute_ids_set)
+    return False
 
 
 def _purge_filtered_events(
-    instance: Recorder, session: Session, excluded_event_types: list[str]
-) -> None:
-    """Remove filtered events and linked states."""
+    instance: Recorder,
+    session: Session,
+    excluded_event_type_ids: list[int],
+    purge_before_timestamp: float,
+) -> bool:
+    """Remove filtered events and linked states.
+
+    Return true if all events are purged.
+    """
     database_engine = instance.database_engine
     assert database_engine is not None
-    event_ids, data_ids = zip(
-        *(
-            session.query(Events.event_id, Events.data_id)
-            .filter(Events.event_type.in_(excluded_event_types))
-            .limit(MAX_ROWS_TO_PURGE)
+    to_purge = list(
+        session.query(Events.event_id, Events.data_id)
+        .filter(Events.event_type_id.in_(excluded_event_type_ids))
+        .filter(Events.time_fired_ts < purge_before_timestamp)
+        .limit(SQLITE_MAX_BIND_VARS)
+        .all()
+    )
+    if not to_purge:
+        return True
+    event_ids, data_ids = zip(*to_purge)
+    event_ids_set = set(event_ids)
+    _LOGGER.debug(
+        "Selected %s event_ids to remove that should be filtered", len(event_ids_set)
+    )
+    if (
+        instance.use_legacy_events_index
+        and (
+            states := session.query(States.state_id)
+            .filter(States.event_id.in_(event_ids_set))
             .all()
         )
-    )
-    _LOGGER.debug(
-        "Selected %s event_ids to remove that should be filtered", len(event_ids)
-    )
-    states: list[States] = (
-        session.query(States.state_id).filter(States.event_id.in_(event_ids)).all()
-    )
-    state_ids: set[int] = {state.state_id for state in states}
-    _purge_state_ids(instance, session, state_ids)
-    _purge_event_ids(session, event_ids)
+        and (state_ids := {state.state_id for state in states})
+    ):
+        # These are legacy states that are linked to an event that are no longer
+        # created but since we did not remove them when we stopped adding new ones
+        # we will need to purge them here.
+        _purge_state_ids(instance, session, state_ids)
+    _purge_event_ids(session, event_ids_set)
     if unused_data_ids_set := _select_unused_event_data_ids(
         session, set(data_ids), database_engine
     ):
         _purge_batch_data_ids(instance, session, unused_data_ids_set)
-    if EVENT_STATE_CHANGED in excluded_event_types:
-        session.query(StateAttributes).delete(synchronize_session=False)
-        instance._state_attributes_ids = {}  # pylint: disable=protected-access
+    return False
 
 
-@retryable_database_job("purge")
-def purge_entity_data(instance: Recorder, entity_filter: Callable[[str], bool]) -> bool:
+@retryable_database_job("purge_entity_data")
+def purge_entity_data(
+    instance: Recorder, entity_filter: Callable[[str], bool], purge_before: datetime
+) -> bool:
     """Purge states and events of specified entities."""
     database_engine = instance.database_engine
     assert database_engine is not None
+    purge_before_timestamp = purge_before.timestamp()
     with session_scope(session=instance.get_session()) as session:
-        selected_entity_ids: list[str] = [
-            entity_id
-            for (entity_id,) in session.query(distinct(States.entity_id)).all()
+        selected_metadata_ids: list[str] = [
+            metadata_id
+            for (metadata_id, entity_id) in session.query(
+                StatesMeta.metadata_id, StatesMeta.entity_id
+            ).all()
             if entity_filter(entity_id)
         ]
-        _LOGGER.debug("Purging entity data for %s", selected_entity_ids)
-        if len(selected_entity_ids) > 0:
-            # Purge a max of MAX_ROWS_TO_PURGE, based on the oldest states
-            # or events record.
-            _purge_filtered_states(
-                instance, session, selected_entity_ids, database_engine
-            )
+        _LOGGER.debug("Purging entity data for %s", selected_metadata_ids)
+        if not selected_metadata_ids:
+            return True
+
+        # Purge a max of SQLITE_MAX_BIND_VARS, based on the oldest states
+        # or events record.
+        if not _purge_filtered_states(
+            instance,
+            session,
+            selected_metadata_ids,
+            database_engine,
+            purge_before_timestamp,
+        ):
             _LOGGER.debug("Purging entity data hasn't fully completed yet")
             return False
 
