@@ -1,8 +1,10 @@
-"""This component provides support for Reolink IP cameras."""
+"""Component providing support for Reolink IP cameras."""
 from __future__ import annotations
 
 import logging
 
+from reolink_aio.api import DUAL_LENS_MODELS
+
 from homeassistant.components.camera import Camera, CameraEntityFeature
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
@@ -10,7 +12,7 @@ from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from . import ReolinkData
 from .const import DOMAIN
-from .entity import ReolinkCoordinatorEntity
+from .entity import ReolinkChannelCoordinatorEntity
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -25,7 +27,7 @@ async def async_setup_entry(
     host = reolink_data.host
 
     cameras = []
-    for channel in host.api.channels:
+    for channel in host.api.stream_channels:
         streams = ["sub", "main", "snapshots"]
         if host.api.protocol in ["rtmp", "flv"]:
             streams.append("ext")
@@ -39,7 +41,7 @@ async def async_setup_entry(
     async_add_entities(cameras)
 
 
-class ReolinkCamera(ReolinkCoordinatorEntity, Camera):
+class ReolinkCamera(ReolinkChannelCoordinatorEntity, Camera):
     """An implementation of a Reolink IP camera."""
 
     _attr_supported_features: CameraEntityFeature = CameraEntityFeature.STREAM
@@ -51,12 +53,15 @@ class ReolinkCamera(ReolinkCoordinatorEntity, Camera):
         stream: str,
     ) -> None:
         """Initialize Reolink camera stream."""
-        ReolinkCoordinatorEntity.__init__(self, reolink_data, channel)
+        ReolinkChannelCoordinatorEntity.__init__(self, reolink_data, channel)
         Camera.__init__(self)
 
         self._stream = stream
 
-        self._attr_name = self._stream
+        if self._host.api.model in DUAL_LENS_MODELS:
+            self._attr_name = f"{self._stream} lens {self._channel}"
+        else:
+            self._attr_name = self._stream
         self._attr_unique_id = f"{self._host.unique_id}_{self._channel}_{self._stream}"
         self._attr_entity_registry_enabled_default = stream == "sub"
 
