@@ -1,4 +1,4 @@
-"""This component provides support to the Ring Door Bell camera."""
+"""Component providing support to the Ring Door Bell camera."""
 from __future__ import annotations
 
 from datetime import timedelta
@@ -60,7 +60,7 @@ class RingCam(RingEntityMixin, Camera):
         self._image = None
         self._expires_at = dt_util.utcnow() - FORCE_REFRESH_INTERVAL
 
-    async def async_added_to_hass(self):
+    async def async_added_to_hass(self) -> None:
         """Register callbacks."""
         await super().async_added_to_hass()
 
@@ -68,7 +68,7 @@ class RingCam(RingEntityMixin, Camera):
             self._device, self._history_update_callback
         )
 
-    async def async_will_remove_from_hass(self):
+    async def async_will_remove_from_hass(self) -> None:
         """Disconnect callbacks."""
         await super().async_will_remove_from_hass()
 
@@ -144,7 +144,7 @@ class RingCam(RingEntityMixin, Camera):
         finally:
             await stream.close()
 
-    async def async_update(self):
+    async def async_update(self) -> None:
         """Update camera entity and refresh attributes."""
         if self._last_event is None:
             return
