@@ -1,42 +1,23 @@
 """Support for getting data from websites with scraping."""
 from __future__ import annotations
 
-from datetime import timedelta
 import logging
-from typing import Any
+from typing import Any, cast
 
 import voluptuous as vol
 
-from homeassistant.components.rest import RESOURCE_SCHEMA, create_rest_data_from_config
-from homeassistant.components.sensor import (
-    CONF_STATE_CLASS,
-    DEVICE_CLASSES_SCHEMA,
-    PLATFORM_SCHEMA as PARENT_PLATFORM_SCHEMA,
-    STATE_CLASSES_SCHEMA,
-)
+from homeassistant.components.sensor import SensorDeviceClass
+from homeassistant.components.sensor.helpers import async_parse_date_datetime
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     CONF_ATTRIBUTE,
-    CONF_AUTHENTICATION,
-    CONF_DEVICE_CLASS,
-    CONF_HEADERS,
     CONF_NAME,
-    CONF_PASSWORD,
-    CONF_RESOURCE,
-    CONF_SCAN_INTERVAL,
     CONF_UNIQUE_ID,
-    CONF_UNIT_OF_MEASUREMENT,
-    CONF_USERNAME,
     CONF_VALUE_TEMPLATE,
-    CONF_VERIFY_SSL,
-    HTTP_BASIC_AUTHENTICATION,
-    HTTP_DIGEST_AUTHENTICATION,
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import PlatformNotReady
-import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.issue_registry import IssueSeverity, async_create_issue
 from homeassistant.helpers.template import Template
 from homeassistant.helpers.template_entity import (
     TEMPLATE_SENSOR_BASE_SCHEMA,
@@ -45,43 +26,11 @@ from homeassistant.helpers.template_entity import (
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
-from .const import (
-    CONF_INDEX,
-    CONF_SELECT,
-    DEFAULT_NAME,
-    DEFAULT_SCAN_INTERVAL,
-    DEFAULT_VERIFY_SSL,
-    DOMAIN,
-)
+from .const import CONF_INDEX, CONF_SELECT, DOMAIN
 from .coordinator import ScrapeCoordinator
 
 _LOGGER = logging.getLogger(__name__)
 
-PLATFORM_SCHEMA = PARENT_PLATFORM_SCHEMA.extend(
-    {
-        # Linked to the loading of the page (can be linked to RestData)
-        vol.Optional(CONF_AUTHENTICATION): vol.In(
-            [HTTP_BASIC_AUTHENTICATION, HTTP_DIGEST_AUTHENTICATION]
-        ),
-        vol.Optional(CONF_HEADERS): vol.Schema({cv.string: cv.string}),
-        vol.Optional(CONF_PASSWORD): cv.string,
-        vol.Required(CONF_RESOURCE): cv.string,
-        vol.Optional(CONF_USERNAME): cv.string,
-        vol.Optional(CONF_VERIFY_SSL, default=DEFAULT_VERIFY_SSL): cv.boolean,
-        # Linked to the parsing of the page (specific to scrape)
-        vol.Optional(CONF_ATTRIBUTE): cv.string,
-        vol.Optional(CONF_INDEX, default=0): cv.positive_int,
-        vol.Required(CONF_SELECT): cv.string,
-        vol.Optional(CONF_VALUE_TEMPLATE): cv.template,
-        # Linked to the sensor definition (can be linked to TemplateSensor)
-        vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
-        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-        vol.Optional(CONF_STATE_CLASS): STATE_CLASSES_SCHEMA,
-        vol.Optional(CONF_UNIQUE_ID): cv.string,
-        vol.Optional(CONF_UNIT_OF_MEASUREMENT): cv.string,
-    }
-)
-
 
 async def async_setup_platform(
     hass: HomeAssistant,
@@ -90,33 +39,9 @@ async def async_setup_platform(
     discovery_info: DiscoveryInfoType | None = None,
 ) -> None:
     """Set up the Web scrape sensor."""
-    coordinator: ScrapeCoordinator
-    sensors_config: list[ConfigType]
-    if discovery_info is None:
-        async_create_issue(
-            hass,
-            DOMAIN,
-            "moved_yaml",
-            breaks_in_ha_version="2022.12.0",
-            is_fixable=False,
-            severity=IssueSeverity.WARNING,
-            translation_key="moved_yaml",
-        )
-        resource_config = vol.Schema(RESOURCE_SCHEMA, extra=vol.REMOVE_EXTRA)(config)
-        rest = create_rest_data_from_config(hass, resource_config)
-
-        scan_interval: timedelta = config.get(CONF_SCAN_INTERVAL, DEFAULT_SCAN_INTERVAL)
-        coordinator = ScrapeCoordinator(hass, rest, scan_interval)
-
-        sensors_config = [
-            vol.Schema(TEMPLATE_SENSOR_BASE_SCHEMA.schema, extra=vol.ALLOW_EXTRA)(
-                config
-            )
-        ]
-
-    else:
-        coordinator = discovery_info["coordinator"]
-        sensors_config = discovery_info["configs"]
+    discovery_info = cast(DiscoveryInfoType, discovery_info)
+    coordinator: ScrapeCoordinator = discovery_info["coordinator"]
+    sensors_config: list[ConfigType] = discovery_info["configs"]
 
     await coordinator.async_refresh()
     if coordinator.data is None:
@@ -246,12 +171,19 @@ class ScrapeSensor(CoordinatorEntity[ScrapeCoordinator], TemplateSensor):
         """Update state from the rest data."""
         value = self._extract_value()
 
-        if self._value_template is not None:
-            self._attr_native_value = (
-                self._value_template.async_render_with_possible_json_value(value, None)
-            )
-        else:
+        if (template := self._value_template) is not None:
+            value = template.async_render_with_possible_json_value(value, None)
+
+        if self.device_class not in {
+            SensorDeviceClass.DATE,
+            SensorDeviceClass.TIMESTAMP,
+        }:
             self._attr_native_value = value
+            return
+
+        self._attr_native_value = async_parse_date_datetime(
+            value, self.entity_id, self.device_class
+        )
 
     @callback
     def _handle_coordinator_update(self) -> None:
