@@ -1,15 +1,21 @@
 """Support for a ScreenLogic 'circuit' switch."""
 import logging
 
-from screenlogicpy.const import DATA as SL_DATA, GENERIC_CIRCUIT_NAMES
+from screenlogicpy.const import (
+    CODE,
+    DATA as SL_DATA,
+    GENERIC_CIRCUIT_NAMES,
+    INTERFACE_GROUP,
+)
 
 from homeassistant.components.switch import SwitchEntity
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
-from . import ScreenLogicCircuitEntity
+from . import ScreenlogicDataUpdateCoordinator
 from .const import DOMAIN, LIGHT_CIRCUIT_FUNCTIONS
+from .entity import ScreenLogicCircuitEntity
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -20,13 +26,20 @@ async def async_setup_entry(
     async_add_entities: AddEntitiesCallback,
 ) -> None:
     """Set up entry."""
-    coordinator = hass.data[DOMAIN][config_entry.entry_id]
+    coordinator: ScreenlogicDataUpdateCoordinator = hass.data[DOMAIN][
+        config_entry.entry_id
+    ]
+    circuits = coordinator.gateway_data[SL_DATA.KEY_CIRCUITS]
     async_add_entities(
         [
             ScreenLogicSwitch(
-                coordinator, circuit_num, circuit["name"] not in GENERIC_CIRCUIT_NAMES
+                coordinator,
+                circuit_num,
+                CODE.STATUS_CHANGED,
+                circuit["name"] not in GENERIC_CIRCUIT_NAMES
+                and circuit["interface"] != INTERFACE_GROUP.DONT_SHOW,
             )
-            for circuit_num, circuit in coordinator.data[SL_DATA.KEY_CIRCUITS].items()
+            for circuit_num, circuit in circuits.items()
             if circuit["function"] not in LIGHT_CIRCUIT_FUNCTIONS
         ]
     )
