@@ -10,7 +10,7 @@ import voluptuous as vol
 from homeassistant.components import automation, group, person, script, websocket_api
 from homeassistant.components.homeassistant import scene
 from homeassistant.core import HomeAssistant, callback, split_entity_id
-from homeassistant.helpers import device_registry, entity_registry
+from homeassistant.helpers import device_registry as dr, entity_registry as er
 from homeassistant.helpers.entity import entity_sources as get_entity_sources
 from homeassistant.helpers.typing import ConfigType
 
@@ -53,8 +53,8 @@ def websocket_search_related(
     """Handle search."""
     searcher = Searcher(
         hass,
-        device_registry.async_get(hass),
-        entity_registry.async_get(hass),
+        dr.async_get(hass),
+        er.async_get(hass),
         get_entity_sources(hass),
     )
     connection.send_result(
@@ -86,8 +86,8 @@ class Searcher:
     def __init__(
         self,
         hass: HomeAssistant,
-        device_reg: device_registry.DeviceRegistry,
-        entity_reg: entity_registry.EntityRegistry,
+        device_reg: dr.DeviceRegistry,
+        entity_reg: er.EntityRegistry,
         entity_sources: dict[str, dict[str, str]],
     ) -> None:
         """Search results."""
@@ -141,12 +141,10 @@ class Searcher:
     @callback
     def _resolve_area(self, area_id) -> None:
         """Resolve an area."""
-        for device in device_registry.async_entries_for_area(self._device_reg, area_id):
+        for device in dr.async_entries_for_area(self._device_reg, area_id):
             self._add_or_resolve("device", device.id)
 
-        for entity_entry in entity_registry.async_entries_for_area(
-            self._entity_reg, area_id
-        ):
+        for entity_entry in er.async_entries_for_area(self._entity_reg, area_id):
             self._add_or_resolve("entity", entity_entry.entity_id)
 
         for entity_id in script.scripts_with_area(self.hass, area_id):
@@ -178,12 +176,12 @@ class Searcher:
 
         Will only be called if config entry is an entry point.
         """
-        for device_entry in device_registry.async_entries_for_config_entry(
+        for device_entry in dr.async_entries_for_config_entry(
             self._device_reg, config_entry_id
         ):
             self._add_or_resolve("device", device_entry.id)
 
-        for entity_entry in entity_registry.async_entries_for_config_entry(
+        for entity_entry in er.async_entries_for_config_entry(
             self._entity_reg, config_entry_id
         ):
             self._add_or_resolve("entity", entity_entry.entity_id)
@@ -203,9 +201,7 @@ class Searcher:
             # We do not resolve device_entry.via_device_id because that
             # device is not related data-wise inside HA.
 
-        for entity_entry in entity_registry.async_entries_for_device(
-            self._entity_reg, device_id
-        ):
+        for entity_entry in er.async_entries_for_device(self._entity_reg, device_id):
             self._add_or_resolve("entity", entity_entry.entity_id)
 
         for entity_id in script.scripts_with_device(self.hass, device_id):
