@@ -2,12 +2,13 @@
 from __future__ import annotations
 
 import logging
+from typing import cast
 
 from homeassistant.components.number import NumberEntity
 from homeassistant.config_entries import ConfigEntry
+from homeassistant.const import EntityCategory
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
-from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import SONOS_CREATE_LEVELS
@@ -18,15 +19,52 @@ from .speaker import SonosSpeaker
 LEVEL_TYPES = {
     "audio_delay": (0, 5),
     "bass": (-10, 10),
+    "balance": (-100, 100),
     "treble": (-10, 10),
     "sub_gain": (-15, 15),
     "surround_level": (-15, 15),
     "music_surround_level": (-15, 15),
 }
 
+SocoFeatures = list[tuple[str, tuple[int, int]]]
+
 _LOGGER = logging.getLogger(__name__)
 
 
+def _balance_to_number(state: tuple[int, int]) -> float:
+    """Represent a balance measure returned by SoCo as a number.
+
+    SoCo returns a pair of volumes, one for the left side and one
+    for the right side. When the two are equal, sound is centered;
+    HA will show that as 0. When the left side is louder, HA will
+    show a negative value, and a positive value means the right
+    side is louder. Maximum absolute value is 100, which means only
+    one side produces sound at all.
+    """
+    left, right = state
+    return (right - left) * 100 // max(right, left)
+
+
+def _balance_from_number(value: float) -> tuple[int, int]:
+    """Convert a balance value from -100 to 100 into SoCo format.
+
+    0 becomes (100, 100), fully enabling both sides. Note that
+    the master volume control is separate, so this does not
+    turn up the speakers to maximum volume. Negative values
+    reduce the volume of the right side, and positive values
+    reduce the volume of the left side. -100 becomes (100, 0),
+    fully muting the right side, and +100 becomes (0, 100),
+    muting the left side.
+    """
+    left = min(100, 100 - int(value))
+    right = min(100, int(value) + 100)
+    return left, right
+
+
+LEVEL_TO_NUMBER = {"balance": _balance_to_number}
+LEVEL_FROM_NUMBER = {"balance": _balance_from_number}
+
+
 async def async_setup_entry(
     hass: HomeAssistant,
     config_entry: ConfigEntry,
@@ -34,8 +72,8 @@ async def async_setup_entry(
 ) -> None:
     """Set up the Sonos number platform from a config entry."""
 
-    def available_soco_attributes(speaker: SonosSpeaker) -> list[str]:
-        features = []
+    def available_soco_attributes(speaker: SonosSpeaker) -> SocoFeatures:
+        features: SocoFeatures = []
         for level_type, valid_range in LEVEL_TYPES.items():
             if (state := getattr(speaker.soco, level_type, None)) is not None:
                 setattr(speaker, level_type, state)
@@ -67,7 +105,7 @@ class SonosLevelEntity(SonosEntity, NumberEntity):
     _attr_entity_category = EntityCategory.CONFIG
 
     def __init__(
-        self, speaker: SonosSpeaker, level_type: str, valid_range: tuple[int]
+        self, speaker: SonosSpeaker, level_type: str, valid_range: tuple[int, int]
     ) -> None:
         """Initialize the level entity."""
         super().__init__(speaker)
@@ -89,9 +127,11 @@ class SonosLevelEntity(SonosEntity, NumberEntity):
     @soco_error()
     def set_native_value(self, value: float) -> None:
         """Set a new value."""
-        setattr(self.soco, self.level_type, value)
+        from_number = LEVEL_FROM_NUMBER.get(self.level_type, int)
+        setattr(self.soco, self.level_type, from_number(value))
 
     @property
     def native_value(self) -> float:
         """Return the current value."""
-        return getattr(self.speaker, self.level_type)
+        to_number = LEVEL_TO_NUMBER.get(self.level_type, int)
+        return cast(float, to_number(getattr(self.speaker, self.level_type)))
