@@ -6,12 +6,12 @@ from typing import Any
 
 import sqlalchemy
 from sqlalchemy.engine import Result
-from sqlalchemy.exc import SQLAlchemyError
+from sqlalchemy.exc import NoSuchColumnError, SQLAlchemyError
 from sqlalchemy.orm import Session, scoped_session, sessionmaker
 import voluptuous as vol
 
 from homeassistant import config_entries
-from homeassistant.components.recorder import CONF_DB_URL
+from homeassistant.components.recorder import CONF_DB_URL, get_instance
 from homeassistant.const import CONF_NAME, CONF_UNIT_OF_MEASUREMENT, CONF_VALUE_TEMPLATE
 from homeassistant.core import callback
 from homeassistant.data_entry_flow import FlowResult
@@ -22,19 +22,32 @@ from .util import resolve_db_url
 
 _LOGGER = logging.getLogger(__name__)
 
-DATA_SCHEMA = vol.Schema(
+OPTIONS_SCHEMA: vol.Schema = vol.Schema(
     {
-        vol.Required(CONF_NAME, default="Select SQL Query"): selector.TextSelector(),
-        vol.Optional(CONF_DB_URL): selector.TextSelector(),
-        vol.Required(CONF_COLUMN_NAME): selector.TextSelector(),
-        vol.Required(CONF_QUERY): selector.TextSelector(
-            selector.TextSelectorConfig(multiline=True)
-        ),
-        vol.Optional(CONF_UNIT_OF_MEASUREMENT): selector.TextSelector(),
-        vol.Optional(CONF_VALUE_TEMPLATE): selector.TemplateSelector(),
+        vol.Optional(
+            CONF_DB_URL,
+        ): selector.TextSelector(),
+        vol.Required(
+            CONF_COLUMN_NAME,
+        ): selector.TextSelector(),
+        vol.Required(
+            CONF_QUERY,
+        ): selector.TextSelector(selector.TextSelectorConfig(multiline=True)),
+        vol.Optional(
+            CONF_UNIT_OF_MEASUREMENT,
+        ): selector.TextSelector(),
+        vol.Optional(
+            CONF_VALUE_TEMPLATE,
+        ): selector.TemplateSelector(),
     }
 )
 
+CONFIG_SCHEMA: vol.Schema = vol.Schema(
+    {
+        vol.Required(CONF_NAME, default="Select SQL Query"): selector.TextSelector(),
+    }
+).extend(OPTIONS_SCHEMA.schema)
+
 
 def validate_sql_select(value: str) -> str | None:
     """Validate that value is a SQL SELECT query."""
@@ -56,14 +69,23 @@ def validate_query(db_url: str, query: str, column: str) -> bool:
         _LOGGER.debug("Execution error %s", error)
         if sess:
             sess.close()
+            engine.dispose()
         raise ValueError(error) from error
 
     for res in result.mappings():
+        if column not in res:
+            _LOGGER.debug("Column `%s` is not returned by the query", column)
+            if sess:
+                sess.close()
+                engine.dispose()
+            raise NoSuchColumnError(f"Column {column} is not returned by the query.")
+
         data = res[column]
         _LOGGER.debug("Return value from query: %s", data)
 
     if sess:
         sess.close()
+        engine.dispose()
 
     return True
 
@@ -86,6 +108,7 @@ class SQLConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
     ) -> FlowResult:
         """Handle the user step."""
         errors = {}
+        description_placeholders = {}
 
         if user_input is not None:
             db_url = user_input.get(CONF_DB_URL)
@@ -102,6 +125,9 @@ class SQLConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
                 await self.hass.async_add_executor_job(
                     validate_query, db_url_for_validation, query, column
                 )
+            except NoSuchColumnError:
+                errors["column"] = "column_invalid"
+                description_placeholders = {"column": column}
             except SQLAlchemyError:
                 errors["db_url"] = "db_url_invalid"
             except ValueError:
@@ -127,29 +153,27 @@ class SQLConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
 
         return self.async_show_form(
             step_id="user",
-            data_schema=DATA_SCHEMA,
+            data_schema=self.add_suggested_values_to_schema(CONFIG_SCHEMA, user_input),
             errors=errors,
+            description_placeholders=description_placeholders,
         )
 
 
-class SQLOptionsFlowHandler(config_entries.OptionsFlow):
+class SQLOptionsFlowHandler(config_entries.OptionsFlowWithConfigEntry):
     """Handle SQL options."""
 
-    def __init__(self, entry: config_entries.ConfigEntry) -> None:
-        """Initialize SQL options flow."""
-        self.entry = entry
-
     async def async_step_init(
         self, user_input: dict[str, Any] | None = None
     ) -> FlowResult:
         """Manage SQL options."""
         errors = {}
+        description_placeholders = {}
 
         if user_input is not None:
             db_url = user_input.get(CONF_DB_URL)
             query = user_input[CONF_QUERY]
             column = user_input[CONF_COLUMN_NAME]
-            name = self.entry.options.get(CONF_NAME, self.entry.title)
+            name = self.options.get(CONF_NAME, self.config_entry.title)
 
             try:
                 validate_sql_select(query)
@@ -157,61 +181,35 @@ class SQLOptionsFlowHandler(config_entries.OptionsFlow):
                 await self.hass.async_add_executor_job(
                     validate_query, db_url_for_validation, query, column
                 )
+            except NoSuchColumnError:
+                errors["column"] = "column_invalid"
+                description_placeholders = {"column": column}
             except SQLAlchemyError:
                 errors["db_url"] = "db_url_invalid"
             except ValueError:
                 errors["query"] = "query_invalid"
             else:
-                new_user_input = user_input
-                if new_user_input.get(CONF_DB_URL) and db_url == db_url_for_validation:
-                    new_user_input.pop(CONF_DB_URL)
+                recorder_db = get_instance(self.hass).db_url
+                _LOGGER.debug(
+                    "db_url: %s, resolved db_url: %s, recorder: %s",
+                    db_url,
+                    db_url_for_validation,
+                    recorder_db,
+                )
+                if db_url and db_url_for_validation == recorder_db:
+                    user_input.pop(CONF_DB_URL)
                 return self.async_create_entry(
-                    title="",
                     data={
                         CONF_NAME: name,
-                        **new_user_input,
+                        **user_input,
                     },
                 )
 
         return self.async_show_form(
             step_id="init",
-            data_schema=vol.Schema(
-                {
-                    vol.Optional(
-                        CONF_DB_URL,
-                        description={
-                            "suggested_value": self.entry.options.get(CONF_DB_URL)
-                        },
-                    ): selector.TextSelector(),
-                    vol.Required(
-                        CONF_QUERY,
-                        description={"suggested_value": self.entry.options[CONF_QUERY]},
-                    ): selector.TextSelector(
-                        selector.TextSelectorConfig(multiline=True)
-                    ),
-                    vol.Required(
-                        CONF_COLUMN_NAME,
-                        description={
-                            "suggested_value": self.entry.options[CONF_COLUMN_NAME]
-                        },
-                    ): selector.TextSelector(),
-                    vol.Optional(
-                        CONF_UNIT_OF_MEASUREMENT,
-                        description={
-                            "suggested_value": self.entry.options.get(
-                                CONF_UNIT_OF_MEASUREMENT
-                            )
-                        },
-                    ): selector.TextSelector(),
-                    vol.Optional(
-                        CONF_VALUE_TEMPLATE,
-                        description={
-                            "suggested_value": self.entry.options.get(
-                                CONF_VALUE_TEMPLATE
-                            )
-                        },
-                    ): selector.TemplateSelector(),
-                }
+            data_schema=self.add_suggested_values_to_schema(
+                OPTIONS_SCHEMA, user_input or self.options
             ),
             errors=errors,
+            description_placeholders=description_placeholders,
         )
