@@ -4,6 +4,7 @@ from http import HTTPStatus
 import logging
 from typing import TYPE_CHECKING
 
+import async_timeout
 from pysqueezebox import Server, async_discover
 import voluptuous as vol
 
@@ -130,7 +131,8 @@ class SqueezeboxConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
 
         # no host specified, see if we can discover an unconfigured LMS server
         try:
-            await asyncio.wait_for(self._discover(), timeout=TIMEOUT)
+            async with async_timeout.timeout(TIMEOUT):
+                await self._discover()
             return await self.async_step_edit()
         except asyncio.TimeoutError:
             errors["base"] = "no_server_found"
