@@ -1,7 +1,11 @@
 """Light support for switch entities."""
 from __future__ import annotations
 
-from homeassistant.components.light import ColorMode, LightEntity
+from homeassistant.components.light import (
+    DOMAIN as LIGHT_DOMAIN,
+    ColorMode,
+    LightEntity,
+)
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_ENTITY_ID
 from homeassistant.core import HomeAssistant
@@ -27,6 +31,7 @@ async def async_setup_entry(
             LightSwitch(
                 hass,
                 config_entry.title,
+                LIGHT_DOMAIN,
                 entity_id,
                 config_entry.entry_id,
             )
