@@ -3,7 +3,6 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 from datetime import datetime, timedelta
-from typing import Any
 
 from synology_dsm.api.core.utilization import SynoCoreUtilization
 from synology_dsm.api.dsm.information import SynoDSMInformation
@@ -26,6 +25,7 @@ from homeassistant.const import (
 )
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.typing import StateType
 from homeassistant.util.dt import utcnow
 
 from . import SynoApi
@@ -50,7 +50,7 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="cpu_other_load",
-        name="CPU Utilization (Other)",
+        translation_key="cpu_other_load",
         native_unit_of_measurement=PERCENTAGE,
         icon="mdi:chip",
         entity_registry_enabled_default=False,
@@ -59,7 +59,7 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="cpu_user_load",
-        name="CPU Utilization (User)",
+        translation_key="cpu_user_load",
         native_unit_of_measurement=PERCENTAGE,
         icon="mdi:chip",
         state_class=SensorStateClass.MEASUREMENT,
@@ -67,7 +67,7 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="cpu_system_load",
-        name="CPU Utilization (System)",
+        translation_key="cpu_system_load",
         native_unit_of_measurement=PERCENTAGE,
         icon="mdi:chip",
         entity_registry_enabled_default=False,
@@ -76,7 +76,7 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="cpu_total_load",
-        name="CPU Utilization (Total)",
+        translation_key="cpu_total_load",
         native_unit_of_measurement=PERCENTAGE,
         icon="mdi:chip",
         state_class=SensorStateClass.MEASUREMENT,
@@ -84,7 +84,7 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="cpu_1min_load",
-        name="CPU Load Average (1 min)",
+        translation_key="cpu_1min_load",
         native_unit_of_measurement=ENTITY_UNIT_LOAD,
         icon="mdi:chip",
         entity_registry_enabled_default=False,
@@ -92,21 +92,21 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="cpu_5min_load",
-        name="CPU Load Average (5 min)",
+        translation_key="cpu_5min_load",
         native_unit_of_measurement=ENTITY_UNIT_LOAD,
         icon="mdi:chip",
     ),
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="cpu_15min_load",
-        name="CPU Load Average (15 min)",
+        translation_key="cpu_15min_load",
         native_unit_of_measurement=ENTITY_UNIT_LOAD,
         icon="mdi:chip",
     ),
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="memory_real_usage",
-        name="Memory Usage (Real)",
+        translation_key="memory_real_usage",
         native_unit_of_measurement=PERCENTAGE,
         icon="mdi:memory",
         state_class=SensorStateClass.MEASUREMENT,
@@ -114,8 +114,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="memory_size",
-        name="Memory Size",
-        native_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        translation_key="memory_size",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:memory",
         entity_registry_enabled_default=False,
@@ -124,8 +126,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="memory_cached",
-        name="Memory Cached",
-        native_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        translation_key="memory_cached",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:memory",
         entity_registry_enabled_default=False,
@@ -134,8 +138,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="memory_available_swap",
-        name="Memory Available (Swap)",
-        native_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        translation_key="memory_available_swap",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:memory",
         state_class=SensorStateClass.MEASUREMENT,
@@ -143,8 +149,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="memory_available_real",
-        name="Memory Available (Real)",
-        native_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        translation_key="memory_available_real",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:memory",
         state_class=SensorStateClass.MEASUREMENT,
@@ -152,8 +160,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="memory_total_swap",
-        name="Memory Total (Swap)",
-        native_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        translation_key="memory_total_swap",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:memory",
         state_class=SensorStateClass.MEASUREMENT,
@@ -161,8 +171,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="memory_total_real",
-        name="Memory Total (Real)",
-        native_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        translation_key="memory_total_real",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.MEGABYTES,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:memory",
         state_class=SensorStateClass.MEASUREMENT,
@@ -170,8 +182,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="network_up",
-        name="Upload Throughput",
-        native_unit_of_measurement=UnitOfDataRate.KILOBYTES_PER_SECOND,
+        translation_key="network_up",
+        native_unit_of_measurement=UnitOfDataRate.BYTES_PER_SECOND,
+        suggested_unit_of_measurement=UnitOfDataRate.KILOBYTES_PER_SECOND,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_RATE,
         icon="mdi:upload",
         state_class=SensorStateClass.MEASUREMENT,
@@ -179,8 +193,10 @@ UTILISATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoCoreUtilization.API_KEY,
         key="network_down",
-        name="Download Throughput",
-        native_unit_of_measurement=UnitOfDataRate.KILOBYTES_PER_SECOND,
+        translation_key="network_down",
+        native_unit_of_measurement=UnitOfDataRate.BYTES_PER_SECOND,
+        suggested_unit_of_measurement=UnitOfDataRate.KILOBYTES_PER_SECOND,
+        suggested_display_precision=1,
         device_class=SensorDeviceClass.DATA_RATE,
         icon="mdi:download",
         state_class=SensorStateClass.MEASUREMENT,
@@ -190,14 +206,16 @@ STORAGE_VOL_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="volume_status",
-        name="Status",
+        translation_key="volume_status",
         icon="mdi:checkbox-marked-circle-outline",
     ),
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="volume_size_total",
-        name="Total Size",
-        native_unit_of_measurement=UnitOfInformation.TERABYTES,
+        translation_key="volume_size_total",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.TERABYTES,
+        suggested_display_precision=2,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:chart-pie",
         entity_registry_enabled_default=False,
@@ -206,8 +224,10 @@ STORAGE_VOL_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="volume_size_used",
-        name="Used Space",
-        native_unit_of_measurement=UnitOfInformation.TERABYTES,
+        translation_key="volume_size_used",
+        native_unit_of_measurement=UnitOfInformation.BYTES,
+        suggested_unit_of_measurement=UnitOfInformation.TERABYTES,
+        suggested_display_precision=2,
         device_class=SensorDeviceClass.DATA_SIZE,
         icon="mdi:chart-pie",
         state_class=SensorStateClass.MEASUREMENT,
@@ -215,14 +235,14 @@ STORAGE_VOL_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="volume_percentage_used",
-        name="Volume Used",
+        translation_key="volume_percentage_used",
         native_unit_of_measurement=PERCENTAGE,
         icon="mdi:chart-pie",
     ),
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="volume_disk_temp_avg",
-        name="Average Disk Temp",
+        translation_key="volume_disk_temp_avg",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         entity_category=EntityCategory.DIAGNOSTIC,
@@ -230,7 +250,7 @@ STORAGE_VOL_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="volume_disk_temp_max",
-        name="Maximum Disk Temp",
+        translation_key="volume_disk_temp_max",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         entity_registry_enabled_default=False,
@@ -241,7 +261,7 @@ STORAGE_DISK_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="disk_smart_status",
-        name="Status (Smart)",
+        translation_key="disk_smart_status",
         icon="mdi:checkbox-marked-circle-outline",
         entity_registry_enabled_default=False,
         entity_category=EntityCategory.DIAGNOSTIC,
@@ -249,14 +269,14 @@ STORAGE_DISK_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="disk_status",
-        name="Status",
+        translation_key="disk_status",
         icon="mdi:checkbox-marked-circle-outline",
         entity_category=EntityCategory.DIAGNOSTIC,
     ),
     SynologyDSMSensorEntityDescription(
         api_key=SynoStorage.API_KEY,
         key="disk_temp",
-        name="Temperature",
+        translation_key="disk_temp",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
@@ -268,7 +288,7 @@ INFORMATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoDSMInformation.API_KEY,
         key="temperature",
-        name="Temperature",
+        translation_key="temperature",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
@@ -277,7 +297,7 @@ INFORMATION_SENSORS: tuple[SynologyDSMSensorEntityDescription, ...] = (
     SynologyDSMSensorEntityDescription(
         api_key=SynoDSMInformation.API_KEY,
         key="uptime",
-        name="Last Boot",
+        translation_key="uptime",
         device_class=SensorDeviceClass.TIMESTAMP,
         entity_registry_enabled_default=False,
         entity_category=EntityCategory.DIAGNOSTIC,
@@ -349,27 +369,20 @@ class SynoDSMUtilSensor(SynoDSMSensor):
     """Representation a Synology Utilisation sensor."""
 
     @property
-    def native_value(self) -> Any | None:
+    def native_value(self) -> StateType:
         """Return the state."""
         attr = getattr(self._api.utilisation, self.entity_description.key)
         if callable(attr):
             attr = attr()
-        if attr is None:
-            return None
-
-        # Data (RAM)
-        if self.native_unit_of_measurement == UnitOfInformation.MEGABYTES:
-            return round(attr / 1024.0**2, 1)
-
-        # Network
-        if self.native_unit_of_measurement == UnitOfDataRate.KILOBYTES_PER_SECOND:
-            return round(attr / 1024.0, 1)
 
         # CPU load average
-        if self.native_unit_of_measurement == ENTITY_UNIT_LOAD:
+        if (
+            isinstance(attr, int)
+            and self.native_unit_of_measurement == ENTITY_UNIT_LOAD
+        ):
             return round(attr / 100, 2)
 
-        return attr
+        return attr  # type: ignore[no-any-return]
 
     @property
     def available(self) -> bool:
@@ -393,17 +406,10 @@ class SynoDSMStorageSensor(SynologyDSMDeviceEntity, SynoDSMSensor):
         super().__init__(api, coordinator, description, device_id)
 
     @property
-    def native_value(self) -> Any | None:
+    def native_value(self) -> StateType:
         """Return the state."""
         attr = getattr(self._api.storage, self.entity_description.key)(self._device_id)
-        if attr is None:
-            return None
-
-        # Data (disk space)
-        if self.native_unit_of_measurement == UnitOfInformation.TERABYTES:
-            return round(attr / 1024.0**4, 2)
-
-        return attr
+        return attr  # type: ignore[no-any-return]
 
 
 class SynoDSMInfoSensor(SynoDSMSensor):
@@ -421,7 +427,7 @@ class SynoDSMInfoSensor(SynoDSMSensor):
         self._last_boot: datetime | None = None
 
     @property
-    def native_value(self) -> Any | None:
+    def native_value(self) -> StateType | datetime:
         """Return the state."""
         attr = getattr(self._api.information, self.entity_description.key)
         if attr is None:
@@ -434,4 +440,4 @@ class SynoDSMInfoSensor(SynoDSMSensor):
 
             self._previous_uptime = attr
             return self._last_boot
-        return attr
+        return attr  # type: ignore[no-any-return]
