@@ -1,9 +1,7 @@
 """Support for Todoist task management (https://todoist.com)."""
 from __future__ import annotations
 
-import asyncio
 from datetime import date, datetime, timedelta
-from itertools import chain
 import logging
 from typing import Any
 import uuid
@@ -11,7 +9,7 @@ import uuid
 from todoist_api_python.api_async import TodoistAPIAsync
 from todoist_api_python.endpoints import get_sync_url
 from todoist_api_python.headers import create_headers
-from todoist_api_python.models import Label, Task
+from todoist_api_python.models import Due, Label, Task
 import voluptuous as vol
 
 from homeassistant.components.calendar import (
@@ -19,12 +17,13 @@ from homeassistant.components.calendar import (
     CalendarEntity,
     CalendarEvent,
 )
-from homeassistant.const import CONF_ID, CONF_NAME, CONF_TOKEN
-from homeassistant.core import HomeAssistant, ServiceCall
+from homeassistant.const import CONF_ID, CONF_NAME, CONF_TOKEN, EVENT_HOMEASSISTANT_STOP
+from homeassistant.core import Event, HomeAssistant, ServiceCall
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
+from homeassistant.helpers.update_coordinator import CoordinatorEntity
 from homeassistant.util import dt
 
 from .const import (
@@ -56,6 +55,7 @@ from .const import (
     START,
     SUMMARY,
 )
+from .coordinator import TodoistCoordinator
 from .types import CalData, CustomProject, ProjectData, TodoistEvent
 
 _LOGGER = logging.getLogger(__name__)
@@ -117,18 +117,20 @@ async def async_setup_platform(
 
     # Look up IDs based on (lowercase) names.
     project_id_lookup = {}
-    label_id_lookup = {}
-    collaborator_id_lookup = {}
 
     api = TodoistAPIAsync(token)
+    coordinator = TodoistCoordinator(hass, _LOGGER, SCAN_INTERVAL, api)
+    await coordinator.async_config_entry_first_refresh()
+
+    async def _shutdown_coordinator(_: Event) -> None:
+        await coordinator.async_shutdown()
+
+    hass.bus.async_listen_once(EVENT_HOMEASSISTANT_STOP, _shutdown_coordinator)
 
     # Setup devices:
     # Grab all projects.
     projects = await api.get_projects()
 
-    collaborator_tasks = (api.get_collaborators(project.id) for project in projects)
-    collaborators = list(chain.from_iterable(await asyncio.gather(*collaborator_tasks)))
-
     # Grab all labels
     labels = await api.get_labels()
 
@@ -138,17 +140,10 @@ async def async_setup_platform(
         # Project is an object, not a dict!
         # Because of that, we convert what we need to a dict.
         project_data: ProjectData = {CONF_NAME: project.name, CONF_ID: project.id}
-        project_devices.append(TodoistProjectEntity(project_data, labels, api))
+        project_devices.append(TodoistProjectEntity(coordinator, project_data, labels))
         # Cache the names so we can easily look up name->ID.
         project_id_lookup[project.name.lower()] = project.id
 
-    # Cache all label names
-    label_id_lookup = {label.name.lower(): label.id for label in labels}
-
-    collaborator_id_lookup = {
-        collab.name.lower(): collab.id for collab in collaborators
-    }
-
     # Check config for more projects.
     extra_projects: list[CustomProject] = config[CONF_EXTRA_PROJECTS]
     for extra_project in extra_projects:
@@ -171,9 +166,9 @@ async def async_setup_platform(
         # Create the custom project and add it to the devices array.
         project_devices.append(
             TodoistProjectEntity(
+                coordinator,
                 {"id": None, "name": extra_project["name"]},
                 labels,
-                api,
                 due_date_days=project_due_date,
                 whitelisted_labels=project_label_filter,
                 whitelisted_projects=project_id_filter,
@@ -194,14 +189,16 @@ async def async_setup_platform(
         data: dict[str, Any] = {"project_id": project_id}
 
         if task_labels := call.data.get(LABELS):
-            data["label_ids"] = [
-                label_id_lookup[label.lower()] for label in task_labels
-            ]
+            data["labels"] = task_labels
 
         if ASSIGNEE in call.data:
+            collaborators = await api.get_collaborators(project_id)
+            collaborator_id_lookup = {
+                collab.name.lower(): collab.id for collab in collaborators
+            }
             task_assignee = call.data[ASSIGNEE].lower()
             if task_assignee in collaborator_id_lookup:
-                data["assignee"] = collaborator_id_lookup[task_assignee]
+                data["assignee_id"] = collaborator_id_lookup[task_assignee]
             else:
                 raise ValueError(
                     f"User is not part of the shared project. user: {task_assignee}"
@@ -279,23 +276,24 @@ async def async_setup_platform(
     )
 
 
-class TodoistProjectEntity(CalendarEntity):
+class TodoistProjectEntity(CoordinatorEntity[TodoistCoordinator], CalendarEntity):
     """A device for getting the next Task from a Todoist Project."""
 
     def __init__(
         self,
+        coordinator: TodoistCoordinator,
         data: ProjectData,
         labels: list[Label],
-        api: TodoistAPIAsync,
         due_date_days: int | None = None,
         whitelisted_labels: list[str] | None = None,
         whitelisted_projects: list[str] | None = None,
     ) -> None:
         """Create the Todoist Calendar Entity."""
+        super().__init__(coordinator=coordinator)
         self.data = TodoistProjectData(
             data,
             labels,
-            api,
+            coordinator,
             due_date_days=due_date_days,
             whitelisted_labels=whitelisted_labels,
             whitelisted_projects=whitelisted_projects,
@@ -318,6 +316,7 @@ class TodoistProjectEntity(CalendarEntity):
 
     async def async_update(self) -> None:
         """Update all Todoist Calendars."""
+        await super().async_update()
         await self.data.async_update()
         # Set Todoist-specific data that can't easily be grabbed
         self._cal_data["all_tasks"] = [
@@ -385,7 +384,7 @@ class TodoistProjectData:
         self,
         project_data: ProjectData,
         labels: list[Label],
-        api: TodoistAPIAsync,
+        coordinator: TodoistCoordinator,
         due_date_days: int | None = None,
         whitelisted_labels: list[str] | None = None,
         whitelisted_projects: list[str] | None = None,
@@ -393,7 +392,7 @@ class TodoistProjectData:
         """Initialize a Todoist Project."""
         self.event: TodoistEvent | None = None
 
-        self._api = api
+        self._coordinator = coordinator
         self._name = project_data[CONF_NAME]
         # If no ID is defined, fetch all tasks.
         self._id = project_data.get(CONF_ID)
@@ -452,7 +451,7 @@ class TodoistProjectData:
             LABELS: [],
             OVERDUE: False,
             PRIORITY: data.priority,
-            START: dt.utcnow(),
+            START: dt.now(),
             SUMMARY: data.content,
         }
 
@@ -581,8 +580,8 @@ class TodoistProjectData:
         self, start_date: datetime, end_date: datetime
     ) -> list[CalendarEvent]:
         """Get all tasks in a specific time frame."""
+        tasks = self._coordinator.data
         if self._id is None:
-            tasks = await self._api.get_tasks()
             project_task_data = [
                 task
                 for task in tasks
@@ -590,37 +589,31 @@ class TodoistProjectData:
                 or task.project_id in self._project_id_whitelist
             ]
         else:
-            project_task_data = await self._api.get_tasks(project_id=self._id)
+            project_task_data = [task for task in tasks if task.project_id == self._id]
 
         events = []
         for task in project_task_data:
             if task.due is None:
                 continue
-            due_date = dt.parse_datetime(
-                task.due.datetime if task.due.datetime else task.due.date
-            )
-            if not due_date:
+            start = get_start(task.due)
+            if start is None:
                 continue
-            due_date = dt.as_utc(due_date)
-            if start_date < due_date < end_date:
-                due_date_value: datetime | date = due_date
-                midnight = dt.start_of_local_day(due_date)
-                if due_date == midnight:
-                    # If the due date has no time data, return just the date so that it
-                    # will render correctly as an all day event on a calendar.
-                    due_date_value = due_date.date()
-                event = CalendarEvent(
-                    summary=task.content,
-                    start=due_date_value,
-                    end=due_date_value,
-                )
-                events.append(event)
+            event = CalendarEvent(
+                summary=task.content,
+                start=start,
+                end=start + timedelta(days=1),
+            )
+            if event.start_datetime_local >= end_date:
+                continue
+            if event.end_datetime_local < start_date:
+                continue
+            events.append(event)
         return events
 
     async def async_update(self) -> None:
         """Get the latest data."""
+        tasks = self._coordinator.data
         if self._id is None:
-            tasks = await self._api.get_tasks()
             project_task_data = [
                 task
                 for task in tasks
@@ -628,7 +621,7 @@ class TodoistProjectData:
                 or task.project_id in self._project_id_whitelist
             ]
         else:
-            project_task_data = await self._api.get_tasks(project_id=self._id)
+            project_task_data = [task for task in tasks if task.project_id == self._id]
 
         # If we have no data, we can just return right away.
         if not project_task_data:
@@ -669,3 +662,15 @@ class TodoistProjectData:
             return
         self.event = event
         _LOGGER.debug("Updated %s", self._name)
+
+
+def get_start(due: Due) -> datetime | date | None:
+    """Return the task due date as a start date or date time."""
+    if due.datetime:
+        start = dt.parse_datetime(due.datetime)
+        if not start:
+            return None
+        return dt.as_local(start)
+    if due.date:
+        return dt.parse_date(due.date)
+    return None
