@@ -190,9 +190,14 @@ class TuyaVacuumEntity(TuyaEntity, StateVacuumEntity):
         self._send_command([{"code": DPCode.SUCTION, "value": fan_speed}])
 
     def send_command(
-        self, command: str, params: dict | list | None = None, **kwargs: Any
+        self,
+        command: str,
+        params: dict[str, Any] | list[Any] | None = None,
+        **kwargs: Any,
     ) -> None:
         """Send raw command."""
         if not params:
             raise ValueError("Params cannot be omitted for Tuya vacuum commands")
+        if not isinstance(params, list):
+            raise TypeError("Params must be a list for Tuya vacuum commands")
         self._send_command([{"code": command, "value": params[0]}])
