@@ -28,18 +28,13 @@ async def async_setup_entry(
     sensors: list[Entity] = [
         VerisureThermometer(coordinator, serial_number)
         for serial_number, values in coordinator.data["climate"].items()
-        if "temperature" in values
+        if "temperatureValue" in values
     ]
 
     sensors.extend(
         VerisureHygrometer(coordinator, serial_number)
         for serial_number, values in coordinator.data["climate"].items()
-        if "humidity" in values
-    )
-
-    sensors.extend(
-        VerisureMouseDetection(coordinator, serial_number)
-        for serial_number in coordinator.data["mice"]
+        if values.get("humidityEnabled")
     )
 
     async_add_entities(sensors)
@@ -52,7 +47,7 @@ class VerisureThermometer(
 
     _attr_device_class = SensorDeviceClass.TEMPERATURE
     _attr_has_entity_name = True
-    _attr_name = "Temperature"
+    _attr_translation_key = "temperature"
     _attr_native_unit_of_measurement = UnitOfTemperature.CELSIUS
     _attr_state_class = SensorStateClass.MEASUREMENT
 
@@ -67,10 +62,10 @@ class VerisureThermometer(
     @property
     def device_info(self) -> DeviceInfo:
         """Return device information about this entity."""
-        device_type = self.coordinator.data["climate"][self.serial_number].get(
-            "deviceType"
-        )
-        area = self.coordinator.data["climate"][self.serial_number]["deviceArea"]
+        device_type = self.coordinator.data["climate"][self.serial_number]["device"][
+            "gui"
+        ]["label"]
+        area = self.coordinator.data["climate"][self.serial_number]["device"]["area"]
         return DeviceInfo(
             name=area,
             suggested_area=area,
@@ -84,7 +79,7 @@ class VerisureThermometer(
     @property
     def native_value(self) -> str | None:
         """Return the state of the entity."""
-        return self.coordinator.data["climate"][self.serial_number]["temperature"]
+        return self.coordinator.data["climate"][self.serial_number]["temperatureValue"]
 
     @property
     def available(self) -> bool:
@@ -92,7 +87,8 @@ class VerisureThermometer(
         return (
             super().available
             and self.serial_number in self.coordinator.data["climate"]
-            and "temperature" in self.coordinator.data["climate"][self.serial_number]
+            and "temperatureValue"
+            in self.coordinator.data["climate"][self.serial_number]
         )
 
 
@@ -103,7 +99,7 @@ class VerisureHygrometer(
 
     _attr_device_class = SensorDeviceClass.HUMIDITY
     _attr_has_entity_name = True
-    _attr_name = "Humidity"
+    _attr_translation_key = "humidity"
     _attr_native_unit_of_measurement = PERCENTAGE
     _attr_state_class = SensorStateClass.MEASUREMENT
 
@@ -118,10 +114,10 @@ class VerisureHygrometer(
     @property
     def device_info(self) -> DeviceInfo:
         """Return device information about this entity."""
-        device_type = self.coordinator.data["climate"][self.serial_number].get(
-            "deviceType"
-        )
-        area = self.coordinator.data["climate"][self.serial_number]["deviceArea"]
+        device_type = self.coordinator.data["climate"][self.serial_number]["device"][
+            "gui"
+        ]["label"]
+        area = self.coordinator.data["climate"][self.serial_number]["device"]["area"]
         return DeviceInfo(
             name=area,
             suggested_area=area,
@@ -135,7 +131,7 @@ class VerisureHygrometer(
     @property
     def native_value(self) -> str | None:
         """Return the state of the entity."""
-        return self.coordinator.data["climate"][self.serial_number]["humidity"]
+        return self.coordinator.data["climate"][self.serial_number]["humidityValue"]
 
     @property
     def available(self) -> bool:
@@ -143,51 +139,5 @@ class VerisureHygrometer(
         return (
             super().available
             and self.serial_number in self.coordinator.data["climate"]
-            and "humidity" in self.coordinator.data["climate"][self.serial_number]
-        )
-
-
-class VerisureMouseDetection(
-    CoordinatorEntity[VerisureDataUpdateCoordinator], SensorEntity
-):
-    """Representation of a Verisure mouse detector."""
-
-    _attr_name = "Mouse"
-    _attr_has_entity_name = True
-    _attr_native_unit_of_measurement = "Mice"
-
-    def __init__(
-        self, coordinator: VerisureDataUpdateCoordinator, serial_number: str
-    ) -> None:
-        """Initialize the sensor."""
-        super().__init__(coordinator)
-        self._attr_unique_id = f"{serial_number}_mice"
-        self.serial_number = serial_number
-
-    @property
-    def device_info(self) -> DeviceInfo:
-        """Return device information about this entity."""
-        area = self.coordinator.data["mice"][self.serial_number]["area"]
-        return DeviceInfo(
-            name=area,
-            suggested_area=area,
-            manufacturer="Verisure",
-            model="Mouse detector",
-            identifiers={(DOMAIN, self.serial_number)},
-            via_device=(DOMAIN, self.coordinator.entry.data[CONF_GIID]),
-            configuration_url="https://mypages.verisure.com",
-        )
-
-    @property
-    def native_value(self) -> str | None:
-        """Return the state of the entity."""
-        return self.coordinator.data["mice"][self.serial_number]["detections"]
-
-    @property
-    def available(self) -> bool:
-        """Return True if entity is available."""
-        return (
-            super().available
-            and self.serial_number in self.coordinator.data["mice"]
-            and "detections" in self.coordinator.data["mice"][self.serial_number]
+            and "humidityValue" in self.coordinator.data["climate"][self.serial_number]
         )
