@@ -3,12 +3,15 @@ from __future__ import annotations
 
 import logging
 
-from homeassistant.const import WEEKDAYS
+from homeassistant.const import WEEKDAYS, Platform
 
 LOGGER = logging.getLogger(__package__)
 
 ALLOWED_DAYS = WEEKDAYS + ["holiday"]
 
+DOMAIN = "workday"
+PLATFORMS = [Platform.BINARY_SENSOR]
+
 CONF_COUNTRY = "country"
 CONF_PROVINCE = "province"
 CONF_WORKDAYS = "workdays"
