@@ -64,6 +64,7 @@ from .const import (
     MODEL_AIRPURIFIER_4_LITE_RMA1,
     MODEL_AIRPURIFIER_4_LITE_RMB1,
     MODEL_AIRPURIFIER_4_PRO,
+    MODEL_AIRPURIFIER_MA2,
     MODEL_AIRPURIFIER_PRO,
     MODEL_AIRPURIFIER_PRO_V7,
     MODEL_AIRPURIFIER_V2,
@@ -467,6 +468,16 @@ PURIFIER_ZA1_SENSORS = (
     ATTR_HUMIDITY,
     ATTR_TEMPERATURE,
 )
+PURIFIER_MA2_SENSORS = (
+    ATTR_FILTER_LIFE_REMAINING,
+    ATTR_FILTER_USE,
+    ATTR_HUMIDITY,
+    ATTR_MOTOR_SPEED,
+    ATTR_PM25,
+    ATTR_TEMPERATURE,
+    ATTR_USE_TIME,
+    ATTR_ILLUMINANCE,
+)
 PURIFIER_V2_SENSORS = (
     ATTR_FILTER_LIFE_REMAINING,
     ATTR_FILTER_USE,
@@ -564,6 +575,7 @@ MODEL_TO_SENSORS_MAP: dict[str, tuple[str, ...]] = {
     MODEL_AIRPURIFIER_V2: PURIFIER_V2_SENSORS,
     MODEL_AIRPURIFIER_V3: PURIFIER_V3_SENSORS,
     MODEL_AIRPURIFIER_ZA1: PURIFIER_ZA1_SENSORS,
+    MODEL_AIRPURIFIER_MA2: PURIFIER_MA2_SENSORS,
     MODEL_FAN_V2: FAN_V2_V3_SENSORS,
     MODEL_FAN_V3: FAN_V2_V3_SENSORS,
     MODEL_FAN_ZA5: FAN_ZA5_SENSORS,
