@@ -20,11 +20,12 @@ from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .core import discovery
 from .core.const import (
-    CHANNEL_ACCELEROMETER,
-    CHANNEL_BINARY_INPUT,
-    CHANNEL_OCCUPANCY,
-    CHANNEL_ON_OFF,
-    CHANNEL_ZONE,
+    CLUSTER_HANDLER_ACCELEROMETER,
+    CLUSTER_HANDLER_BINARY_INPUT,
+    CLUSTER_HANDLER_HUE_OCCUPANCY,
+    CLUSTER_HANDLER_OCCUPANCY,
+    CLUSTER_HANDLER_ON_OFF,
+    CLUSTER_HANDLER_ZONE,
     DATA_ZHA,
     SIGNAL_ADD_ENTITIES,
     SIGNAL_ATTR_UPDATED,
@@ -33,13 +34,22 @@ from .core.registries import ZHA_ENTITIES
 from .entity import ZhaEntity
 
 # Zigbee Cluster Library Zone Type to Home Assistant device class
-CLASS_MAPPING = {
-    0x000D: BinarySensorDeviceClass.MOTION,
-    0x0015: BinarySensorDeviceClass.OPENING,
-    0x0028: BinarySensorDeviceClass.SMOKE,
-    0x002A: BinarySensorDeviceClass.MOISTURE,
-    0x002B: BinarySensorDeviceClass.GAS,
-    0x002D: BinarySensorDeviceClass.VIBRATION,
+IAS_ZONE_CLASS_MAPPING = {
+    IasZone.ZoneType.Motion_Sensor: BinarySensorDeviceClass.MOTION,
+    IasZone.ZoneType.Contact_Switch: BinarySensorDeviceClass.OPENING,
+    IasZone.ZoneType.Fire_Sensor: BinarySensorDeviceClass.SMOKE,
+    IasZone.ZoneType.Water_Sensor: BinarySensorDeviceClass.MOISTURE,
+    IasZone.ZoneType.Carbon_Monoxide_Sensor: BinarySensorDeviceClass.GAS,
+    IasZone.ZoneType.Vibration_Movement_Sensor: BinarySensorDeviceClass.VIBRATION,
+}
+
+IAS_ZONE_NAME_MAPPING = {
+    IasZone.ZoneType.Motion_Sensor: "Motion",
+    IasZone.ZoneType.Contact_Switch: "Opening",
+    IasZone.ZoneType.Fire_Sensor: "Smoke",
+    IasZone.ZoneType.Water_Sensor: "Moisture",
+    IasZone.ZoneType.Carbon_Monoxide_Sensor: "Gas",
+    IasZone.ZoneType.Vibration_Movement_Sensor: "Vibration",
 }
 
 STRICT_MATCH = functools.partial(ZHA_ENTITIES.strict_match, Platform.BINARY_SENSOR)
@@ -72,22 +82,22 @@ class BinarySensor(ZhaEntity, BinarySensorEntity):
 
     SENSOR_ATTR: str | None = None
 
-    def __init__(self, unique_id, zha_device, channels, **kwargs):
+    def __init__(self, unique_id, zha_device, cluster_handlers, **kwargs):
         """Initialize the ZHA binary sensor."""
-        super().__init__(unique_id, zha_device, channels, **kwargs)
-        self._channel = channels[0]
+        super().__init__(unique_id, zha_device, cluster_handlers, **kwargs)
+        self._cluster_handler = cluster_handlers[0]
 
     async def async_added_to_hass(self) -> None:
         """Run when about to be added to hass."""
         await super().async_added_to_hass()
         self.async_accept_signal(
-            self._channel, SIGNAL_ATTR_UPDATED, self.async_set_state
+            self._cluster_handler, SIGNAL_ATTR_UPDATED, self.async_set_state
         )
 
     @property
     def is_on(self) -> bool:
         """Return True if the switch is on based on the state machine."""
-        raw_state = self._channel.cluster.get(self.SENSOR_ATTR)
+        raw_state = self._cluster_handler.cluster.get(self.SENSOR_ATTR)
         if raw_state is None:
             return False
         return self.parse(raw_state)
@@ -103,27 +113,35 @@ class BinarySensor(ZhaEntity, BinarySensorEntity):
         return bool(value)
 
 
-@MULTI_MATCH(channel_names=CHANNEL_ACCELEROMETER)
+@MULTI_MATCH(cluster_handler_names=CLUSTER_HANDLER_ACCELEROMETER)
 class Accelerometer(BinarySensor):
     """ZHA BinarySensor."""
 
     SENSOR_ATTR = "acceleration"
+    _attr_name: str = "Accelerometer"
     _attr_device_class: BinarySensorDeviceClass = BinarySensorDeviceClass.MOVING
 
 
-@MULTI_MATCH(channel_names=CHANNEL_OCCUPANCY)
+@MULTI_MATCH(cluster_handler_names=CLUSTER_HANDLER_OCCUPANCY)
 class Occupancy(BinarySensor):
     """ZHA BinarySensor."""
 
     SENSOR_ATTR = "occupancy"
+    _attr_name: str = "Occupancy"
     _attr_device_class: BinarySensorDeviceClass = BinarySensorDeviceClass.OCCUPANCY
 
 
-@STRICT_MATCH(channel_names=CHANNEL_ON_OFF)
+@MULTI_MATCH(cluster_handler_names=CLUSTER_HANDLER_HUE_OCCUPANCY)
+class HueOccupancy(Occupancy):
+    """ZHA Hue occupancy."""
+
+
+@STRICT_MATCH(cluster_handler_names=CLUSTER_HANDLER_ON_OFF)
 class Opening(BinarySensor):
     """ZHA OnOff BinarySensor."""
 
     SENSOR_ATTR = "on_off"
+    _attr_name: str = "Opening"
     _attr_device_class: BinarySensorDeviceClass = BinarySensorDeviceClass.OPENING
 
     # Client/out cluster attributes aren't stored in the zigpy database, but are properly stored in the runtime cache.
@@ -131,47 +149,56 @@ class Opening(BinarySensor):
     @callback
     def async_restore_last_state(self, last_state):
         """Restore previous state to zigpy cache."""
-        self._channel.cluster.update_attribute(
+        self._cluster_handler.cluster.update_attribute(
             OnOff.attributes_by_name[self.SENSOR_ATTR].id,
             t.Bool.true if last_state.state == STATE_ON else t.Bool.false,
         )
 
 
-@MULTI_MATCH(channel_names=CHANNEL_BINARY_INPUT)
+@MULTI_MATCH(cluster_handler_names=CLUSTER_HANDLER_BINARY_INPUT)
 class BinaryInput(BinarySensor):
     """ZHA BinarySensor."""
 
     SENSOR_ATTR = "present_value"
+    _attr_name: str = "Binary input"
 
 
 @STRICT_MATCH(
-    channel_names=CHANNEL_ON_OFF,
+    cluster_handler_names=CLUSTER_HANDLER_ON_OFF,
     manufacturers="IKEA of Sweden",
     models=lambda model: isinstance(model, str)
     and model is not None
     and model.find("motion") != -1,
 )
 @STRICT_MATCH(
-    channel_names=CHANNEL_ON_OFF,
+    cluster_handler_names=CLUSTER_HANDLER_ON_OFF,
     manufacturers="Philips",
     models={"SML001", "SML002"},
 )
 class Motion(Opening):
     """ZHA OnOff BinarySensor with motion device class."""
 
+    _attr_name: str = "Motion"
     _attr_device_class: BinarySensorDeviceClass = BinarySensorDeviceClass.MOTION
 
 
-@MULTI_MATCH(channel_names=CHANNEL_ZONE)
+@MULTI_MATCH(cluster_handler_names=CLUSTER_HANDLER_ZONE)
 class IASZone(BinarySensor):
     """ZHA IAS BinarySensor."""
 
     SENSOR_ATTR = "zone_status"
 
+    @property
+    def name(self) -> str | None:
+        """Return the name of the sensor."""
+        zone_type = self._cluster_handler.cluster.get("zone_type")
+        return IAS_ZONE_NAME_MAPPING.get(zone_type, "iaszone")
+
     @property
     def device_class(self) -> BinarySensorDeviceClass | None:
         """Return device class from component DEVICE_CLASSES."""
-        return CLASS_MAPPING.get(self._channel.cluster.get("zone_type"))
+        zone_type = self._cluster_handler.cluster.get("zone_type")
+        return IAS_ZONE_CLASS_MAPPING.get(zone_type)
 
     @staticmethod
     def parse(value: bool | int) -> bool:
@@ -204,13 +231,13 @@ class IASZone(BinarySensor):
         else:
             migrated_state = IasZone.ZoneStatus(0)
 
-        self._channel.cluster.update_attribute(
+        self._cluster_handler.cluster.update_attribute(
             IasZone.attributes_by_name[self.SENSOR_ATTR].id, migrated_state
         )
 
 
 @MULTI_MATCH(
-    channel_names="tuya_manufacturer",
+    cluster_handler_names="tuya_manufacturer",
     manufacturers={
         "_TZE200_htnnfasr",
     },
@@ -220,17 +247,19 @@ class FrostLock(BinarySensor, id_suffix="frost_lock"):
 
     SENSOR_ATTR = "frost_lock"
     _attr_device_class: BinarySensorDeviceClass = BinarySensorDeviceClass.LOCK
+    _attr_name: str = "Frost lock"
 
 
-@MULTI_MATCH(channel_names="ikea_airpurifier")
+@MULTI_MATCH(cluster_handler_names="ikea_airpurifier")
 class ReplaceFilter(BinarySensor, id_suffix="replace_filter"):
     """ZHA BinarySensor."""
 
     SENSOR_ATTR = "replace_filter"
     _attr_device_class: BinarySensorDeviceClass = BinarySensorDeviceClass.PROBLEM
+    _attr_name: str = "Replace filter"
 
 
-@MULTI_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
+@MULTI_MATCH(cluster_handler_names="opple_cluster", models={"aqara.feeder.acn001"})
 class AqaraPetFeederErrorDetected(BinarySensor, id_suffix="error_detected"):
     """ZHA aqara pet feeder error detected binary sensor."""
 
@@ -240,7 +269,8 @@ class AqaraPetFeederErrorDetected(BinarySensor, id_suffix="error_detected"):
 
 
 @MULTI_MATCH(
-    channel_names="opple_cluster", models={"lumi.plug.mmeu01", "lumi.plug.maeu01"}
+    cluster_handler_names="opple_cluster",
+    models={"lumi.plug.mmeu01", "lumi.plug.maeu01"},
 )
 class XiaomiPlugConsumerConnected(BinarySensor, id_suffix="consumer_connected"):
     """ZHA Xiaomi plug consumer connected binary sensor."""
@@ -250,7 +280,7 @@ class XiaomiPlugConsumerConnected(BinarySensor, id_suffix="consumer_connected"):
     _attr_device_class: BinarySensorDeviceClass = BinarySensorDeviceClass.PLUG
 
 
-@MULTI_MATCH(channel_names="opple_cluster", models={"lumi.airrtc.agl001"})
+@MULTI_MATCH(cluster_handler_names="opple_cluster", models={"lumi.airrtc.agl001"})
 class AqaraThermostatWindowOpen(BinarySensor, id_suffix="window_open"):
     """ZHA Aqara thermostat window open binary sensor."""
 
@@ -259,7 +289,7 @@ class AqaraThermostatWindowOpen(BinarySensor, id_suffix="window_open"):
     _attr_name: str = "Window open"
 
 
-@MULTI_MATCH(channel_names="opple_cluster", models={"lumi.airrtc.agl001"})
+@MULTI_MATCH(cluster_handler_names="opple_cluster", models={"lumi.airrtc.agl001"})
 class AqaraThermostatValveAlarm(BinarySensor, id_suffix="valve_alarm"):
     """ZHA Aqara thermostat valve alarm binary sensor."""
 
@@ -268,7 +298,9 @@ class AqaraThermostatValveAlarm(BinarySensor, id_suffix="valve_alarm"):
     _attr_name: str = "Valve alarm"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names="opple_cluster", models={"lumi.airrtc.agl001"})
+@CONFIG_DIAGNOSTIC_MATCH(
+    cluster_handler_names="opple_cluster", models={"lumi.airrtc.agl001"}
+)
 class AqaraThermostatCalibrated(BinarySensor, id_suffix="calibrated"):
     """ZHA Aqara thermostat calibrated binary sensor."""
 
@@ -277,7 +309,9 @@ class AqaraThermostatCalibrated(BinarySensor, id_suffix="calibrated"):
     _attr_name: str = "Calibrated"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names="opple_cluster", models={"lumi.airrtc.agl001"})
+@CONFIG_DIAGNOSTIC_MATCH(
+    cluster_handler_names="opple_cluster", models={"lumi.airrtc.agl001"}
+)
 class AqaraThermostatExternalSensor(BinarySensor, id_suffix="sensor"):
     """ZHA Aqara thermostat external sensor binary sensor."""
 
@@ -286,7 +320,7 @@ class AqaraThermostatExternalSensor(BinarySensor, id_suffix="sensor"):
     _attr_name: str = "External sensor"
 
 
-@MULTI_MATCH(channel_names="opple_cluster", models={"lumi.sensor_smoke.acn03"})
+@MULTI_MATCH(cluster_handler_names="opple_cluster", models={"lumi.sensor_smoke.acn03"})
 class AqaraLinkageAlarmState(BinarySensor, id_suffix="linkage_alarm_state"):
     """ZHA Aqara linkage alarm state binary sensor."""
 
