@@ -64,39 +64,40 @@ ATTR_WARNING_DEVICE_STROBE_INTENSITY = "intensity"
 BAUD_RATES = [2400, 4800, 9600, 14400, 19200, 38400, 57600, 115200, 128000, 256000]
 BINDINGS = "bindings"
 
-CHANNEL_ACCELEROMETER = "accelerometer"
-CHANNEL_BINARY_INPUT = "binary_input"
-CHANNEL_ANALOG_INPUT = "analog_input"
-CHANNEL_ANALOG_OUTPUT = "analog_output"
-CHANNEL_ATTRIBUTE = "attribute"
-CHANNEL_BASIC = "basic"
-CHANNEL_COLOR = "light_color"
-CHANNEL_COVER = "window_covering"
-CHANNEL_DEVICE_TEMPERATURE = "device_temperature"
-CHANNEL_DOORLOCK = "door_lock"
-CHANNEL_ELECTRICAL_MEASUREMENT = "electrical_measurement"
-CHANNEL_EVENT_RELAY = "event_relay"
-CHANNEL_FAN = "fan"
-CHANNEL_HUMIDITY = "humidity"
-CHANNEL_SOIL_MOISTURE = "soil_moisture"
-CHANNEL_LEAF_WETNESS = "leaf_wetness"
-CHANNEL_IAS_ACE = "ias_ace"
-CHANNEL_IAS_WD = "ias_wd"
-CHANNEL_IDENTIFY = "identify"
-CHANNEL_ILLUMINANCE = "illuminance"
-CHANNEL_LEVEL = ATTR_LEVEL
-CHANNEL_MULTISTATE_INPUT = "multistate_input"
-CHANNEL_OCCUPANCY = "occupancy"
-CHANNEL_ON_OFF = "on_off"
-CHANNEL_POWER_CONFIGURATION = "power"
-CHANNEL_PRESSURE = "pressure"
-CHANNEL_SHADE = "shade"
-CHANNEL_SMARTENERGY_METERING = "smartenergy_metering"
-CHANNEL_TEMPERATURE = "temperature"
-CHANNEL_THERMOSTAT = "thermostat"
-CHANNEL_ZDO = "zdo"
-CHANNEL_ZONE = ZONE = "ias_zone"
-CHANNEL_INOVELLI = "inovelli_vzm31sn_cluster"
+CLUSTER_HANDLER_ACCELEROMETER = "accelerometer"
+CLUSTER_HANDLER_BINARY_INPUT = "binary_input"
+CLUSTER_HANDLER_ANALOG_INPUT = "analog_input"
+CLUSTER_HANDLER_ANALOG_OUTPUT = "analog_output"
+CLUSTER_HANDLER_ATTRIBUTE = "attribute"
+CLUSTER_HANDLER_BASIC = "basic"
+CLUSTER_HANDLER_COLOR = "light_color"
+CLUSTER_HANDLER_COVER = "window_covering"
+CLUSTER_HANDLER_DEVICE_TEMPERATURE = "device_temperature"
+CLUSTER_HANDLER_DOORLOCK = "door_lock"
+CLUSTER_HANDLER_ELECTRICAL_MEASUREMENT = "electrical_measurement"
+CLUSTER_HANDLER_EVENT_RELAY = "event_relay"
+CLUSTER_HANDLER_FAN = "fan"
+CLUSTER_HANDLER_HUMIDITY = "humidity"
+CLUSTER_HANDLER_HUE_OCCUPANCY = "philips_occupancy"
+CLUSTER_HANDLER_SOIL_MOISTURE = "soil_moisture"
+CLUSTER_HANDLER_LEAF_WETNESS = "leaf_wetness"
+CLUSTER_HANDLER_IAS_ACE = "ias_ace"
+CLUSTER_HANDLER_IAS_WD = "ias_wd"
+CLUSTER_HANDLER_IDENTIFY = "identify"
+CLUSTER_HANDLER_ILLUMINANCE = "illuminance"
+CLUSTER_HANDLER_LEVEL = ATTR_LEVEL
+CLUSTER_HANDLER_MULTISTATE_INPUT = "multistate_input"
+CLUSTER_HANDLER_OCCUPANCY = "occupancy"
+CLUSTER_HANDLER_ON_OFF = "on_off"
+CLUSTER_HANDLER_POWER_CONFIGURATION = "power"
+CLUSTER_HANDLER_PRESSURE = "pressure"
+CLUSTER_HANDLER_SHADE = "shade"
+CLUSTER_HANDLER_SMARTENERGY_METERING = "smartenergy_metering"
+CLUSTER_HANDLER_TEMPERATURE = "temperature"
+CLUSTER_HANDLER_THERMOSTAT = "thermostat"
+CLUSTER_HANDLER_ZDO = "zdo"
+CLUSTER_HANDLER_ZONE = ZONE = "ias_zone"
+CLUSTER_HANDLER_INOVELLI = "inovelli_vzm31sn_cluster"
 
 CLUSTER_COMMAND_SERVER = "server"
 CLUSTER_COMMANDS_CLIENT = "client_commands"
@@ -151,7 +152,9 @@ CONF_DEFAULT_CONSIDER_UNAVAILABLE_BATTERY = 60 * 60 * 6  # 6 hours
 
 CONF_ZHA_OPTIONS_SCHEMA = vol.Schema(
     {
-        vol.Optional(CONF_DEFAULT_LIGHT_TRANSITION, default=0): cv.positive_int,
+        vol.Optional(CONF_DEFAULT_LIGHT_TRANSITION, default=0): vol.All(
+            vol.Coerce(float), vol.Range(min=0, max=2**16 / 10)
+        ),
         vol.Required(CONF_ENABLE_ENHANCED_LIGHT_TRANSITION, default=False): cv.boolean,
         vol.Required(CONF_ENABLE_LIGHT_TRANSITIONING_FLAG, default=True): cv.boolean,
         vol.Required(CONF_ALWAYS_PREFER_XY_COLOR_MODE, default=True): cv.boolean,
@@ -330,15 +333,15 @@ REPORT_CONFIG_OP = (
 
 SENSOR_ACCELERATION = "acceleration"
 SENSOR_BATTERY = "battery"
-SENSOR_ELECTRICAL_MEASUREMENT = CHANNEL_ELECTRICAL_MEASUREMENT
+SENSOR_ELECTRICAL_MEASUREMENT = CLUSTER_HANDLER_ELECTRICAL_MEASUREMENT
 SENSOR_GENERIC = "generic"
-SENSOR_HUMIDITY = CHANNEL_HUMIDITY
-SENSOR_ILLUMINANCE = CHANNEL_ILLUMINANCE
+SENSOR_HUMIDITY = CLUSTER_HANDLER_HUMIDITY
+SENSOR_ILLUMINANCE = CLUSTER_HANDLER_ILLUMINANCE
 SENSOR_METERING = "metering"
-SENSOR_OCCUPANCY = CHANNEL_OCCUPANCY
+SENSOR_OCCUPANCY = CLUSTER_HANDLER_OCCUPANCY
 SENSOR_OPENING = "opening"
-SENSOR_PRESSURE = CHANNEL_PRESSURE
-SENSOR_TEMPERATURE = CHANNEL_TEMPERATURE
+SENSOR_PRESSURE = CLUSTER_HANDLER_PRESSURE
+SENSOR_TEMPERATURE = CLUSTER_HANDLER_TEMPERATURE
 SENSOR_TYPE = "sensor_type"
 
 SIGNAL_ADD_ENTITIES = "zha_add_new_entities"
@@ -381,12 +384,12 @@ WARNING_DEVICE_SQUAWK_MODE_ARMED = 0
 WARNING_DEVICE_SQUAWK_MODE_DISARMED = 1
 
 ZHA_DISCOVERY_NEW = "zha_discovery_new_{}"
-ZHA_CHANNEL_MSG = "zha_channel_message"
-ZHA_CHANNEL_MSG_BIND = "zha_channel_bind"
-ZHA_CHANNEL_MSG_CFG_RPT = "zha_channel_configure_reporting"
-ZHA_CHANNEL_MSG_DATA = "zha_channel_msg_data"
-ZHA_CHANNEL_CFG_DONE = "zha_channel_cfg_done"
-ZHA_CHANNEL_READS_PER_REQ = 5
+ZHA_CLUSTER_HANDLER_MSG = "zha_channel_message"
+ZHA_CLUSTER_HANDLER_MSG_BIND = "zha_channel_bind"
+ZHA_CLUSTER_HANDLER_MSG_CFG_RPT = "zha_channel_configure_reporting"
+ZHA_CLUSTER_HANDLER_MSG_DATA = "zha_channel_msg_data"
+ZHA_CLUSTER_HANDLER_CFG_DONE = "zha_channel_cfg_done"
+ZHA_CLUSTER_HANDLER_READS_PER_REQ = 5
 ZHA_EVENT = "zha_event"
 ZHA_GW_MSG = "zha_gateway_message"
 ZHA_GW_MSG_DEVICE_FULL_INIT = "device_fully_initialized"
