@@ -18,11 +18,11 @@ from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .core import discovery
 from .core.const import (
-    CHANNEL_ANALOG_OUTPUT,
-    CHANNEL_BASIC,
-    CHANNEL_COLOR,
-    CHANNEL_INOVELLI,
-    CHANNEL_LEVEL,
+    CLUSTER_HANDLER_ANALOG_OUTPUT,
+    CLUSTER_HANDLER_BASIC,
+    CLUSTER_HANDLER_COLOR,
+    CLUSTER_HANDLER_INOVELLI,
+    CLUSTER_HANDLER_LEVEL,
     DATA_ZHA,
     SIGNAL_ADD_ENTITIES,
     SIGNAL_ATTR_UPDATED,
@@ -31,7 +31,7 @@ from .core.registries import ZHA_ENTITIES
 from .entity import ZhaEntity
 
 if TYPE_CHECKING:
-    from .core.channels.base import ZigbeeChannel
+    from .core.cluster_handlers import ClusterHandler
     from .core.device import ZHADevice
 
 _LOGGER = logging.getLogger(__name__)
@@ -275,37 +275,43 @@ async def async_setup_entry(
     config_entry.async_on_unload(unsub)
 
 
-@STRICT_MATCH(channel_names=CHANNEL_ANALOG_OUTPUT)
+@STRICT_MATCH(cluster_handler_names=CLUSTER_HANDLER_ANALOG_OUTPUT)
 class ZhaNumber(ZhaEntity, NumberEntity):
     """Representation of a ZHA Number entity."""
 
+    _attr_name: str = "Number"
+
     def __init__(
         self,
         unique_id: str,
         zha_device: ZHADevice,
-        channels: list[ZigbeeChannel],
+        cluster_handlers: list[ClusterHandler],
         **kwargs: Any,
     ) -> None:
         """Init this entity."""
-        super().__init__(unique_id, zha_device, channels, **kwargs)
-        self._analog_output_channel = self.cluster_channels[CHANNEL_ANALOG_OUTPUT]
+        super().__init__(unique_id, zha_device, cluster_handlers, **kwargs)
+        self._analog_output_cluster_handler = self.cluster_handlers[
+            CLUSTER_HANDLER_ANALOG_OUTPUT
+        ]
 
     async def async_added_to_hass(self) -> None:
         """Run when about to be added to hass."""
         await super().async_added_to_hass()
         self.async_accept_signal(
-            self._analog_output_channel, SIGNAL_ATTR_UPDATED, self.async_set_state
+            self._analog_output_cluster_handler,
+            SIGNAL_ATTR_UPDATED,
+            self.async_set_state,
         )
 
     @property
     def native_value(self) -> float | None:
         """Return the current value."""
-        return self._analog_output_channel.present_value
+        return self._analog_output_cluster_handler.present_value
 
     @property
     def native_min_value(self) -> float:
         """Return the minimum value."""
-        min_present_value = self._analog_output_channel.min_present_value
+        min_present_value = self._analog_output_cluster_handler.min_present_value
         if min_present_value is not None:
             return min_present_value
         return 0
@@ -313,7 +319,7 @@ class ZhaNumber(ZhaEntity, NumberEntity):
     @property
     def native_max_value(self) -> float:
         """Return the maximum value."""
-        max_present_value = self._analog_output_channel.max_present_value
+        max_present_value = self._analog_output_cluster_handler.max_present_value
         if max_present_value is not None:
             return max_present_value
         return 1023
@@ -321,15 +327,15 @@ class ZhaNumber(ZhaEntity, NumberEntity):
     @property
     def native_step(self) -> float | None:
         """Return the value step."""
-        resolution = self._analog_output_channel.resolution
+        resolution = self._analog_output_cluster_handler.resolution
         if resolution is not None:
             return resolution
         return super().native_step
 
     @property
-    def name(self) -> str:
+    def name(self) -> str | None:
         """Return the name of the number entity."""
-        description = self._analog_output_channel.description
+        description = self._analog_output_cluster_handler.description
         if description is not None and len(description) > 0:
             return f"{super().name} {description}"
         return super().name
@@ -337,7 +343,7 @@ class ZhaNumber(ZhaEntity, NumberEntity):
     @property
     def icon(self) -> str | None:
         """Return the icon to be used for this entity."""
-        application_type = self._analog_output_channel.application_type
+        application_type = self._analog_output_cluster_handler.application_type
         if application_type is not None:
             return ICONS.get(application_type >> 16, super().icon)
         return super().icon
@@ -345,26 +351,26 @@ class ZhaNumber(ZhaEntity, NumberEntity):
     @property
     def native_unit_of_measurement(self) -> str | None:
         """Return the unit the value is expressed in."""
-        engineering_units = self._analog_output_channel.engineering_units
+        engineering_units = self._analog_output_cluster_handler.engineering_units
         return UNITS.get(engineering_units)
 
     @callback
     def async_set_state(self, attr_id, attr_name, value):
-        """Handle value update from channel."""
+        """Handle value update from cluster handler."""
         self.async_write_ha_state()
 
     async def async_set_native_value(self, value: float) -> None:
         """Update the current value from HA."""
         num_value = float(value)
-        if await self._analog_output_channel.async_set_present_value(num_value):
+        if await self._analog_output_cluster_handler.async_set_present_value(num_value):
             self.async_write_ha_state()
 
     async def async_update(self) -> None:
         """Attempt to retrieve the state of the entity."""
         await super().async_update()
         _LOGGER.debug("polling current state")
-        if self._analog_output_channel:
-            value = await self._analog_output_channel.get_attribute_value(
+        if self._analog_output_cluster_handler:
+            value = await self._analog_output_cluster_handler.get_attribute_value(
                 "present_value", from_cache=False
             )
             _LOGGER.debug("read value=%s", value)
@@ -383,17 +389,17 @@ class ZHANumberConfigurationEntity(ZhaEntity, NumberEntity):
         cls,
         unique_id: str,
         zha_device: ZHADevice,
-        channels: list[ZigbeeChannel],
+        cluster_handlers: list[ClusterHandler],
         **kwargs: Any,
     ) -> Self | None:
         """Entity Factory.
 
         Return entity if it is a supported configuration, otherwise return None
         """
-        channel = channels[0]
+        cluster_handler = cluster_handlers[0]
         if (
-            cls._zcl_attribute in channel.cluster.unsupported_attributes
-            or channel.cluster.get(cls._zcl_attribute) is None
+            cls._zcl_attribute in cluster_handler.cluster.unsupported_attributes
+            or cluster_handler.cluster.get(cls._zcl_attribute) is None
         ):
             _LOGGER.debug(
                 "%s is not supported - skipping %s entity creation",
@@ -402,28 +408,31 @@ class ZHANumberConfigurationEntity(ZhaEntity, NumberEntity):
             )
             return None
 
-        return cls(unique_id, zha_device, channels, **kwargs)
+        return cls(unique_id, zha_device, cluster_handlers, **kwargs)
 
     def __init__(
         self,
         unique_id: str,
         zha_device: ZHADevice,
-        channels: list[ZigbeeChannel],
+        cluster_handlers: list[ClusterHandler],
         **kwargs: Any,
     ) -> None:
         """Init this number configuration entity."""
-        self._channel: ZigbeeChannel = channels[0]
-        super().__init__(unique_id, zha_device, channels, **kwargs)
+        self._cluster_handler: ClusterHandler = cluster_handlers[0]
+        super().__init__(unique_id, zha_device, cluster_handlers, **kwargs)
 
     @property
     def native_value(self) -> float:
         """Return the current value."""
-        return self._channel.cluster.get(self._zcl_attribute) * self._attr_multiplier
+        return (
+            self._cluster_handler.cluster.get(self._zcl_attribute)
+            * self._attr_multiplier
+        )
 
     async def async_set_native_value(self, value: float) -> None:
         """Update the current value from HA."""
         try:
-            res = await self._channel.cluster.write_attributes(
+            res = await self._cluster_handler.cluster.write_attributes(
                 {self._zcl_attribute: int(value / self._attr_multiplier)}
             )
         except zigpy.exceptions.ZigbeeException as ex:
@@ -438,15 +447,16 @@ class ZHANumberConfigurationEntity(ZhaEntity, NumberEntity):
         """Attempt to retrieve the state of the entity."""
         await super().async_update()
         _LOGGER.debug("polling current state")
-        if self._channel:
-            value = await self._channel.get_attribute_value(
+        if self._cluster_handler:
+            value = await self._cluster_handler.get_attribute_value(
                 self._zcl_attribute, from_cache=False
             )
             _LOGGER.debug("read value=%s", value)
 
 
 @CONFIG_DIAGNOSTIC_MATCH(
-    channel_names="opple_cluster", models={"lumi.motion.ac02", "lumi.motion.agl04"}
+    cluster_handler_names="opple_cluster",
+    models={"lumi.motion.ac02", "lumi.motion.agl04"},
 )
 class AqaraMotionDetectionInterval(
     ZHANumberConfigurationEntity, id_suffix="detection_interval"
@@ -459,7 +469,7 @@ class AqaraMotionDetectionInterval(
     _attr_name = "Detection interval"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_LEVEL)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_LEVEL)
 class OnOffTransitionTimeConfigurationEntity(
     ZHANumberConfigurationEntity, id_suffix="on_off_transition_time"
 ):
@@ -471,7 +481,7 @@ class OnOffTransitionTimeConfigurationEntity(
     _attr_name = "On/Off transition time"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_LEVEL)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_LEVEL)
 class OnLevelConfigurationEntity(ZHANumberConfigurationEntity, id_suffix="on_level"):
     """Representation of a ZHA on level configuration entity."""
 
@@ -481,7 +491,7 @@ class OnLevelConfigurationEntity(ZHANumberConfigurationEntity, id_suffix="on_lev
     _attr_name = "On level"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_LEVEL)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_LEVEL)
 class OnTransitionTimeConfigurationEntity(
     ZHANumberConfigurationEntity, id_suffix="on_transition_time"
 ):
@@ -493,7 +503,7 @@ class OnTransitionTimeConfigurationEntity(
     _attr_name = "On transition time"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_LEVEL)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_LEVEL)
 class OffTransitionTimeConfigurationEntity(
     ZHANumberConfigurationEntity, id_suffix="off_transition_time"
 ):
@@ -505,7 +515,7 @@ class OffTransitionTimeConfigurationEntity(
     _attr_name = "Off transition time"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_LEVEL)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_LEVEL)
 class DefaultMoveRateConfigurationEntity(
     ZHANumberConfigurationEntity, id_suffix="default_move_rate"
 ):
@@ -517,7 +527,7 @@ class DefaultMoveRateConfigurationEntity(
     _attr_name = "Default move rate"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_LEVEL)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_LEVEL)
 class StartUpCurrentLevelConfigurationEntity(
     ZHANumberConfigurationEntity, id_suffix="start_up_current_level"
 ):
@@ -529,7 +539,7 @@ class StartUpCurrentLevelConfigurationEntity(
     _attr_name = "Start-up current level"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_COLOR)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_COLOR)
 class StartUpColorTemperatureConfigurationEntity(
     ZHANumberConfigurationEntity, id_suffix="start_up_color_temperature"
 ):
@@ -544,18 +554,18 @@ class StartUpColorTemperatureConfigurationEntity(
         self,
         unique_id: str,
         zha_device: ZHADevice,
-        channels: list[ZigbeeChannel],
+        cluster_handlers: list[ClusterHandler],
         **kwargs: Any,
     ) -> None:
         """Init this ZHA startup color temperature entity."""
-        super().__init__(unique_id, zha_device, channels, **kwargs)
-        if self._channel:
-            self._attr_native_min_value: float = self._channel.min_mireds
-            self._attr_native_max_value: float = self._channel.max_mireds
+        super().__init__(unique_id, zha_device, cluster_handlers, **kwargs)
+        if self._cluster_handler:
+            self._attr_native_min_value: float = self._cluster_handler.min_mireds
+            self._attr_native_max_value: float = self._cluster_handler.max_mireds
 
 
 @CONFIG_DIAGNOSTIC_MATCH(
-    channel_names="tuya_manufacturer",
+    cluster_handler_names="tuya_manufacturer",
     manufacturers={
         "_TZE200_htnnfasr",
     },
@@ -572,7 +582,7 @@ class TimerDurationMinutes(ZHANumberConfigurationEntity, id_suffix="timer_durati
     _attr_name = "Timer duration"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names="ikea_airpurifier")
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names="ikea_airpurifier")
 class FilterLifeTime(ZHANumberConfigurationEntity, id_suffix="filter_life_time"):
     """Representation of a ZHA filter lifetime configuration entity."""
 
@@ -586,7 +596,7 @@ class FilterLifeTime(ZHANumberConfigurationEntity, id_suffix="filter_life_time")
 
 
 @CONFIG_DIAGNOSTIC_MATCH(
-    channel_names=CHANNEL_BASIC,
+    cluster_handler_names=CLUSTER_HANDLER_BASIC,
     manufacturers={"TexasInstruments"},
     models={"ti.router"},
 )
@@ -599,7 +609,7 @@ class TiRouterTransmitPower(ZHANumberConfigurationEntity, id_suffix="transmit_po
     _attr_name = "Transmit power"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliRemoteDimmingUpSpeed(
     ZHANumberConfigurationEntity, id_suffix="dimming_speed_up_remote"
 ):
@@ -613,7 +623,7 @@ class InovelliRemoteDimmingUpSpeed(
     _attr_name: str = "Remote dimming up speed"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliButtonDelay(ZHANumberConfigurationEntity, id_suffix="button_delay"):
     """Inovelli button delay configuration entity."""
 
@@ -625,7 +635,7 @@ class InovelliButtonDelay(ZHANumberConfigurationEntity, id_suffix="button_delay"
     _attr_name: str = "Button delay"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliLocalDimmingUpSpeed(
     ZHANumberConfigurationEntity, id_suffix="dimming_speed_up_local"
 ):
@@ -639,7 +649,7 @@ class InovelliLocalDimmingUpSpeed(
     _attr_name: str = "Local dimming up speed"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliLocalRampRateOffToOn(
     ZHANumberConfigurationEntity, id_suffix="ramp_rate_off_to_on_local"
 ):
@@ -653,7 +663,7 @@ class InovelliLocalRampRateOffToOn(
     _attr_name: str = "Local ramp rate off to on"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliRemoteDimmingSpeedOffToOn(
     ZHANumberConfigurationEntity, id_suffix="ramp_rate_off_to_on_remote"
 ):
@@ -667,7 +677,7 @@ class InovelliRemoteDimmingSpeedOffToOn(
     _attr_name: str = "Remote ramp rate off to on"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliRemoteDimmingDownSpeed(
     ZHANumberConfigurationEntity, id_suffix="dimming_speed_down_remote"
 ):
@@ -681,7 +691,7 @@ class InovelliRemoteDimmingDownSpeed(
     _attr_name: str = "Remote dimming down speed"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliLocalDimmingDownSpeed(
     ZHANumberConfigurationEntity, id_suffix="dimming_speed_down_local"
 ):
@@ -695,7 +705,7 @@ class InovelliLocalDimmingDownSpeed(
     _attr_name: str = "Local dimming down speed"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliLocalRampRateOnToOff(
     ZHANumberConfigurationEntity, id_suffix="ramp_rate_on_to_off_local"
 ):
@@ -709,7 +719,7 @@ class InovelliLocalRampRateOnToOff(
     _attr_name: str = "Local ramp rate on to off"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliRemoteDimmingSpeedOnToOff(
     ZHANumberConfigurationEntity, id_suffix="ramp_rate_on_to_off_remote"
 ):
@@ -723,7 +733,7 @@ class InovelliRemoteDimmingSpeedOnToOff(
     _attr_name: str = "Remote ramp rate on to off"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliMinimumLoadDimmingLevel(
     ZHANumberConfigurationEntity, id_suffix="minimum_level"
 ):
@@ -737,7 +747,7 @@ class InovelliMinimumLoadDimmingLevel(
     _attr_name: str = "Minimum load dimming level"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliMaximumLoadDimmingLevel(
     ZHANumberConfigurationEntity, id_suffix="maximum_level"
 ):
@@ -751,7 +761,7 @@ class InovelliMaximumLoadDimmingLevel(
     _attr_name: str = "Maximum load dimming level"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliAutoShutoffTimer(
     ZHANumberConfigurationEntity, id_suffix="auto_off_timer"
 ):
@@ -765,7 +775,7 @@ class InovelliAutoShutoffTimer(
     _attr_name: str = "Automatic switch shutoff timer"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliLoadLevelIndicatorTimeout(
     ZHANumberConfigurationEntity, id_suffix="load_level_indicator_timeout"
 ):
@@ -779,7 +789,7 @@ class InovelliLoadLevelIndicatorTimeout(
     _attr_name: str = "Load level indicator timeout"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliDefaultAllLEDOnColor(
     ZHANumberConfigurationEntity, id_suffix="led_color_when_on"
 ):
@@ -793,7 +803,7 @@ class InovelliDefaultAllLEDOnColor(
     _attr_name: str = "Default all LED on color"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliDefaultAllLEDOffColor(
     ZHANumberConfigurationEntity, id_suffix="led_color_when_off"
 ):
@@ -807,7 +817,7 @@ class InovelliDefaultAllLEDOffColor(
     _attr_name: str = "Default all LED off color"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliDefaultAllLEDOnIntensity(
     ZHANumberConfigurationEntity, id_suffix="led_intensity_when_on"
 ):
@@ -821,7 +831,7 @@ class InovelliDefaultAllLEDOnIntensity(
     _attr_name: str = "Default all LED on intensity"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names=CHANNEL_INOVELLI)
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
 class InovelliDefaultAllLEDOffIntensity(
     ZHANumberConfigurationEntity, id_suffix="led_intensity_when_off"
 ):
@@ -835,7 +845,37 @@ class InovelliDefaultAllLEDOffIntensity(
     _attr_name: str = "Default all LED off intensity"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
+class InovelliDoubleTapUpLevel(
+    ZHANumberConfigurationEntity, id_suffix="double_tap_up_level"
+):
+    """Inovelli double tap up level configuration entity."""
+
+    _attr_entity_category = EntityCategory.CONFIG
+    _attr_icon: str = ICONS[16]
+    _attr_native_min_value: float = 2
+    _attr_native_max_value: float = 254
+    _zcl_attribute: str = "double_tap_up_level"
+    _attr_name: str = "Double tap up level"
+
+
+@CONFIG_DIAGNOSTIC_MATCH(cluster_handler_names=CLUSTER_HANDLER_INOVELLI)
+class InovelliDoubleTapDownLevel(
+    ZHANumberConfigurationEntity, id_suffix="double_tap_down_level"
+):
+    """Inovelli double tap down level configuration entity."""
+
+    _attr_entity_category = EntityCategory.CONFIG
+    _attr_icon: str = ICONS[16]
+    _attr_native_min_value: float = 0
+    _attr_native_max_value: float = 254
+    _zcl_attribute: str = "double_tap_down_level"
+    _attr_name: str = "Double tap down level"
+
+
+@CONFIG_DIAGNOSTIC_MATCH(
+    cluster_handler_names="opple_cluster", models={"aqara.feeder.acn001"}
+)
 class AqaraPetFeederServingSize(ZHANumberConfigurationEntity, id_suffix="serving_size"):
     """Aqara pet feeder serving size configuration entity."""
 
@@ -848,7 +888,9 @@ class AqaraPetFeederServingSize(ZHANumberConfigurationEntity, id_suffix="serving
     _attr_icon: str = "mdi:counter"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
+@CONFIG_DIAGNOSTIC_MATCH(
+    cluster_handler_names="opple_cluster", models={"aqara.feeder.acn001"}
+)
 class AqaraPetFeederPortionWeight(
     ZHANumberConfigurationEntity, id_suffix="portion_weight"
 ):
@@ -864,7 +906,9 @@ class AqaraPetFeederPortionWeight(
     _attr_icon: str = "mdi:weight-gram"
 
 
-@CONFIG_DIAGNOSTIC_MATCH(channel_names="opple_cluster", models={"lumi.airrtc.agl001"})
+@CONFIG_DIAGNOSTIC_MATCH(
+    cluster_handler_names="opple_cluster", models={"lumi.airrtc.agl001"}
+)
 class AqaraThermostatAwayTemp(
     ZHANumberConfigurationEntity, id_suffix="away_preset_temperature"
 ):
