@@ -29,6 +29,7 @@ from homeassistant.const import (
     LIGHT_LUX,
     PERCENTAGE,
     SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
+    EntityCategory,
     UnitOfElectricCurrent,
     UnitOfElectricPotential,
     UnitOfEnergy,
@@ -40,7 +41,6 @@ from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
 from homeassistant.helpers import entity_platform
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
-from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import (
@@ -565,8 +565,8 @@ class ZWaveConfigParameterSensor(ZwaveSensorBase):
         if (
             self._primary_value.configuration_value_type == ConfigurationValueType.RANGE
             or (
-                not str(self.info.primary_value.value)
-                in self.info.primary_value.metadata.states
+                str(self.info.primary_value.value)
+                not in self.info.primary_value.metadata.states
             )
         ):
             return str(self.info.primary_value.value)
