@@ -11,6 +11,7 @@ from typing import Any, TypeVar
 
 import voluptuous as vol
 
+from homeassistant.components.homeassistant.exposed_entities import async_should_expose
 from homeassistant.const import (
     ATTR_DEVICE_CLASS,
     ATTR_ENTITY_ID,
@@ -65,6 +66,7 @@ async def async_handle(
     text_input: str | None = None,
     context: Context | None = None,
     language: str | None = None,
+    assistant: str | None = None,
 ) -> IntentResponse:
     """Handle an intent."""
     handler: IntentHandler = hass.data.get(DATA_KEY, {}).get(intent_type)
@@ -79,7 +81,14 @@ async def async_handle(
         language = hass.config.language
 
     intent = Intent(
-        hass, platform, intent_type, slots or {}, text_input, context, language
+        hass,
+        platform=platform,
+        intent_type=intent_type,
+        slots=slots or {},
+        text_input=text_input,
+        context=context,
+        language=language,
+        assistant=assistant,
     )
 
     try:
@@ -208,6 +217,7 @@ def async_match_states(
     entities: entity_registry.EntityRegistry | None = None,
     areas: area_registry.AreaRegistry | None = None,
     devices: device_registry.DeviceRegistry | None = None,
+    assistant: str | None = None,
 ) -> Iterable[State]:
     """Find states that match the constraints."""
     if states is None:
@@ -258,6 +268,14 @@ def async_match_states(
 
         states_and_entities = list(_filter_by_area(states_and_entities, area, devices))
 
+    if assistant is not None:
+        # Filter by exposure
+        states_and_entities = [
+            (state, entity)
+            for state, entity in states_and_entities
+            if async_should_expose(hass, assistant, state.entity_id)
+        ]
+
     if name is not None:
         if devices is None:
             devices = device_registry.async_get(hass)
@@ -387,6 +405,7 @@ class ServiceIntentHandler(IntentHandler):
                 area=area,
                 domains=domains,
                 device_classes=device_classes,
+                assistant=intent_obj.assistant,
             )
         )
 
@@ -496,6 +515,7 @@ class Intent:
         "context",
         "language",
         "category",
+        "assistant",
     ]
 
     def __init__(
@@ -508,6 +528,7 @@ class Intent:
         context: Context,
         language: str,
         category: IntentCategory | None = None,
+        assistant: str | None = None,
     ) -> None:
         """Initialize an intent."""
         self.hass = hass
@@ -518,6 +539,7 @@ class Intent:
         self.context = context
         self.language = language
         self.category = category
+        self.assistant = assistant
 
     @callback
     def create_response(self) -> IntentResponse:
@@ -568,7 +590,7 @@ class IntentResponseTargetType(str, Enum):
     CUSTOM = "custom"
 
 
-@dataclass
+@dataclass(slots=True)
 class IntentResponseTarget:
     """Target of the intent response."""
 
